classdef auctionData
%
% auctionData 
%
% Creates object consisting of bids in a single auction and characteristics
% of that auction, such as date of bidding and escalation factors.
%
% INPUTS:
%    - List of bid files
%    - Assumptions for auction evaluation
%
% OUTPUTS:
%    - auctionData object
%
properties
    auction_id;           % String auction ID
    bidder_files;         % Cell array containing file names of bid files
    bids;                 % Struct containing bidData objects
    bid_ids;              % bid_ids of bid objects
    esc_factors;          % Assumptions used in bid evaluation
end

properties (SetAccess = protected)
    lt;          % Vector of levelised tariffs of bidders in auction
    rank;        % Vector of ranks of bidders in auction
    winner;      % List of dummies for whether bid was accepted
    bid_keys;    % bid_keys of bid objects, same as ids but with _
    num_bidders; % Number of bidders in the auction
end

methods
    
    function obj = auctionData( auction_id, inventory, esc_data )

        % Auction ID
        obj.auction_id = auction_id;
        
        % Create bid objects for each bid in the auction
        bid_rows = find(strcmp(inventory.auction_id_provisional,auction_id));
        bid_dups = strfind(inventory.Notes,'Duplicate');
        bid_dups = find(~cellfun('isempty',bid_dups));
        inventory = inventory( setdiff(bid_rows,bid_dups), : );     

        obj.bids = struct;
        for i = 1:length(inventory.bid_id_provisional)
            
            % Replace dash with underscore in bid_ids for use as key
            bid_id    = inventory.bid_id_provisional{i};
            bid_file  = ['c',bid_id,'.txt'];
            bid_field = strrep(bid_id,'-','_');
            
            % Assign bid id key
            obj.bids.(bid_field) = bidData( bid_file, esc_data );
            obj.bid_ids{i}       = bid_id;
            obj.bid_keys{i}      = bid_field;           
        end
        obj.num_bidders = length(obj.bid_ids);

        % Get assumptions for auction scoring
        obj.esc_factors = get_escalation_factors( obj, esc_data );

        % Rank bidders
        [ obj.lt, obj.rank ] = rank_bidders( obj );
        
    end

    % Rank bids based on levelised tariff
    function [ lt, rank ] = rank_bidders( obj )
        lt = zeros(obj.num_bidders,1);
        for i = 1:obj.num_bidders
            lt(i) = obj.bids.(obj.bid_keys{i}).lt;
        end
        [ ~, rank ] = ismember( lt, unique(lt) );
    end
    
    % Method to plot all bids in an auction (external function)
%     auctionPlot
    
    % Method to calculate whether bid is a winner
    %   Should calculate bidder ranks and find cut-off based on capacity
    %   procured or total number of empirical winners.
    
end

methods (Access = private)

    function esc_factors = get_escalation_factors( obj, esc_data )
        auction_row = find(strcmp(obj.auction_id,esc_data.auction_id));
        if isempty(auction_row)
            auction_row = find(strcmp('Default',esc_data.auction_id));
        end           
        esc_factors = esc_data(auction_row,:);       
    end

end

end