classdef bidData
%
% bidData 
%
% Creates bid object in matlab from tab-delimited text file
%
% INPUTS:
%    - Bid-level data file of bid components
%
% OUTPUTS:
%    - bidData object
%
properties
    
    % Properties calculated on initialization
    file;           % Tab-delimited text file with bid data
    bidder_name;   
    auction_id;     % Id of auction to which bid belongs
    bid_id;         % Id of bid
    raw;            % Data table to hold bid components  
    esc_factors;    % Dataset of escalation factors
    dates;          % Matrix of start and end dates of each contract year
    
    % Properties calculated by leveliseBid
    part_names = {'capacity','energy_nes','energy_esc'};
    parts;          % Matrix of simpler bid components
    parts_all;      % Matrix with time path of all bid components
    parts_int;      % Bid components adjusted to force internal indexation
    annual;         % Vector of bid components by year
    heat_rate_bid;  % Dummy for whether heat rate was bid in place of 
                    %   escalable energy charge
    heat_rate;      % Heat rate (btu/kWh), if bid
    lt;             % Levelised tariff (INR/kWh)
    delta;          % Vector of discount factors in all periods of the bid
    Tdisc;          % Sum of discount factors (i.e., present value of 
                    %   number of periods
    Pdisc;          % Factor to convert current price into present average
                    %   value of future prices
    frac_indexed;   % Share of present value of bid indexed to energy price
    frac_indexed_var; % Share of present value of variable charges indexed
    frac_early5;    % Share of present value of bid in first 5 years
    frac_early10;
    charges;        % Present value of nominal bid components, with transport
                    %   stored separately from non-escalable energy
    transmission_included = 0; % Whether transmission charge was included in bid 
end

methods
    
    function obj = bidData( file, esc_data )
        % Initiates new powerBidData object
      
        % Read bid data from file
        obj.raw        = readtable(file,'Delimiter','\t',...
                                   'ReadVariableNames',true);
        % For Matlab 2017  'DatetimeType','text'
                               
        obj.file       = file;
        obj.auction_id = obj.file(2:6);
        obj.bid_id     = obj.file(2:10);
        obj.dates      = obj.get_bid_date_nums;
        
        % Get datatable object containing escalation factors
        %   for this particular bid, from the file containing escalation
        %   factors for all bids
        obj.esc_factors = get_escalation_factors( obj, esc_data );
    
        obj = leveliseBid( obj );
        
        % Tariff by year, undiscounted
        obj.annual = nansum( obj.parts_all, 2 );
        
    end
    
    % Levelise bid and aggregate bid components
    obj = leveliseBid( obj );
    
    % Plot bid components
    [ ] = plotBid( obj, write );
  
end

methods (Access = private)
    
    function dates = get_bid_date_nums( obj )
        date_str = [ obj.raw.COMMENCEMENTDATEOFCONTRACTYEAR, ...
                     obj.raw.ENDDATEOFCONTRACTYEAR ];

        % Detect whether year is missing from bid year end date
        %   Needed because many dates are of format '31-MARCH' with no year
        fy_missing = false;
        try 
            datenum(char(date_str(1,2)),'DD-mmmm-yyyy');
        catch ME
            if strcmp(ME.identifier,'MATLAB:datenum:ConvertDateString')
                fy_missing = true;
            else
                rethrow(ME)
            end
        end
        
        % Add financial year information to start and end dates, if missing
        fy = obj.raw.FINANCIALYEAR;
        if fy_missing
            fychar   = char(fy);
            fy_start = strcat( date_str(2:end,1),{'-'},fychar(2:end,1:4));
            fy_end   = strcat( date_str(1:end-1,2),{'-'}, ...
                               fychar(2:end,1:2), fychar(2:end,6:7) );
            date_str(2:end,1)   = fy_start;
            date_str(1:end-1,2) = fy_end;
        end
            
        % Fill in start and end dates if not specified in bid, based on
        %   assumption that project starts mid-way through fiscal year
        if ~isempty(strfind(date_str{1,1},'SCHEDULED'))
            first_year_end = datenum(date_str(1,2),'DD-mmmm-yyyy');
            first_year     = datevec(first_year_end);
            first_year_start = datetime(first_year(1)-1,10,1);
            date_str{1,1} = upper(datestr(first_year_start,'DD-mmmm-yyyy'));
        end
        
        if ~isempty(strfind(date_str{end,2},'SCHEDULE')) || ...
           ~isempty(strfind(date_str{end,2},'CONTRACT'))
            last_year_start = datenum(date_str(end,1),'DD-mmmm-yyyy');
            last_year       = datevec(last_year_start);
            last_year_end = datetime(last_year(1),9,30);
            date_str{end,2} = upper(datestr(last_year_end,'DD-mmmm-yyyy'));
        end
        
        % Check that commencement data of first contract year is a
        %   four-digit year, and not a two-digit year.  Correct as needed
        date_parts = strsplit(date_str{1,1},'-');
        if length(date_parts{3}) == 2
            date_parts{3} = ['20',date_parts{3}];
            date_str{1,1} = strjoin( date_parts, '-' );
        end
        
        % Convert string dates to numeric
        dates = [ datenum(date_str(:,1),'DD-mmmm-yyyy') ...
                  datenum(date_str(:,2),'DD-mmmm-yyyy') ];
    end

    function esc_factors = get_escalation_factors( obj, esc_data )
        auction_row = find(strcmp(obj.auction_id,esc_data.auction_id));
        default_row = find(strcmp('Default',esc_data.auction_id));
        if isempty(auction_row)
            auction_row = default_row;
        end           
        esc_factors         = esc_data(auction_row,:);
        esc_factors_default = esc_data(default_row,:);
        
        % Calculate first year fraction, commissioning lag if no value
        if isnan( esc_factors.year_one_fraction )
            esc_factors.year_one_fraction = ...
                days(days(obj.dates(1,2) - obj.dates(1,1))) / 365;
            nm = ~isnan( esc_factors.year_one_fraction );
            assert( all(esc_factors.year_one_fraction(nm) <= 1 ));
            assert( all(esc_factors.year_one_fraction(nm) >= 0 ));
        end
        
        if isnan( esc_factors.years_till_start )
            esc_factors.years_till_start = 6.022;
        end
        
        % Assign values of transportation escalation for inland and overseas
        %   based on generic transport escalation from the same bid
        if isnan( esc_factors{1,'esc_rate_transportation_inland'} )
            esc_factors{1,'esc_rate_transportation_inland'} = ...
                esc_factors{1,'esc_rate_transport'};
        end
        
        if isnan( esc_factors{1,'esc_rate_transportation_overseas'} )
            esc_factors{1,'esc_rate_transportation_overseas'} = ...
                esc_factors{1,'esc_rate_transport'};
        end
        
        % Assign values of bidding assumptions from 'default' bid profile
        %   assumption-by-assumption, if an element of assumptions missing.
        %   For example, Sasan project has interest rate but no assumption
        %   on INR appreciation.
        assumptions = esc_factors.Properties.VariableNames';
        for i = 4:length(assumptions)
            if isnan( esc_factors{1,assumptions{i}} )
                esc_factors(1,assumptions{i}) = esc_factors_default(1,assumptions{i});
            end
        end
    end
    
end

end