function [ obj ] = leveliseBid( obj )
% leveliseBid Calculate levelised tariff and consolidate bid components
%             into the three theoretical components of escalable energy
%             charges, non-escalable energy charges, and fixed charges.
%
% INPUT:
%  obj          bidData object
%
%  esc_factors  table of escalation factors, part of powerBidData object,
%               which contains the following components
%     'esc_rate_capacity'   capacity charge escalation at annual rate
%     'esc_rate_energy'     energy charge escalation at annual rate
%     'esc_rate_transport'  transport charge escalation at annual rate
%     'esc_rate_handling'   handling charge escalation at annual rate
%     'inr_per_usd'         exchange rate in base year
%     'inr_rate_apprec'     inr appreciation at annual rate
%     'interest_rate'       interest rate used in computing present values
%     'year_one_fraction'   fractional year length of first contract year
%     'years_till_start'    years from the bidding date to commissioning
%
% OUTPUT:

%  parts_all    Matrix of all bid components. For non-captive projects, 
%               bid components are {Non-escalable,escalable} parts of:
%
%                      Capacity Energy     Transport Handling
%                      Rs/kWh   USD/kWh    USD/kWh   Rs/kWh  
%   
%               For captive projects, bid components are:
%
%                      Capacity Energy 
%                      Rs/kWh   Rs/kWh      
%
%  bid          Matrix of bid components with only three columns,
%                 for capacity, non-escalable energy charges and escalable
%                 energy charges, respectively. 
%
%  lt           Scalar levelised tariff of the bid

%% Select relevant bid components for the given bid type

% Fundamental components of bids
%   Row vector indicating whether charge is part of:
%   [ Capacity charge, variable charges *not* indexed to fuel price,
%     variable charge indexed to fuel price (escalable energy) ]
bid_component     = [ 1 2 2 2 2 2 1 3 3 2 2 2 ];    
bid_component_trn = [ 1 2 2 4 4 2 1 3 3 4 4 2 ];  % With transportation separate

years        = length(obj.dates(:,1));
currency_usd = [ 0 0 0 0 0 0 ];
nes          = zeros(years,6);
esc          = zeros(years,6);

%% Non-escalable charges
%   Capacity           Energy-Domestic       Energy-Overseas
%   Transport-Inland   Transport-Overseas    Handling

% Capacity          
charges = {'CAPACITYCHARGE_RS_KWH_', ... 
           'NON_ESCALABLECAPACITYCHARGE_RS_KWH_'};
keep    = ismember(charges,obj.raw.Properties.VariableNames');
charges = charges(keep);
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    nes(:,1)   = nansum( obj.raw{:,charges{applicable}}, 2 ); 
    currency_usd(1) = any(~cellfun('isempty',...
                          strfind(charges(applicable),'USD')));
end

% Energy - Domestic (or Imported, if project has only one fuel source)
charges = {'ENERGYCHARGE_RS_KWH_',...
           'NON_ESCALABLEENERGYCHARGE_RS_KWH_',...
           'NON_ESCALABLEENERGYCHARGE_RS_KWH_OR_USD_KWH_',...
           'NON_ESCALABLEENERGYCHARGE_USD_KWH_'};
keep    = ismember(charges,obj.raw.Properties.VariableNames');
charges = charges(keep);
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    nes(:,2)   = nansum( obj.raw{:,charges{applicable}}, 2 ); 
    currency_usd(2) = any(cellfun('isempty',...
                          strfind(charges(applicable),'RS')));
end

% Energy - Overseas (only for blended coal projects with two fuel sources)
charges = {'NON_ESCALABLEENERGYCHARGE_USD_KWHTORS_KWH_'};
keep    = ismember(charges,obj.raw.Properties.VariableNames');
charges = charges(keep);
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    nes(:,3)   = nansum( obj.raw{:,charges{applicable}}, 2 ); 
end

% Transportation - Inland
charges = {'TRANSPORTATIONCHARGE_RS_KWH_',...
           'NON_ESCALABLEINLANDTRANSPORTATIONCHARGE_RS_KWH_',...
           'NON_ESCALABLETRANSMISSIONCHARGE_RS_KWH_',...
           'NON_ESCALABLETRANSPORTATIONCHARGE_RS_KWH_'};
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    nes(:,4)   = nansum( obj.raw{:,charges(applicable)}, 2 ); 
    currency_usd(4) = any(~cellfun('isempty',...
                          strfind(charges(applicable),'USD')));
end

% Transportation - Overseas
charges = {'NON_ESCALABLEOVERSEASTRANSPORTATIONCHARGE_RS_KWH_',...
           'NON_ESCALABLEOVERSEASTRANSPORTATIONCHARGE_RS_KWH_OR_USD_KWH_',...
           'NON_ESCALABLEOVERSEASTRANSPORTATIONCHARGE_USD_KWH_',...
           'NON_ESCALABLETRANSPORTATIONCHARGE_USD_KWH_',...
           'NON_ESCALABLEOVERSEASTRANSPORTATIONCHARGE_USD_KWHTORS_KWH_'};
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    nes(:,5)   = nansum( obj.raw{:,charges(applicable)}, 2 ); 
    currency_usd(5) = any(~cellfun('isempty',...
                          strfind(charges(applicable),'USD'))) & ...
                      ~any(~cellfun('isempty',...
                          strfind(charges(applicable),'TORS')));
end
      
% Fuel Handling
charges = {'NON_ESCALABLEFUELHANDLINGCHARGE_RS_KWH_'};
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    nes(:,6)   = nansum( obj.raw{:,charges{applicable}}, 2 ); 
    currency_usd(6) = any(~cellfun('isempty',...
                          strfind(charges(applicable),'USD')));
end

%% Escalable charges
%   Capacity           Energy-Domestic       Energy-Overseas
%   Transport-Inland   Transport-Overseas    Handling

% Capacity
esc(:,1) = obj.raw.ESCALABLECAPACITYCHARGE_RS_KWH_;
 
% Energy - Domestic (or Imported, if project has only one fuel source)
charges = {'ESCALABLEENERGYCHARGE_RS_KWH_',...
           'ESCALABLEENERGYCHARGE_USD_KWH_'};
%  'ESCALABLEENERGYCHARGE_RS_KWH_OR_USD_KWH_',...
applicable        = any(obj.raw{:,charges},1);
obj.heat_rate_bid = any(obj.raw{:,'HEATRATE_KCAL_KWH_'},1);
if any(applicable)
    esc(:,2)        = nansum( obj.raw{:,charges{applicable}}, 2 ); 
    currency_usd(2) = max( currency_usd(2), ...
                           any(cellfun('isempty', ...
                           strfind(charges(applicable),'RS'))) );
elseif obj.heat_rate_bid
    obj.heat_rate = 3.96567 * obj.raw{1,'HEATRATE_KCAL_KWH_'};
    esc(:,2) = obj.raw{:,'HEATRATE_KCAL_KWH_'} / ...
               obj.esc_factors.gross_calorific_value * ...
               obj.esc_factors.coal_cost / 1000;
    esc(:,4) = obj.raw{:,'HEATRATE_KCAL_KWH_'} / ...
               obj.esc_factors.gross_calorific_value * ...
               obj.esc_factors.coal_transportation_cost / 1000;
end

% Energy - Overseas (only for blended coal projects with two fuel sources)
charges = {'ESCALABLEENERGYCHARGE_USD_KWHTORS_KWH_'};
keep    = ismember(charges,obj.raw.Properties.VariableNames');
charges = charges(keep);
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    esc(:,3)   = nansum( obj.raw{:,charges{applicable}}, 2 ); 
end

% Transportation - Inland
charges = {'ESCALABLEINLANDTRANSPORTATIONCHARGE_RS_KWH_',...
           'ESCALABLETRANSPORTATIONCHARGE_RS_KWH_',...
           'ADD_TRANSMISSIONCHARGES'}; % Transmission should have own esc. rate
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    esc(:,4)        = nansum( obj.raw{:,charges(applicable)}, 2 ); 
    currency_usd(4) = max( currency_usd(4), ...
                           any(~cellfun('isempty',...
                           strfind(charges(applicable),'USD'))) );
end

% Transportation - Overseas
charges = {'ESCALABLEOVERSEASTRANSPORTATIONCHARGE_RS_KWH_',...
           'ESCALABLEOVERSEASTRANSPORTATIONCHARGE_RS_KWH_OR_USD_KWH_',...
           'ESCALABLEOVERSEASTRANSPORTATIONCHARGE_USD_KWH_',...
           'ESCALABLETRANSPORTATIONCHARGE_USD_KWH_',...
           'ESCALABLEOVERSEASTRANSPORTATIONCHARGE_USD_KWHTORS_KWH_'};
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    esc(:,5)        = nansum( obj.raw{:,charges{applicable}}, 2 ); 
    currency_usd(5) = max( currency_usd(5), ...
                           any(~cellfun('isempty',...
                           strfind(charges(applicable),'USD'))) & ...
                           ~any(~cellfun('isempty',...
                           strfind(charges(applicable),'TORS'))) );
end

% Fuel Handling
charges = {'ESCALABLEFUELHANDLINGCHARGE_RS_KWH_'};
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    esc(:,6)   = nansum( obj.raw{:,charges{applicable}}, 2 ); 
    currency_usd(6) = max( currency_usd(6), ...
                       any(~cellfun('isempty',...
                       strfind(charges(applicable),'USD'))) );
end

% Example: charges for Krishnapatnam
% nes2 = [ obj.raw.NON_ESCALABLECAPACITYCHARGE_RS_KWH_ ...
%         obj.raw.NON_ESCALABLEFUELENERGYCHARGE_USD_KWH_ ...
%         obj.raw.NON_ESCALABLETRANSPORTATIONENERGYCHARGE_USD_KWH_ ...
%         obj.raw.NON_ESCALABLEFUELHANDLINGENERGYCHARGE_RS_KWH_ ];
% 
% esc2 = [ obj.raw.ESCALABLECAPACITYCHARGE_RS_KWH_ ...
%         obj.raw.ESCALABLEFUELENERGYCHARGE_USD_KWH_ ...
%         obj.raw.ESCALABLETRANSPORTATIONENERGYCHARGE_USD_KWH_ ...
%         obj.raw.ESCALABLEFUELHANDLINGENERGYCHARGE_RS_KWH_ ];

% Flag whether transmission charges are included in the bid. Typically they
% are not included in the bid for Case 1 projects, but are included as part
% of the calculation of Levelised Tariffs.
charges = {'ADD_TRANSMISSIONCHARGES',...
           'NON_ESCALABLETRANSMISSIONCHARGE_RS_KWH_'};
applicable = any(obj.raw{:,charges},1);
if any(applicable)
    obj.transmission_included = 1;
end

%% Calculate escalation factors for escalable components of bid
%   Mimic the Krishnapatnam spreadsheet in the factors applied to year one

% Length of first (fractional) contract year
year_one = obj.esc_factors.year_one_fraction;

% Calculate appropriate powers to which to raise escalation factors
powers   = repmat((1:26)',[1 size(nes,2)]);
% powers12 = [ obj.esc_factors.years_till_start + year_one/2; ...
%              obj.esc_factors.years_till_start + year_one + 0.5 ];
powers12 = [ obj.esc_factors.years_till_start; ...
             obj.esc_factors.years_till_start + 1 ];
powers12 = [ [ 0; 1 ] powers12(:,ones(1,size(nes,2)-1)) ];
powers   = [ powers12 ; powers(1:24,:) + powers12(2*ones(24,1),:)];

% Escalation factors for 
%   Capacity Energy Transport-Inland Transport-Overseas Handling
escalation = [ 1 + obj.esc_factors.esc_rate_capacity ...
               1 + obj.esc_factors.esc_rate_energy ...
               1 + obj.esc_factors.esc_rate_energy_overseas ...
               1 + obj.esc_factors.esc_rate_transport ...
               1 + obj.esc_factors.esc_rate_transportation_overseas ...
               1 + obj.esc_factors.esc_rate_handling ];
escalation = escalation(ones(26,1),:) .^ powers;

% Discount factors
%   Present value of future payment is ( delta X payment )
R         = 1 + obj.esc_factors.interest_rate;
delta     = [ (1/R).^(year_one/2); ...
              (1/R).^(year_one+0.5); ...
              (1/R).^(year_one+0.5+[1:24]') ];

% Exchange rate
%    INR / USD assumed to rise over time, thus depreciation; however, the 
%    positive rate of INR / USD growth is referred to as 'appreciation/
%    depreciation'.  Confirmed with Krisnapatnam analysis that it is in
%    fact appreciation.
inr_depreciation        = obj.esc_factors.inr_per_usd(ones(26,1)) .* ...
                          (1 + obj.esc_factors.inr_rate_apprec).^ ...
                          ([0:25]' + obj.esc_factors.years_till_start);
num_usd_charges         = sum(currency_usd);        
exchange                = currency_usd(ones(size(esc,1),1),:);        
exchange( exchange==1 ) = inr_depreciation(:,ones(1,num_usd_charges));
exchange( exchange==0 ) = 1;

%% Sum over bid components
%   Capacity Energy Transport-Inland Transport-Overseas Handling
esc = esc .* escalation .* exchange;
nes = nes               .* exchange; 

% Levelised tariff
obj.parts_all = [ nes esc ];
bid_sum   = nansum(obj.parts_all,2);
obj.delta = delta;
obj.Tdisc = sum(delta,1); % Discounted number of periods
obj.lt    = sum(delta.*bid_sum,1) / obj.Tdisc;

% Present average value of expected future prices
%   Present value as of the start of delivery
%   Average is a weighted average with discount factor weights
obj.Pdisc = sum( escalation(:,2) .* delta ) / obj.Tdisc;

% Theoretically consistent bids
%   [ Capacity charge, variable charges *not* indexed to fuel price,
%     variable charge indexed to fuel price (escalable energy) ]
rows      = repmat([1:26]',1,size(bid_component,2));
cols      = bid_component(ones(26,1),:);
obj.parts = accumarray([rows(:) cols(:)],obj.parts_all(:),[26 3],@nansum);

% Theoretically consistent bids - Transportation separate
%   [ Capacity charge, variable charges *not* indexed to fuel price,
%     variable charge indexed to fuel price (escalable energy), 
%     transportation ]
cols      = bid_component_trn(ones(26,1),:);
parts_trn = accumarray([rows(:) cols(:)],obj.parts_all(:),[26 4],@nansum);

%% Create objects recording share of bid indexed

% Adjust bids for internal indexation
%   Bid components as above for theoretically consistent bids. System of
%   equations for type relies on interior solution for indexation. 
%   If escalable part of energy charge is zero, increase it to 10% of the
%     total (escalable and non-escalable) energy charge.
obj.parts_int = obj.parts;
beta_0  = (delta' * obj.parts) / obj.Tdisc;       
if obj.parts(1,3) == 0
    index_frac = 0.10;
    beta_h  = index_frac * beta_0(2) * escalation(:,2) / obj.Pdisc;
    beta_e  = (1-index_frac) * obj.parts(:,2);
    obj.parts_int(:,2) = beta_e;
    obj.parts_int(:,3) = beta_h;
end

% Share of present value of bids indexed
obj.frac_indexed = beta_0(3) / sum(beta_0);

% Share of present value of variable charges indexed
obj.frac_indexed_var = beta_0(3) / sum(beta_0(2:3));

% Share of bid present value in first 5/10 years
delta_first5  = [ delta(1:5); zeros(length(delta)-5,1) ];
delta_first10 = [ delta(1:10); zeros(length(delta)-10,1) ];
% delta_last20 = [ zeros(5,1); delta(6:end) ];
obj.frac_early5  = (delta_first5'  * bid_sum) / (delta' * bid_sum);
obj.frac_early10 = (delta_first10' * bid_sum) / (delta' * bid_sum);

% Present value of nominal tariff components
beta0_trn = (delta' * parts_trn) / obj.Tdisc;    
capacity    = beta0_trn(1);
transport   = beta0_trn(4);
energy_nesc = beta0_trn(2);
energy_esc  = beta0_trn(3);
obj.charges = table(capacity,energy_nesc,energy_esc,transport);

end



