classdef EnergyDemandModel
% EnergyDemandModel 
%
% A model of input demand given parameters of production function.
%
% INPUT:
%   Parameter vector
%
% OUTPUT:
%   Mean log input demand by plant
%

properties
    paramlist;         
    lower_bound;
    upper_bound;
    paramlist_sig;    
    paramlist_pi;     
    paramlist_alp      = { 'alpha' };
    paramlist_del      = { 'delta' };
    paramlist_muA      = { 'muA' };
    paramlist_sigA     = { 'sigA' };
    phi                = 0.85;
    default_startparam;  
    demand_varlist     = { 'auditTreatment' };
    production_fun;
end

properties (Dependent)
    nparam;          % Number of parameters
    indices;         % Struct giving the index of each parameter
    indices_sig;
    indices_pi;
    indices_alp;
    indices_del;
    indices_muA;
    indices_sigA;
end

methods
    
    function obj = EnergyDemandModel( production_function )
        if nargin == 0
            production_function = '2level_LM_EHK';
        end
        
        obj.production_fun = production_function;
        
        switch obj.production_fun
            
            case '2level_LM_EHK'
                obj.default_startparam = [ 0.5 3.0 0.5 0.3 0.3 ...
                                           0.2 1.1 7.0 ];  
                obj.lower_bound        = [ 0.01 0.01 0.01 0.01 0.01 ...
                                           0.01 0.8  1.0 ];  
                obj.upper_bound        = [ 10.0 10.0 0.99 0.99 0.99 ...
                                           0.99 2.0 10.0 ];  
                obj.paramlist          = { 'sig1' 'sig2' ...
                                           'pi1' 'pi2' 'pi3' ...
                                           'alpha' 'delta' 'muA' };
                obj.paramlist_sig      = { 'sig1' 'sig2' };
                obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' };
                
            case '2level_HK_EML'  
                obj.default_startparam = [ 0.5 3.0 0.5 0.3 0.3 ...
                                           0.2 1.1 7.0 ];  
                obj.lower_bound        = [ 0.01 0.01 0.01 0.01 0.01 ...
                                           0.01 0.8  1.0 ];  
                obj.upper_bound        = [ 10.0 10.0 0.99 0.99 0.99 ...
                                           0.99 2.0 10.0 ];  
                obj.paramlist          = { 'sig1' 'sig2' ...
                                           'pi1' 'pi2' 'pi3' ...
                                           'alpha' 'delta' 'muA' };
                obj.paramlist_sig      = { 'sig1' 'sig2' };
                obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' };
                
            case '2level_hybrid_HK_EML'  
%                 obj.default_startparam = [ 0.5 3.0 0.5 0.3 0.3 ...
%                                            0.2 1.1 6.0 ];  
%                 obj.lower_bound        = [ 0.01 0.01 0.01 0.01 0.01 ...
%                                            0.01 1.0  1.0 ];  
%                 obj.upper_bound        = [ 15.0 15.0 0.99 0.99 0.99 ...
%                                            0.99 2.0 10.0 ];  
%                 obj.paramlist          = { 'sig1' 'sig2' ...
%                                            'pi1' 'pi2' 'pi3' ...
%                                            'alpha' 'delta' 'muA' };
%                 obj.paramlist_sig      = { 'sig1' 'sig2' };
%                 obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' };
                 
                obj.paramlist          = { 'sig1' 'sig2' ...
                                           'pi1' 'pi2' 'pi3' ...
                                           'alpha' 'delta' 'muA' 'sigA' };
                obj.default_startparam = [ 0.5 3.0 0.5 0.3 0.3 ...
                                           0.2 1.1 6.0 0.10 ];  
                obj.lower_bound        = [ 0.01 0.01 0.01 0.01 0.01 ...
                                           0.01 0.8  1.0  0.00 ];  
                obj.upper_bound        = [ 10.0 10.0 0.99 0.99 0.99 ...
                                           0.99 2.0 10.0 10.0 ];  
                obj.paramlist_sig      = { 'sig1' 'sig2' };
                obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' };
                 
            case '3level_H_K_EML'
                obj.default_startparam = [ 0.5 0.5 3.0 0.5 0.3 0.3 ...
                                           0.2 1.1 7.0 ];  
                obj.lower_bound        = [ 0.01 0.01 0.01 0.01 0.01 0.01 ...
                                           0.01 0.8  1.0 ];  
                obj.upper_bound        = [ 10.0 10.0 10.0 0.99 0.99 0.99 ...
                                           0.99 2.0 10.0 ];  
                obj.paramlist          = { 'sig1' 'sig2' 'sig3' ...
                                           'pi1' 'pi2' 'pi3' ...
                                           'alpha' 'delta' 'muA' };
                obj.paramlist_sig      = { 'sig1' 'sig2' 'sig3' };
                obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' };
                
            case '2level_ces_HK_ELM'
                obj.paramlist          = { 'sig1' 'sig2' 'sig3' ...
                                           'pi1'  'pi2'  'pi3' 'pi4' ...
                                           'delta' 'muA' };
                obj.default_startparam = [ 0.5 0.5 2.0 ...
                                           0.3 0.3 0.3 0.3 ...
                                           1.1 7.0 ];  
                obj.lower_bound        = [ 0.01 0.01 0.01 ...
                                           0.01 0.01 0.01 0.01 ...
                                           0.8  1.0 ];  
                obj.upper_bound        = [ 10.0 10.0 10.0 ...
                                           0.99 0.99 0.99 0.99 ...
                                           2.0 10.0 ];  
                obj.paramlist_sig      = { 'sig1' 'sig2' 'sig3' };
                obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' 'pi4' };
                
            case '2level_ces_LM_EHK'
                obj.paramlist          = { 'sig1' 'sig2' 'sig3' ...
                                           'pi1'  'pi2'  'pi3' 'pi4' ...
                                           'delta' 'muA' };
                obj.default_startparam = [ 2.0 2.0 0.5 ...
                                           0.3 0.3 0.3 0.3 ...
                                           1.1 7.0 ];  
                obj.lower_bound        = [ 0.01 0.01 0.01 ...
                                           0.01 0.01 0.01 0.01 ...
                                           0.8  1.0 ];  
                obj.upper_bound        = [ 10.0 10.0 10.0 ...
                                           0.99 0.99 0.99 0.99 ...
                                           2.0 10.0 ];  
                obj.paramlist_sig      = { 'sig1' 'sig2' 'sig3' };
                obj.paramlist_pi       = { 'pi1' 'pi2' 'pi3' 'pi4' };               
                
            otherwise
                warning('No production function assigned!');
                
        end
        
    end
    
    function n = get.nparam(obj)
        n = length(obj.paramlist);
    end

    function ind = get.indices(obj)
        ind = cell2struct(num2cell(1:obj.nparam)', obj.paramlist);
    end  
    
    function ind = get.indices_sig(obj)
        ind = find(ismember(obj.paramlist, obj.paramlist_sig));
    end
    
    function ind = get.indices_pi(obj)
        ind = find(ismember(obj.paramlist, obj.paramlist_pi));
    end
    
    function ind = get.indices_alp(obj)
        ind = find(ismember(obj.paramlist, obj.paramlist_alp));
    end
    
    function ind = get.indices_del(obj)
        ind = find(ismember(obj.paramlist, obj.paramlist_del));
    end
    
    function ind = get.indices_muA(obj)
        ind = find(ismember(obj.paramlist, obj.paramlist_muA));
    end
    
    function ind = get.indices_sigA(obj)
        ind = find(ismember(obj.paramlist, obj.paramlist_sigA));
    end
    
    [ I, Cov ] = ComputeEnergyDemand( obj, data, param );
           
end

end