classdef coalData
%
% coalData 
%
% Creates bid object in matlab from file of coal prices
%
% INPUTS:
%    - Time series data of coal prices
%
% OUTPUTS:
%    - coalData object
%
properties
    
    % Expectation assumptions: How coal price expectations are formed
    captive_margin        = 0.20; % 20 percent margin assumed on captive coal  
    energy_growth_process = {'captive','domestic','imported','auctioneer','source'};
    energy_growth_index   = 3;
%     energy_growth_index = 4;
    
    % Domestic coal price baseline.
    %   WPI coal price series is an index value. Therefore pin to domestic
    %   Coal India prices in a given base year (alternatively, to imports).
    currency       = 'inr';
    base_method    = 'coalindia';
    base_years     = [ 2012 ];
%     base_method    = 'imported';
%     base_year      = 2003;  % Base year for domestic coal price re-basing
%     base_years     = [ 2000 2003 ];
    
    % Properties calculated on initialization
    prices;        % Table of coal price data
    source         = {'captive','domestic','imported'};
    start_years    = [2006:2012]'; % Auction years in sample
    interest_rate  = 0.105;        % Interest rate to use in discounting 
    simulations    = 2000;
    discount;                      % Matrix of discount factors from interest rate
    seed           = 20180822;     % Seed for simulation of price paths
    units          = 'USD per ton';
                    
    % Properties calculated by summarizePricePath
    %   Each object is of dimension 
    %   [ start years / start months X sources ]
    %   for the three coal sources, captive, domestic and imported
    exp_price;      % expected discounted value of price path (# start years)
    variance_price; % variance of discounted value of price path (# start years)
    trailing_price; % price in the year before bidding
    
    % Properties calculated by futurePriceParameters
    mu_s;           % [T X |start_years| X Sources] matrix of mean of log price dist.
    sig_s;          % [T X |start_years| X Sources] matrix of std of log price dist.
    mu_t;           % [T X |start_years|] matrix of mean of log price dist.
    sig_t;          % [T X |start_years|] matrix of std of log price dist.
      
end

methods
    
    function obj = coalData( file_imported, file_domestic )
        % Initialize a coalData object
        
        % Coal price data on each source
        imported = readtable( ['./imported_newc/',file_imported] );
        domestic = readtable( ['./domestic_wpi/', file_domestic] );
        
        % Exchange rate data
        exchange = readtable( './exchange_rate/inr_per_usd.csv' );
        
        % Numeric date and year
        imported = get_date_nums( imported ); 
        domestic = get_date_nums( domestic ); 
        exchange = get_date_nums( exchange );
        
        % Merge all prices
        obj.prices = join(imported,   domestic, 'Keys', 'date');
        obj.prices = join(obj.prices, exchange, 'Keys', 'date');
        [ obj.prices.year, obj.prices.month ] = datevec( obj.prices.date );
        
        % Assign price series names
        obj.prices.captive      = NaN(size(obj.prices.wpi_coal));
        obj.prices.domestic     = obj.prices.wpi_coal;
        obj.prices.imported_usd = obj.prices.newc;
        obj.prices.imported     = obj.prices.newc .* obj.prices.inrperusd;
        
        % Remove redundant variables
        delete = regexp( obj.prices.Properties.VariableNames, ...
                         '_imported$|_domestic$|wpi_coal|newc' );
        obj.prices = obj.prices( :, cellfun( @isempty, delete ) );
        
        % Discount factor to convert future charges into present value
        %  * as of the start of supply *. This discounting mimics that in
        %  the Krishnapatnam scoring sheet. It will differ from PV as of
        %  the time of bidding, which is typically 5 years earlier.
        obj.discount = (1+obj.interest_rate).^[-4:25]';
        
        % Re-base prices, as domestic price is passed in index form
        obj.prices         = rebase( obj );
        obj.prices.captive = obj.prices.domestic / (1+obj.captive_margin);
        
        % Coal price expectations
        [ obj ] = coalPriceExpectations( obj );
        
    end
    
    function [ prices ] = rebase( obj )
        % Re-base domestic coal prices 
        
        switch obj.base_method
            
            case 'coalindia'
                % Base: Coal India domestic prices
                coalindia = readtable(['./coal_india_prices/clean/',...
                    'coal_india_prices.txt'],'Delimiter','\t');
                years = length(coalindia.Var1);
                coalindia.year = NaN(years,1);
                for y = 1:years
                    date  = coalindia.Var1{y};
                    year2 = str2num(date(5:6));
                    coalindia.year(y) = 2000 + year2;
                end
                
                in_base_years = ismember( coalindia.year, obj.base_years );
                base_prices = table2array( coalindia(...
                    in_base_years,{'price_Rs_tonne_'}) );
                in_base_years = ismember( obj.prices.year, obj.base_years );
                base_index = table2array( obj.prices(...
                    in_base_years,{'domestic'}) );
                inflation_factor = mean(base_prices,1) / mean(base_index,1);
                
            case 'imported'
                % Base: Imported (newcastle) prices
                in_base_years = ismember( obj.prices.year, obj.base_years );
                base_prices = table2array( obj.prices(...
                    in_base_years,{'domestic','imported'}) );
                base_prices = mean(base_prices,1);
                inflation_factor = base_prices(2) / base_prices(1);           
        end
        
        prices          = obj.prices;
        prices.domestic = prices.domestic * inflation_factor;
    end
    
    function [ obj ] = coalPriceExpectations( obj )
        % Create price expectations for each source of 
        %  {captive, domestic, imported}
        sources            = length(obj.source);
        T                  = length(obj.start_years);
        obj.exp_price      = NaN(T,sources);
        obj.variance_price = NaN(T,sources);
        obj.trailing_price = NaN(T,sources);
        
        for s = 1:sources
        
            % Check if a price is available
            price_not_missing = any( ~isnan(obj.prices.(obj.source{s})) );
            if price_not_missing
                
                % Simulate price paths for each starting year
                %   log-differences in moving average of monthly
                %   prices, at 12-month intervals
                [ price_log_diff ] = differenceLogPrices( obj, obj.source{s} );

                % Auction length X # paths X # start years simulated 
                %   price paths
                [ price_paths ] = simulatePricePath( obj, price_log_diff );

                % Summary statistics on price paths for each starting year
                [ obj.exp_price(:,s), obj.variance_price(:,s) ] = ...
                    summarizePricePath( obj, price_paths );
                [ obj.trailing_price(:,s) ] = trailingPrice( obj, obj.source{s} );

                % Parameters of future price distributions
                [ obj.mu_s(:,:,s), obj.sig_s(:,:,s) ] = ...
                    futurePriceParameters( obj, price_log_diff );
            
            end     
        end 
        
        % Pick parameters for expectations from source series
        energy_growth = obj.energy_growth_process{obj.energy_growth_index};
        switch energy_growth
            
            case {'captive','domestic','imported'}
                obj.mu_t  = obj.mu_s(:,:,obj.energy_growth_index);
                obj.sig_t = obj.sig_s(:,:,obj.energy_growth_index);           
            
            case 'auctioneer'
                % Mean energy growth escalation from auction assumptions
                gp = 0.0606; 
                num_sample_years = length(obj.start_years);    
                obj.mu_t = (1+gp).^repmat([1:30]',[1 num_sample_years]);
                
                % Standard deviation of energy growth escalation from data
                obj.sig_t = obj.sig_s(:,:,3);
                
            case 'source'
                % May add in future if we want to differentiate 
                %   expectations parameters by source.
            
        end
        
    end
    
    function [ price_log_diff ] = differenceLogPrices( obj, source )
        % Smooth monthly price series to ma
        %   24-months matches trailing price
        switch source
            case 'captive'
                ma_length = 12;
            case 'domestic'
                ma_length = 12;
            case 'imported'
                ma_length = 60;
        end
        price_cs  = cumsum( obj.prices.(source) );
        price_ma  = ( price_cs(ma_length:end) - ...
                      [0; price_cs(1:end-ma_length)] )/ma_length;
        
        % Calculate log price differences
        log_price      = log( price_ma );
        price_log_diff = log_price(13:end) - log_price(1:end-12);
    end 
    
    function [ price_paths ] = simulatePricePath( obj, price_log_diff )
        
        % Initialize price path object
        year           = obj.prices.year(13:end); % To allow 12-month lag
        price_paths    = zeros( 30, obj.simulations, length(obj.start_years) );
        
        % For each starting (auction) year, restrict sample to eligible
        %   years (from 1988 onwards) and draw price innovations at random.
        for i = 1:length(obj.start_years)
            start_year = obj.start_years(i);
            
            % Limit data to sample prior to given start year
            % in_year_range = year < start_year & year >= start_year - 11;
            in_year_range = year < start_year & year >= 1988;
            price_log_diff_yr = price_log_diff(in_year_range);
        
            % Draw price innovations and cumulate for annual price path
            rng(obj.seed);
            bi = randi(length(price_log_diff_yr),[30,obj.simulations]);
            price_log_diff_s     = price_log_diff_yr( bi );
            price_log_diff_s_cum = cumsum( price_log_diff_s );
            price_paths(:,:,i)   = exp( price_log_diff_s_cum );
                       
            % Discount nominal prices into present value terms
            price_paths(:,:,i)= price_paths(:,:,i) ./ ...
                                obj.discount(:,ones(1,obj.simulations));
        end        
    end
        
    function [ exp_price, variance_price ] = summarizePricePath( obj, ...
                                                 price_paths )
        exp_price = zeros(length(obj.start_years),1);
        variance_price = zeros(length(obj.start_years),1);
        Tdisc = sum(1./obj.discount(6:end));
        for i = 1:length(obj.start_years)
            price_pdv         = sum(price_paths(6:end,:,i),1) / Tdisc; 
            exp_price(i)      = mean( price_pdv, 2 );
            variance_price(i) = var( price_pdv, [], 2 );
        end
    end
    
    function [ trailing_price ] = trailingPrice( obj, source )
        switch source
            case 'captive'
                trailing_years = 1;
            case 'domestic'
                trailing_years = 1;
            case 'imported'
                trailing_years = 5;
        end
        trailing_price = zeros(length(obj.start_years),1);
        for i = 1:length(obj.start_years)
            in_year_range = obj.prices.year <= obj.start_years(i) & ...
                            obj.prices.year > ... 
                                (obj.start_years(i) - trailing_years);
            price = obj.prices.(source);
            trailing_price(i) = mean( price( in_year_range ) );
        end
    end
    
    function [ mu_s, sig_s ] = futurePriceParameters( obj, price_log_diff )
        % Estimate parameters of future price distribution 
        %   Use log price differences from one price series as input data
        
        num_auction_years = length(obj.start_years);
        mu_s              = zeros(30,num_auction_years);
        sig_s             = zeros(30,num_auction_years);
                     
        for i = 1:num_auction_years
            
            % Limit data to sample prior to given start year
            start_year        = obj.start_years(i);
            year              = obj.prices.year(13:end);
            % in_year_range = year < start_year & year >= start_year - 11;
            in_year_range     = year < start_year & year >= 1995;
            price_log_diff_yr = price_log_diff(in_year_range);

            % Calculate mean and standard deviation of log price difference
            exp_price_log_diff = mean(price_log_diff_yr);
            gp                 = exp(exp_price_log_diff) - 1;
            sige               = std( price_log_diff_yr - exp_price_log_diff );

            % Calculate parameters of log-normal distribution in each future year
            mu_s(:,i)  = (1+gp).^[1:30]';
            sig_s(:,i) = sige * sqrt([1:30]');
            
        end
        
    end
    
    function print( obj )
        for s = 1:length(obj.source)
            output = [ obj.start_years obj.trailing_price(:,s) ...
                       obj.exp_price(:,s) obj.variance_price(:,s) ];
            fprintf(1,'\nPrices for %s coal',obj.source{s});
            fprintf(1,'\n%4s\t%7s\t%7s\t%7s\n','Year','Price','EP','VP');
            for r = 1:size(output,1)
                fprintf(1,'%4.0f\t%7.2f\t%7.2f\t%7.2f\n',output(r,:));
            end
        end
    end
    
end

end % End class definition

% Helper functions
function [ price ] = get_date_nums( price )
    price.date = datenum(char(price.date),'mm/dd/yyyy');
end
  


