classdef scoreModel
    %scoreModel Model for marginal distribution of equilibrium scores
    %   Model for the distribution G(S|X,N) of levelised tariffs (scores)
    %   in power purchase agreement auctions. Initialize with dataset of
    %   bids on which to estimate the model
    
    properties
                    
        % Specification with distinct price effect by fuel type
%         mu_paramlist = {'constant','bidders','UMPP','coal_imported',...
%                         'coal_domestic','priceXcaptive','priceXnotcaptive'};
%         sig_paramlist = {'constant','bidders','UMPP','coal_imported',...
%                         'coal_domestic','priceXcaptive','priceXnotcaptive'};
        
%         mu_paramlist = {'constant','bidders_top','case2','UMPP',...
%                         'coal_notcaptive','priceXnotcaptive'};
%         sig_paramlist = {'constant','bidders_top'};
%         sig_paramlist = {'constant','bidders_top','case2','UMPP',...
%                         'coal_notcaptive','priceXnotcaptive'};
    
        % Specification in first draft, 9/2018
        mu_paramlist = {'constant','bidders','UMPP','coal_imported',...
                        'coal_domestic','price'};
        sig_paramlist = {'constant','bidders','UMPP','coal_imported',...
                        'coal_domestic','price'};

        default_startparam;
        
%         rowHeads = {'Constant',...
%                     'Number of bidders',...
%                     'Ultra-mega power plant (=1)',...
%                     'Coal imported (=1)',...
%                     'Coal domestic (=1)',...
%                     'Coal price (USD/ton) X captive',...
%                     'Coal price (USD/ton) X not captive'};          

        rowHeads = {'Constant',...
                    'Number of bidders',...
                    'Ultra-mega power plant (=1)',...
                    'Coal imported (=1)',...
                    'Coal domestic (=1)',...
                    'Coal price (USD/ton)'};                   

        % Currency in which price series is stored
        currency = 'inr';
                
        % Bootstrap samples of bids
        bids;     % Store bidding data in scoreModel
        B = 200;
        bi;       % N X B matrix giving row indices of bids drawn from bids

        % Estimates of the score distribution
        coefficients;
        covariance;
        ses; 
        maxLikelihood;
        N;
        mu_auction_pred;
        sig_auction_pred;
        k;               % Pseudo-type inferred by invertScores given dist.
        
        % Bootstrap estimates of the score distribution
        coefficients_b;
        ses_b; 
        maxLikelihood_b;
        N_b;
        mu_auction_pred_b;
        sig_auction_pred_b; 
        k_b; 
        
    end
    
    methods
        
        function obj = scoreModel( bids, mu_paramlist, sig_paramlist )
            % Initialize scoreModel object
            
            % Store bids data table as part of scoreModel object
            obj.bids = bids;
            obj.N = size(obj.bids,1);

            % Update parameter list if not using the default
            if nargin > 1
               obj.mu_paramlist = mu_paramlist;
               obj.sig_paramlist = sig_paramlist;
            end
            obj.default_startparam = zeros(length(obj.mu_paramlist) + ...
                                           length(obj.sig_paramlist),1);
        end
        
        function [ logL, G ] = likelihood( obj, param )
            
            S     = obj.bids.LevelisedTariff;
            
            % Extract design matrix of auction covariates
            X_mu  = [ ones(obj.N,1) table2array(obj.bids(:,obj.mu_paramlist(2:end))) ];
            X_sig = [ ones(obj.N,1) table2array(obj.bids(:,obj.sig_paramlist(2:end))) ];
            
            % Calculate mu_jt and sig_jt given design matrices and param
            Beta_mu  = param(1:length(obj.mu_paramlist));
            Beta_sig = param(length(obj.mu_paramlist)+1:end);
            
            mu_jt    = X_mu * Beta_mu;
            sig_jt   = exp( X_sig * Beta_sig );

            % Calculate log likelihood function
            logL = -1/2*sum(log(2*pi*sig_jt.^2)) - sum(log(S)) ...
                   -1/2*sum( (log(S)-mu_jt).^2 ./ sig_jt.^2 );
            logL = - logL; % Because we are minimizing, not maximizing
               
            if nargout > 1

                % Calculate gradient of log likelihood function 
                dlogLdmu      = log(S)./sig_jt.^2 - mu_jt./sig_jt.^2;
                k1            = length(Beta_mu);
                dlogLdBeta_mu = sum( dlogLdmu(:,ones(1,k1)) .* X_mu, 1);

                dlogLdsig = -1./sig_jt + log(S).^2./sig_jt.^3 ...
                            - 2*log(S).*mu_jt./sig_jt.^3 + mu_jt.^2./sig_jt.^3;
                k2        = length(Beta_sig);
                dlogLdBeta_sig = sum( dlogLdsig(:,ones(1,k2)) .* ...
                                      sig_jt(:,ones(1,k2)) .* X_sig, 1);

                G = [ dlogLdBeta_mu dlogLdBeta_sig ];    
                G = - G; % Because we are minimizing, not maximizing
                
            end
        end
        
        function obj = estimate( obj, display )
            % Estimate scoreModel by maximum likelihood
                           
            % Estimation options
            if nargin < 2
                display = 'iter';
            end
            options = optimoptions('fminunc','TolX',1e-12,'TolFun',1e-12,...
                                   'MaxIter',1e4,'MaxFunEvals',1e5,...
                                   'Display',display,...
                                   'GradObj','on',...
                                   'DerivativeCheck','off',...
                                   'FinDiffType','central');
            % FinDiffRelStep,1e-5
                               
            start_param = obj.default_startparam;
            
            loglikelihood = @( param ) obj.likelihood( param );
            [ obj.coefficients, minLikelihood, ~, ~, G, H ] = ...
                fminunc( loglikelihood, start_param, options );
            
            % Compute covariance
            %   Typical estimator is - 1/N H^{-1}. Here (a) we have no 1/N
            %   factor because we are using the sum of likelihoods rather
            %   than the mean (b) the problem is a minimization, not a
            %   maximization, so we want H rather than -H.
            obj.covariance    = full( inv( H ) );
            obj.ses           = sqrt( diag(obj.covariance) );
            obj.maxLikelihood = - minLikelihood;
            
            [ obj.mu_auction_pred, obj.sig_auction_pred ] = ...
                predict( obj );

        end
        
        function [ mu_jt, sig_jt ] = predict( obj )
            % Predict parameters of score distribution given observables
            
            S = obj.bids.LevelisedTariff;
            
            % Extract design matrix of auction covariates
            X_mu  = [ ones(obj.N,1) table2array(obj.bids(:,obj.mu_paramlist(2:end))) ];
            X_sig = [ ones(obj.N,1) table2array(obj.bids(:,obj.sig_paramlist(2:end))) ];
            
            % Calculate mu_jt and sig_jt given design matrices and param
            param    = obj.coefficients; % Retrieve estimated coefficients
            Beta_mu  = param(1:length(obj.mu_paramlist));
            Beta_sig = param(length(obj.mu_paramlist)+1:end);
            
            mu_jt  = X_mu * Beta_mu;
            sig_jt = exp( X_sig * Beta_sig );
            
        end
        
        function [ Sbar, dSbardX ] = marginalEffect( obj, N )
            % Calculate marginal effects of score distribution at vector X
            %   Automatically determine whether a variable is binary or not
            
            S = obj.bids.LevelisedTariff;
            
            % Extract design matrix of auction covariates
            X_mu  = [ ones(obj.N,1) table2array(obj.bids(:,obj.mu_paramlist(2:end))) ];
            X_sig = [ ones(obj.N,1) table2array(obj.bids(:,obj.sig_paramlist(2:end))) ];
            
            % Flag which variables are continuous and which are binary
            dummy = ~any(X_mu ~= 0 & X_mu ~= 1,1);
            
            % Generate X vector
            X         = zeros(size(dummy));
            X(~dummy) = mean(X_mu(:,~dummy),1);
            X(1)      = 1; % Constant
            X(2)      = N; % Number of bidders
            X(5)      = 1;
            
            % Calculate mu_jt and sig_jt given design matrices and param
            param    = obj.coefficients; % Retrieve estimated coefficients
            Beta_mu  = param(1:length(obj.mu_paramlist));
            Beta_sig = param(length(obj.mu_paramlist)+1:end);
            
            mu  = X * Beta_mu;
            sig = exp( X * Beta_sig );
            
            % Calculate marginal effects on the mean
            Sbar    = exp( mu + sig^2/2 );
            dSbardX = Sbar * ( Beta_mu + Beta_sig .* exp(2*X'.*Beta_sig) );
            dSbardX(1)     = NaN;
            dSbardX(dummy) = NaN;
            
            % Calculate discrete analog of marginal effect for dummies
            %   Notice that fuel source categories are mutually exclusive
            %   so marginal effects do not make sense there
            dummyIndices = find(dummy & X==0);
            for i = 1:length(dummyIndices)
                Xtemp = X;
                Xtemp( dummyIndices(i) ) = 1;
                mu_temp   = Xtemp * Beta_mu;
                sig_temp  = exp( Xtemp * Beta_sig ); 
                Sbar_temp = exp( mu_temp + sig_temp^2/2 ); 
                dSbardX( dummyIndices(i) ) = Sbar_temp - Sbar;
            end
            
        end
        
        
        function obj = invertScores( obj )
            % Invert score distribution to recover pseudo-types
            %        k(theta) =    1/  (1 - G(S|N,X))/  -  S
            %                    (N-1)    g(S|N)          
            S   = obj.bids.LevelisedTariff;
            mu  = obj.mu_auction_pred;
            sig = obj.sig_auction_pred;
            B   = obj.bids.bidders; % Use B instead of N
            W   = obj.bids.winners; % Number of winners in auction
            
            GS = logncdf(S,mu,sig);
            gS = lognpdf(S,mu,sig);
            
            obj.k = 1./(B-W) .* (1-GS)./gS - S;
        end
        
        function [ obj ] = sampleBids( obj, method )
            % Resample from bids and return indices of bids sampled in each b
        
            % Set random number stream
            s = RandStream('mt19937ar','Seed',20180925);
        
            % Bids to consider for sampling
            i = [1:size(obj.bids,1)]';
            i = i( ~isnan(obj.k), : );     % Must have pseudo-type
            withtype = ~isnan(obj.bids.frac_indexed);
                        
            % Bootstrap bid indices by one of two methods: simple or block
            NB     = length(i);
            obj.bi = zeros(NB,obj.B);
            switch method
                % Simple random sampling
                case 'simple' 

                    for b = 1:obj.B
                        obj.bi(:,b) = datasample(s,i,NB);
                    end
                    
                % Block bootstrap at year X source X type available level
                case 'block' 
                    
                    obj.bids.block = 100*obj.bids.auction_year + ...
                                     10*obj.bids.source + ...
                                     withtype;
                    [ blocks, ~, kc ] = unique(obj.bids.block);
                    Nb = accumarray(kc,ones(size(kc)));
                    
                    for k = 1:length(blocks)
                        inblock = obj.bids.block == blocks(k);
                        for b = 1:obj.B
                            obj.bi(inblock,b) = ...
                                datasample(s,i(inblock),Nb(k));
                        end
                    end
            end
            
        end
        
        function [ obj ] = bootstrap( obj )
           % Bootstrap estimates of the scoreModel
           
           bids_static            = obj.bids;
           
           obj.coefficients_b     = zeros([size(obj.coefficients,1) obj.B]);
           obj.ses_b              = zeros([size(obj.ses,1) obj.B]); 
           obj.maxLikelihood_b    = zeros([size(obj.maxLikelihood,1) obj.B]);
           obj.N_b                = zeros([size(obj.N,1) obj.B]);
           obj.mu_auction_pred_b  = zeros([size(obj.mu_auction_pred,1) obj.B]);
           obj.sig_auction_pred_b = zeros([size(obj.sig_auction_pred,1) obj.B]); 
           obj.k_b                = zeros([size(obj.k,1) obj.B]); 
           
           fprintf(1,'Score model estimation - bootstrap iteration: \n');
           for b = 1:obj.B
               
               fprintf(1,'\t%4.0f',b);
               if mod(b,10) == 0
                   fprintf(1,'\n');
               end
              
               % Select bids to be used on this iteration
               obj.bids = bids_static( obj.bi(:,b), : );
               
               % Estimate the scoremodel
               scoreDist = obj.estimate( 'none' );

               % Invert the score distribution for pseudo-types
               scoreDist = scoreDist.invertScores( );

               % Assign estimation output from each iteration to scoreModel
               obj.coefficients_b(:,b)     = scoreDist.coefficients;
               obj.ses_b(:,b)              = scoreDist.ses; 
               obj.maxLikelihood_b(:,b)    = scoreDist.maxLikelihood;
               obj.N_b(:,b)                = scoreDist.N;
               obj.mu_auction_pred_b(:,b)  = scoreDist.mu_auction_pred;
               obj.sig_auction_pred_b(:,b) = scoreDist.sig_auction_pred; 
               obj.k_b(:,b)                = scoreDist.k; 
               
           end
           
           obj.bids = bids_static;
            
        end
        
        [ ] = plotScoreDistribution( obj, bids, write );
        
        [ ] = plotScoreResiduals( obj, bids, write );
        
        [ ] = tabulate( obj, file );
    
    end
    
end


