function [ ] = tabulate( obj, file )
% Print table of coefficient estimates for score distribution
%   obj : scoreModel object with coefficient estimates

%% Prepare data 

% Calculate size of parameter table
columns  = 2;
rows     = length(obj.mu_paramlist);
colHeads = {'','$\mu_{jt}$','$\log \sigma_{jt}$'};

% Create matrices of parameter estimates and standard errors
% Nobs  = zeros(1,columns);
% logL  = zeros(1,columns);
fill    = 2*rows - length(obj.coefficients);

theta = [ obj.coefficients(1:rows) ...
        [ obj.coefficients(rows+1:end); NaN(fill,1) ] ];
se    = [ obj.ses(1:rows) ...
        [ obj.ses(rows+1:end); NaN(fill,1) ] ];

% Adjust currency if stored in INR / ton to USD / ton
if strcmp(obj.currency,'inr')
   theta(end,:) = theta(end,:) * 60;
   se(end,:) = se(end,:) * 60;
end
    
theta = num2cell(theta);
se    = num2cell(se);
for i = 1:numel(theta)
    if isnan(theta{i})
        theta{i} = '';
        se{i} = '';
    end
end
      
% Adjust ordering of data and standard errors
% roworder = [ 7 1 2 3 4 5 6 8 9 ];
% theta    = theta(roworder,:);
% se       = se(roworder,:);
% rowHeadExtra = {'$\times$ Coal price'};
        
% Adjust format with latex separators
format = ['%15s',repmat('\t%.3f',1,columns)];
format = regexprep(format,'\\t','&');

seformat = ['%15s',repmat('\t(%.4f)',1,columns)];
seformat = regexprep(seformat,'\\t','&');

seformat2 = ['%15s','\t(%.4f)\t%.4f'];
seformat2 = regexprep(seformat2,'\\t','&');

% Title of table
title = 'Estimates of equilibrium score distribution';

%% Print table to file
fid = fopen( file, 'w' );

% Front matter
fprintf(fid,'\\begin{table}[!ht]\n\t\\centering\n\t');
fprintf(fid,'\t\\caption{%s}\n',title);
fprintf(fid,'\\begin{tabular}{%s}\n',['l',repmat('r',1,columns)]);

% Title of table
fprintf(fid,'\t\t\\toprule\n');

% Column headings
cformat = regexp(regexprep(format,'\.\df','s'),'&','split')';
for c = 1:columns+1
    fprintf(fid,cformat{c},colHeads{c});
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end

for c = 1:columns+1
    if c > 1
        fprintf(fid,'\\multicolumn{1}{c}{(%1.0f)}',c-1);
    end
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end
fprintf(fid,'\t\t\\midrule\n');

% Data rows with row headings
for r = 1:rows
    fprintf(fid,['\t\t',format,'\\\\\n'],obj.rowHeads{r},theta{r,:});
    if r <= (rows-fill)
        fprintf(fid,['\t\t',seformat,'\\\\\n'],' ',se{r,:});        
    else
        fprintf(fid,[seformat2,'\\\\\n'],' ',se{r,:});
    end
    fprintf(fid,['\t\t \\addlinespace \n']);
end

%  Footer rows with statistics of interest
foot3format = ['%15s\t\\multicolumn{2}{c}{%3.0f}'];
foot3format = regexprep(foot3format,'\\t','&');
fprintf(fid,['\t\t',foot3format,'\\\\\n'],'N',obj.N);

foot4format = ['%15s\t\\multicolumn{2}{c}{%5.2f}'];
foot4format = regexprep(foot4format,'\\t','&');
fprintf(fid,['\t\t',foot4format,'\\\\\n'],'$\log \mathcal{L}$',obj.maxLikelihood);

% End matter
fprintf(fid,'\t\t\\bottomrule\n');
fprintf(fid,['\\multicolumn{%1.0f}{p{%2.1f\\hsize}}{\\footnotesize The table ' ...
        'provides estimates of the parameters of the marginal distribution ' ...
        'of equilibrium bid scores. The first column gives coefficients on ' ...
        'variables affecting the mean score for auction $j$ in time $t$ and ' ...
        'the second column coefficients on variables changing the variance. ' ...
        'Number of bidders is the maximum of the number of bidders in an ' ...
        'auction and six. An asset-specific project is a project where land ' ...
        'or coal is given to the winning bidder. Ultra-mega power plant is a ' ...
        'large projects of nearly 4,000 MW capacity for which the ' ...
        'Central government ran procurement. Coal source not captive refers ' ...
        'to projects using domestic or imported sources of coal and therefore ' ...
        'exposed to coal price fluctuations. The coal price is the 5-year ' ...
        'trailing average of the Newcastle (imported) coal price as of the ' ...
        'year prior to bidding in the auction. ' ...
        'Estimates are by maximum likelihood with standard errors in ' ...
        'parentheses.'],...
        columns+1,0.5 + 0.2*(columns > 4));
fprintf(fid,'} \\\\\n');
fprintf(fid,'\t\\end{tabular}\n');
fprintf(fid,'\\end{table}\n');

fclose(fid);
fprintf(1,'Printed: %s\n',file);

end               
                
