function [ ] = plot1d( obj, file )
%plot Plot 1-D type distribution for heat rate from type model object
%   
% INPUT :
%  obj         type model object with estimates of types
%
% OUTPUT :
%              Writes plot to file
if nargin < 2
    file = 0;
end

%% Formatting options
textProp = {'fontsize'    , 24, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 18, ...
            'FontName'    , textProp{4}};
        
%% Data to plot
theta = [ obj.bids.h obj.bids.Delta ];
theta = theta( ~isnan(theta(:,1)), : )';

%% Kernel density estimation on a grid

% Bandwidth
h_h = 1000;
% h_h = 750;

% Evaluate cdf and pdf of heat rate
h_range = [ 1000:100:25000 ]';
[ Fh, fh ] = obj.smoothHeatCdf( h_range, h_h );
       
%% Plot PDF first
plot(h_range,fh,'k-' ,'LineWidth',2);  
hold on;

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Heat rate $h_i$ (btu/kWh)',textProp{:},'Interpreter','latex')
ylabel('Probability density',textProp{:},'Interpreter','latex')
hold off;

%% Export figure to file
if file
    file_pdf = strrep(file,'.pdf','_pdf.pdf');
    fprintf(1,'Writing %s to file ...',file_pdf);
    export_fig(file_pdf,'-painters','-m2');
    fprintf(1,' complete.\n');
end
% keyboard;
% clf;

%% Plot CDF
plot(h_range,Fh,'k-' ,'LineWidth',2);  
hold on;

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Heat rate $h_i$ (btu/kWh)',textProp{:},'Interpreter','latex')
ylabel('Cumulative probability',textProp{:},'Interpreter','latex')

% % Add engineering estimates from:
% %   Cropper, Maureen; Shama Gamkhar, Kabir Malik, Alex Limonov and Ian
% %   Partridge, `The Health Effcets of Coal Electricity Generation in India'
% %   RFF discussion paper 12-25, June 2012.
% op_heat_rate_p05 = 2302;
op_heat_rate_p50 = 2751;
% op_heat_rate_p95 = 3495;
btu_per_kcal     = 3.96567;
% op_heat_rate_p05 = op_heat_rate_p05 * btu_per_kcal; 
% op_heat_rate_p95 = op_heat_rate_p95 * btu_per_kcal;
op_heat_rate_p50 = op_heat_rate_p50 * btu_per_kcal;

yl = ylim;
% x05 = [ op_heat_rate_p05 op_heat_rate_p05 ];
x50 = [ op_heat_rate_p50 op_heat_rate_p50 ];
% x95 = [ op_heat_rate_p95 op_heat_rate_p95 ];
% line(x05,yl,'Color','red','LineWidth',1,'LineStyle','--');
line(x50,yl,'Color','red','LineWidth',1,'LineStyle','--');
% line(x95,yl,'Color','red','LineWidth',1,'LineStyle','--');

% text(x05(1)-500,yl(2)-0.05,'Engineering 5th-percentile','HorizontalAlignment','right');
text(x50(1)-500,yl(2)-0.05,'Engineering 50th-percentile','HorizontalAlignment','right');
% text(x95(1)-500,yl(2)-0.05,'Engineering 95th-percentile','HorizontalAlignment','right');


hold off;

%% Export figure to file
if file
    file_cdf = strrep(file,'.pdf','_cdf_wmedian.pdf');
    fprintf(1,'Writing %s to file ...',file_cdf);
    export_fig(file_cdf,'-painters','-m2');
    fprintf(1,' complete.\n');
end
% keyboard;

end
