function [ ] = tabulateBoots( obj, file )
% Table of both equilibrium and counterfactual bids and mark-ups under 
%   strict contract enforcement. Outcomes bootstrapped for both estimates
%   and counterfactuals.
%
%   obj : typeModel object with pseudo-type and type estimates as well as
%         counterfactual bids
%           Equilibrium outcomes in obj.boot_eq
%           Counterfactual outcomes in obj.boot_cf
%         These matrices are size N X 9 X B where columns 1-9 contain:
%           (1) h
%           (2) Delta
%           (3) Value of renegotiation ER*Delta
%           (4) Cost of supply
%           (5) Adjusted score / counterfactual bid
%           (6) Margin of bid over cost
%           (7) Pseudo-type 
%           (8) Margin of bid over pseudo-type
%           (9) Whether bid won
%   file : file to which to print the table


%% Prepare data 

% Change sign of pseudo-type to interpret as cost-like
obj.boot_eq(:,7,:) = - obj.boot_eq(:,7,:);
obj.boot_cf(:,7,:) = - obj.boot_cf(:,7,:);

% Variable names and statistics to calculate
var_cols = [ 5 7 8 4 6 2 3 ];
rowHeads = {'Bid (INR/kWh)', ...
            'Pseudo-type (INR/kWh)', ...
            '~~~~Margin over pseudotype (\%)', ...
            'Cost of supply (INR/kWh)', ...
            '~~~~Margin over cost (\%)',...
            'Bonus $\Delta$ (INR/kWh)',...
            'Value of renegotiation (INR/kWh)'};
       
% Calculate means and means conditional on a bid winning
table_data = zeros(length(var_cols),6,2); 
boot_means = zeros(obj.B,length(var_cols),6); % B X V X Sample
for b = 1:obj.B
    
    % Flag and exclude negative pseudo-types
    negative_pseudotype = obj.boot_eq(:,7,b) < 0.5;
    boot_eq_b           = obj.boot_eq(~negative_pseudotype,:,b);
    boot_cf_b           = obj.boot_cf(~negative_pseudotype,:,b);
    with_type           = ~isnan(boot_eq_b(:,1)); % heat rate present

    % Flag winners
    winner_eq = boot_eq_b(:,9) == 1;
    winner_cf = boot_cf_b(:,9) == 1;
    
    % Equilibrium
    
    % Full sample, all bids
    boot_means(b,:,1) = mean( boot_eq_b(:,var_cols), 1 );

    % Full sample, winning bids
    boot_means(b,:,2) = mean( boot_eq_b(winner_eq,var_cols), 1 );

    % Sample with type, all bids
    boot_means(b,:,3) = mean( boot_eq_b(with_type,var_cols), 1 );

    % Sample with type, winning bids
    boot_means(b,:,4) = mean( boot_eq_b(with_type & winner_eq,var_cols), 1 );

    % Counterfactual 
    
    % Sample with type, all bids
    boot_means(b,:,5) = mean( boot_cf_b(with_type,var_cols), 1 );
   
    % Sample with type, winning bids
    boot_means(b,:,6) = mean( boot_cf_b(with_type & winner_cf,var_cols), 1 );
    
    % hist( boot_eq_b(with_type & winner_eq,8), [-100:10:200] );
    % fprintf(1,'Bootstrap iteration: %4.0f\n',b);
    
end

table_data(:,:,1) = permute( mean(boot_means,1), [ 2 3 1 ] ) ;
table_data(:,:,2) = permute( std(boot_means,[],1), [ 2 3 1 ] ) ;
          
%% Prepare table formatting

% Title of table
title = 'Equilibrium and Counterfactual Bids, Costs and Mark-ups';

% Calculate size of parameter table
columns  = size(table_data,2);
rows     = length(var_cols);
colHeads = {'\emph{Bids}: ','\multicolumn{1}{c}{All}',...
    '\multicolumn{1}{c}{Winning}','\multicolumn{1}{c}{All}',...
    '\multicolumn{1}{c}{Winning}','\multicolumn{1}{c}{All}',...
    '\multicolumn{1}{c}{Winning}'};
      
% Adjust format with latex separators
format = ['%15s',repmat('\t%4.2f',1,columns)];
format = regexprep(format,'\\t','&');

seformat = ['%15s',repmat('\t(%.2f)',1,columns)];
seformat = regexprep(seformat,'\\t','&');

%% Print table to file
fid = fopen( file, 'w' );

% Front matter
fprintf(fid,'\\begin{table}[!ht]\n\t\\centering\n\t');
fprintf(fid,'\t\\caption{%s}\n',title);
fprintf(fid,'\\begin{tabular}{%s}\n',['l',repmat('R{1.5cm}',1,columns)]);

% Title of table
fprintf(fid,'\t\t\\toprule\n');

% Meta headings
fprintf(fid,[' & \\multicolumn{4}{c}{Equilibrium}', ...
             '& \\multicolumn{2}{c}{Counterfactual} \\\\\n']);
fprintf(fid,['\\cmidrule(lr){2-5} \\cmidrule(lr){6-7} \n']);
fprintf(fid,['\\emph{Sample}: & \\multicolumn{2}{c}{With bid}', ...
             '& \\multicolumn{2}{c}{With type}', ...
             '& \\multicolumn{2}{c}{With type} \\\\\n']);
fprintf(fid,'\\cmidrule(lr){2-3} \\cmidrule(lr){4-5} \\cmidrule(lr){6-7} \n');

% Column headings
cformat = regexp(regexprep(format,'\.\df','s'),'&','split')';
for c = 1:columns+1
    fprintf(fid,cformat{c},colHeads{c});
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end

for c = 1:columns+1
    if c > 1
        fprintf(fid,'\\multicolumn{1}{c}{(%1.0f)}',c-1);
    end
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end
fprintf(fid,'\t\t\\midrule\n');

% Data rows with row headings
for r = 1:rows
    fprintf(fid,['\t\t',format,'\\\\\n'],rowHeads{r},table_data(r,:,1));
    fprintf(fid,['\t\t',seformat,'\\\\\n'],' ',table_data(r,:,2));
    fprintf(fid,['\t\t \\addlinespace \n']);
end

%  Footer rows with statistics of interest
% foot3format = ['%15s\t\\multicolumn{2}{c}{%3.0f}'];
% foot3format = regexprep(foot3format,'\\t','&');
% fprintf(fid,['\t\t',foot3format,'\\\\\n'],'N',obj.N);

% End matter
fprintf(fid,'\t\t\\bottomrule\n');
fprintf(fid,['\\multicolumn{%1.0f}{p{%2.1f\\hsize}}{\\footnotesize ' ...
        'The table presents both the equilibrium estimates and the ' ...
        'counterfactual results in parallel. The first four columns ' ...
        'show estimates describing the current equilibrium bidding. ' ...
        'The last two columns show counterfactual simulations. The ' ...
        'statistics in the table are reported for two samples. The ' ...
        'first pair of columns applies to the entire sample with bids, ' ...
        'i.e.~equilibrium scores. The second and third pairs of ' ...
        'columns, columns three through six, apply to only bids that ' ...
        'have their component parts, such as the indexed energy charge, ' ...
        'in the data set. Within each pair of columns, the first column ' ...
        'reports the mean for all bids and the second the mean for ' ...
        'winning bids only. Each column of the table then reports the ' ...
        'means of several bidder-level variables. These are the ' ...
        'equilibrium or counter-factual bid; the pseudo-type; the ' ...
        'margin of the bid over the pseudo-type; the cost of supply, ' ...
        'using the estimated heat rate and the coal price applicable to ' ...
        'each auction; the margin over cost; the estimated bidder bonus ' ...
        '$\\Delta_i$; and finally the value of renegotiation, which is ' ...
        'equal to the bonus times the expected discounted number of ' ...
        'times renegotiation will occur evaluated at the time of ' ...
        'bidding. I block bootstrap equilibrium outcomes and ' ...
        'counterfactual outcomes by redrawing bidders within clusters ' ...
        'of bidding year, fuel source, and data availability ' ...
        '(i.e., whether a bid as component parts or not). Standard ' ...
        'errors across 200 bootstrap samples are reported in parentheses.'],...
        columns+1,1.0);
fprintf(fid,'} \\\\\n');
fprintf(fid,'\t\\end{tabular}\n');
fprintf(fid,'\\end{table}\n');

fclose(fid);
fprintf(1,'Printed: %s\n',file);

end               
                
