function [ ] = tabulateCounterfactual( obj, sample, file )
% Table of counterfactual bids and mark-ups under strict contract
%   enforcement
%   obj : typeModel object with pseudo-type and type estimates as well as
%         counterfactual bids
%   sample : whether to use sample of all bids or only those with types
%   file : file to which to print the table


%% Prepare data 

% Restrict sample for table
switch sample
    case 'all'
        keep = obj.bids.k < 0;
    case 'type'
        keep = ~ isnan(obj.bids.h) & obj.bids.k < 0;
end
flag = ~keep;
display(obj.bids.bid_id_provisional(flag));
obj.bids = obj.bids(keep,:);

% Change sign of pseudo-type
obj.bids.k = - obj.bids.k;

% Calculate margins
obj.bids.cost_variable = obj.bids.h.*obj.bids.EP;
obj.bids.cost_total    = obj.bids.h.*obj.bids.EP + obj.bids.F + obj.bids.T;
obj.bids.margin_pseudo = 100*(obj.bids.cf_b - obj.bids.k) ./ ...
                         obj.bids.k;
obj.bids.margin_cost   = 100*(obj.bids.cf_b - obj.bids.cost_total) ./ ...
                         obj.bids.cost_total;
obj.bids.reneg_value   = obj.bids.ER .* obj.bids.Delta;

% Variable names and statistics to calculate
table_vars = {'cf_b','k','margin_pseudo','cost_total',...
              'margin_cost','reneg_value'};
rowHeads = {'Bid (INR/kWh)', ...
            'Pseudo-type (INR/kWh)', ...
            'Margin over pseudotype (\%)', ...
            'Cost of supply (INR/kWh)', ...
            'Margin over cost (\%)',...
            'Value of renegotiation (INR/kWh)'};
        
% Calculate means and means conditional on a bid winning
table_data         = zeros(length(table_vars),2); % For all bids
table_data_winners = zeros(size(table_data));     % Winning bids only
for i = 1:length(table_vars)
    spec = [table_vars{i}, ' ~ 1'];
    
    % All bids
    lm   = fitlm(obj.bids,spec);
    table_data(i,1) = lm.Coefficients.Estimate;
    table_data(i,2) = lm.Coefficients.SE;
       
    % Winning bids only
    lm   = fitlm(obj.bids(obj.bids.cf_winner==1,:),spec);
    table_data_winners(i,1) = lm.Coefficients.Estimate;
    table_data_winners(i,2) = lm.Coefficients.SE;
end

          
%% Prepare table formatting

% Title of table
title = 'Estimates of counterfactual mark-ups';

% Calculate size of parameter table
columns  = 2;
rows     = length(table_vars);
colHeads = {'','All bids','Winning bids'};
      
% Adjust format with latex separators
format = ['%15s',repmat('\t%4.2f',1,columns)];
format = regexprep(format,'\\t','&');

seformat = ['%15s',repmat('\t(%.2f)',1,columns)];
seformat = regexprep(seformat,'\\t','&');


%% Print table to file
fid = fopen( file, 'w' );

% Front matter
fprintf(fid,'\\begin{table}[!ht]\n\t\\centering\n\t');
fprintf(fid,'\t\\caption{%s}\n',title);
fprintf(fid,'\\begin{tabular}{%s}\n',['l',repmat('r',1,columns)]);

% Title of table
fprintf(fid,'\t\t\\toprule\n');

% Column headings
cformat = regexp(regexprep(format,'\.\df','s'),'&','split')';
for c = 1:columns+1
    fprintf(fid,cformat{c},colHeads{c});
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end
fprintf(fid,'\t\t\\midrule\n');

% Data rows with row headings
for r = 1:rows
    fprintf(fid,['\t\t',format,'\\\\\n'],rowHeads{r},table_data(r,1),...
        table_data_winners(r,1));
    fprintf(fid,['\t\t',seformat,'\\\\\n'],' ',table_data(r,2),...
        table_data_winners(r,2));
    fprintf(fid,['\t\t \\addlinespace \n']);
end

%  Footer rows with statistics of interest
% foot3format = ['%15s\t\\multicolumn{2}{c}{%3.0f}'];
% foot3format = regexprep(foot3format,'\\t','&');
% fprintf(fid,['\t\t',foot3format,'\\\\\n'],'N',obj.N);

% End matter
fprintf(fid,'\t\t\\bottomrule\n');
fprintf(fid,['\\multicolumn{%1.0f}{p{%2.1f\\hsize}}{\\footnotesize ' ...
        'The table '],...
        columns+1,0.5);
fprintf(fid,'} \\\\\n');
fprintf(fid,'\t\\end{tabular}\n');
fprintf(fid,'\\end{table}\n');

fclose(fid);
fprintf(1,'Printed: %s\n',file);

end               
                
