classdef typeModel
    %typeModel Model for joint distribution of types
    %   Model for the distribution F(theta) where theta = {h,Delta} are 
    %   bidder types in power purchase agreement auctions. Initialize with 
    %   pseudo-types, dataset of bid characteristics.
    
    properties
    
        % Data table with bid characteristics
        bids;          % Data table that may be altered in bootstrap
        bids_original; % Data table in original ordering
        
        % Bid variables to keep for typeModel
        vars = {'auction_id_provisional','bid_id_provisional',...
                'case2','coal_notcaptive','UMPP','auction_year',...
                'source','LevelisedTariff','winner','winners',...
                'bidders','clean','Notes','transmission_charge','case2'}; 
        bidObjs; % Container map of bidData objects
        
        % Auction characteristics that will remain fixed for an
        %   auction across bootstrap iterations
        auction_variables = {'auction_id_provisional',...
            'auction_year','winners','bidders'};

        % Bidder characteristics that will be drawn on each iteration
        bidder_variables = {'bid_id_provisional','LevelisedTariff',...
            'transmission_charge','case2','h','Delta','objval','c','ER',...
            'F','T','EP','clean','Notes','exp_price','variance_price',...
            'cur_price','k','mu_auction_pred','sig_auction_pred'};
        
        % Calibrated parameters
        eta =  1.0;
%         eta = 0.75;
        V0  =  0.30;    % How much INR/kWh in variable profits can be lost
                        %   without inducing negotiation

        % Bootstrap indices of bids from scoremodel
        B;        % Number of bootstrap iterations
        bi;       % N X B matrix giving row indices of bids drawn from obj.bids
                  %   Inherited from scoreModel object, which does sampling
                  
        % Storage for bootstrap outcomes in equilibrium and counterfactual
        boot_eq;  % N X 9 X B matrix of bootstrapped equilibrium outcomes
                  % Columns defined in counterfactualBoot method below
        boot_cf;  % N X 9 X B matrix of bootstrapped counterfactual outcomes
        
        % Bandwidth for smoothing of type distribution
        h_bandwidth = 1000;
        
        % Whether to display output
        noisy = 1;
         
    end
    
    methods
        
        function obj = typeModel( scoreModel, coalData, esc_factors )
            % Keep only needed components of bid object, including the
            % pseudo-type that will be the basis of identifying types
            obj.bids = scoreModel.bids(:,obj.vars);
            obj.bi   = scoreModel.bi(); % Limit bootstrap replications
            obj.B    = size(obj.bi,2);
            
            % Add bid characteristics from scoreModel object
            obj.bids.k                = scoreModel.k;
            obj.bids.mu_auction_pred  = scoreModel.mu_auction_pred;
            obj.bids.sig_auction_pred = scoreModel.sig_auction_pred;
            
            % Add price expectations and variance from coalData object
            year_index     = obj.bids.auction_year - 2005;
            % source_index   = ones(size(obj.bids.source));
            source_index   = obj.bids.source;
            price_index    = year_index + ...
                size(coalData.trailing_price,1)*(source_index-1);
            
            obj.bids.cur_price      = coalData.trailing_price(price_index);
            obj.bids.exp_price      = coalData.exp_price(price_index);
            obj.bids.variance_price = coalData.variance_price(price_index);
            
            % Initialize container map of bid objects
            obj.bidObjs = containers.Map('KeyType','char','ValueType','any');
            obj = obj.addAllBids( esc_factors );
            
            % Initialize type and counterfactual outcomes
            Nbids              = size(obj.bids,1);
            obj.bids.EP        = nan(Nbids,1); % Expected price of heat
            obj.bids.h         = nan(Nbids,1); % Heat rate (btu/kWh)
            obj.bids.Delta     = nan(Nbids,1); % Bonus
            obj.bids.objval    = nan(Nbids,1); % Objective function value
            obj.bids.F         = nan(Nbids,1); % Fixed cost
            obj.bids.T         = nan(Nbids,1); % Transportation cost
            obj.bids.c         = nan(Nbids,1); % Average cost (INR/kWh)
            obj.bids.ER        = nan(Nbids,1); % Expected value of renegotiation
            obj.bids.cf_b      = nan(Nbids,1); % Counterfactual bid (INR/kWh)
            obj.bids.cf_winner = nan(Nbids,1); % Counterfactual win (=1)
        end
        
        function obj = addAllBids( obj, esc_factors )
            % Add all bids from all auctions to typeModel object
           auction_ids = unique(obj.bids.auction_id_provisional(obj.bids.clean,:));
           for j = 1:length(auction_ids)
               auction  = auctionData( auction_ids{j}, ...
                               obj.bids(obj.bids.clean,:), esc_factors );
               obj = obj.addBidsFromAuction( auction );
           end            
        end
               
        function obj = addBidsFromAuction( obj, auction )
            % Add one auction worth of bids to typeModel object
            Nbids = length(auction.bid_ids);
            for b = 1:Nbids
                fprintf(1,'Adding bid to type model object: %10s\n',...
                    auction.bid_ids{b});
                id  = auction.bid_keys{b};
                obj = addBid( obj, auction.bids.(id) );
            end
        end
        
        function obj = addBid( obj, bidData )
            % Add one bid to a typeModel object
            obj.bidObjs(bidData.bid_id) = bidData;           
        end
        
        function obj = estimate( obj, coalData )
           % Estimate types of bidders in all auctions
           auction_ids = unique(obj.bids.auction_id_provisional(obj.bids.clean,:));
           for j = 1:length(auction_ids)
               obj = obj.solveAuction( auction_ids{j}, coalData );
           end            
        end
               
        function obj = solveAuction( obj, auction_id, coalData )
            % Solve types for all bids in an auction
            bids_in_auction = find(strcmp(obj.bids.auction_id_provisional,auction_id));
            bid_ids         = obj.bids.bid_id_provisional(bids_in_auction);
            for i = 1:length(bid_ids)
                % Solve type for those bids in the auction that have an
                %   available bidData object, hence bid components
                bidAvailable = isKey( obj.bidObjs, bid_ids{i} );
                if bidAvailable
                    bidRow = bids_in_auction(i);
                    obj    = solveBid( obj, bid_ids{i}, bidRow, coalData );
                end
            end
            if obj.noisy
                obj.printAuctionTypes( auction_id )
            end
        end
        
        function obj = solveBid( obj, bid_id, bidRow, coalData )
           % Solve the system consisting of pseudo-type and indexation 
           %   decision to recover the underlying type
           if obj.noisy
               fprintf(1,'Solving type for bid: %10s\n',bid_id);
           end
                     
           % Bid data object for bid to be solved
           bidData = obj.bidObjs(bid_id); 
           
           % Discount factors in scoring
           r  = bidData.esc_factors.interest_rate;    % Discount rate
           rp = bidData.esc_factors.esc_rate_energy;  % Energy price growth
           t0 = bidData.esc_factors.years_till_start; % Time to build
           
           % Retrieve variables needed to specify system of equations
           EP = obj.bids.exp_price(bidRow);      % Expected present coal price
           VP = obj.bids.variance_price(bidRow); % Variance of present coal price 
            
           % Scored present coal price at time of auction (price of heat)
           %   Using constant calorific value here.  Should probably use a
           %   different (lower) calorific value for domestic coal
           switch coalData.currency
               case 'usd'
                   usd_per_btu = obj.bids.cur_price(bidRow) * ...    % USD per ton
                                 1/1000 * 1/6000 * 1/3.96567;        % Heat units
                   p0_inr_per_btu = usd_per_btu * ...
                                    bidData.esc_factors.inr_per_usd; % Currency
               case 'inr'
                   p0_inr_per_btu = obj.bids.cur_price(bidRow) * ... % INR per ton
                                    1/1000 * 1/6000 * 1/3.96567;     % Heat units
           end
                        
           % Put expected present prices in correct units
           EP = EP            * p0_inr_per_btu;
           VP = VP            * p0_inr_per_btu^2;
           P0 = bidData.Pdisc * p0_inr_per_btu;
           
           % Non-energy costs to be deducted from bid
           k = obj.bids.k(bidRow);               % Pseudo-type 
           years_from_2005 = obj.bids.auction_year(bidRow) - 2005;
           F = 0.80 * 1.05^(years_from_2005-1); % Fixed cost INR / kWh expected present value
           T = bidData.charges.transport;       % Transport cost INR/kWh exp. present value
           M = 0;                               % Transmission cost (case 1 only; where available)
           if ~bidData.transmission_included && ~obj.bids.case2(bidRow)
               if ~isnan( obj.bids.transmission_charge(bidRow) )
                   M = obj.bids.transmission_charge(bidRow);
               end
           end
           FT = F + T + M; % Sum of non-energy costs

           % Parameters of future coal price distributions, used in
           %   calculating the likelihood of renegotiation
           mu_t  = coalData.mu_t(:,years_from_2005) + log(p0_inr_per_btu);
           sig_t = coalData.sig_t(:,years_from_2005);
           
           % Components of bid, where parts matrix is of dimension
           % [T X {capacity, escalable energy, non-escalable energy}]
           beta_h = bidData.parts_int(1,3) * 1/p0_inr_per_btu; % Scalar escalable
           beta_e = bidData.parts_int(:,2); % Vector non-escalable energy

           % Search for theta = {h,Delta} that minimizes objectve
           theta0 = [ 10000; 1 ]; % h0 (btu/kWh); Delta0 (INR/kWh)
           epsilon = theta0(1) * 1e-2;
           options = optimoptions('fmincon','TolX',1e-12,'TolFun',1e-14,...
                                   'MaxIter',1e4,'MaxFunEvals',1e5,...
                                   'Display','none');
           thetaObj = @( theta ) objective( theta, k, FT, beta_h, beta_e, EP, P0, ...
                                       obj.eta, VP, mu_t, sig_t, obj.V0, ...
                                       bidData.delta, bidData.Tdisc );
           A = [ -1  0; 0 -1; 0  1 ];
           B = [ -(beta_h + epsilon);   % - (Minimum h)
                 -1e-3;                 % - (Minimum Delta)
                 5 ];                   %    Maximum Delta
           [ theta, fval ] = ...
                fmincon( thetaObj, theta0, A, B, [],[],[],[],[],options); 
           [ ER, ~ ] = expectedRenegotiation( theta(1), mu_t, sig_t, ...
                        obj.V0, beta_e, beta_h, bidData.delta, bidData.Tdisc );
            
           obj.bids.EP(bidRow)     = EP;
           obj.bids.h(bidRow)      = theta(1);
           obj.bids.Delta(bidRow)  = theta(2);
           obj.bids.objval(bidRow) = fval;
           obj.bids.F(bidRow)      = F;
           obj.bids.T(bidRow)      = T;
           obj.bids.c(bidRow)      = theta(1) .* EP + F + T;
           obj.bids.ER(bidRow)     = ER;
  
        end
        
        function printAuctionTypes( obj, auction_id )
            bids_in_auction = strcmp(obj.bids.auction_id_provisional,auction_id);
            output = [ obj.bids.h(bids_in_auction) obj.bids.Delta(bids_in_auction) ];
            format = '%15s:\t\t%6.0f (btu/kWh)\t%4.3f (INR/kWh)\n';
            bid_ids = obj.bids.bid_id_provisional(bids_in_auction);
            for r = 1:length(bid_ids)
                fprintf(1,format,bid_ids{r},output(r,:));
            end
        end
        
        function writeTypeEstimates( obj, filename )
            % Write estimated types to a file           
            
            % Add mean type over bootstrap iterations to data table
            thetaBar       = mean(obj.boot_eq(:,1:2,:),3);
            vars_to_output = {'bid_id_provisional','h','Delta'};
            
            bidTable          = obj.bids(:,vars_to_output);
            bidTable.hBar     = thetaBar(:,1);
            bidTable.DeltaBar = thetaBar(:,2);
                        
            % Write to file
            writetable(bidTable,filename,'Delimiter','\t');
            fprintf(1,'File %s written to text\n',filename);
        end
        
        function [ obj ] = equilibrium_bootstrap( obj, scoreModel, coalData  )
            % Bootstrap prices and mark-ups in equilibrium
            
            % Preserve bids object to restore after bootstrap iterations
            obj.bids_original = obj.bids;
                       
            % Initialize output matrix
            N           = size(obj.bids,1);
            obj.boot_eq = zeros(N,11,obj.B);           
        
            fprintf(1,'Equilibrium markups - bootstrap iteration:\n');
            for b = 1:obj.B
                fprintf(1,'\t%4.0f',b);
                if mod(b,10) == 0
                    fprintf(1,'\n');
                end

                % Draw bids for a given iteration
                obj.bids = [ obj.bids_original(:,          obj.auction_variables) ...
                             obj.bids_original(obj.bi(:,b),obj.bidder_variables) ];
                
                % Estimate the type components given pseudo-types drawn
                obj = obj.estimate( coalData );

                % Assign equilibrium outcomes like price, type, etc.
                obj = obj.equilibrium_outcomes( scoreModel, b );

            end
            
            % Restore the typeModel properties inherited from scoreModel to
            % the original versions from the actually observed sample
            obj.bids = obj.bids_original;
            
        end
       
        function [ obj ] = equilibrium_outcomes( obj, scoreModel, b )
            % Calculate prices and mark-ups in equilibrium given a draw of
            % bids and the pseudo-types from that draw. Store in 
            % obj.boot_eq columns 1-9:
            %     (1) h
            %     (2) Delta
            %     (3) Value of renegotiation ER*Delta
            %     (4) Cost of supply
            %     (5) Score / counterfactual bid
            %     (6) Margin of bid over cost
            %     (7) Pseudo-type 
            %     (8) Margin of bid over pseudo-type
            %     (9) Whether bid won
            %     (10) Adjusted score
            %     (11) Margin of adjusted score over cost
            
            % (1) h - (4) cost 
            obj.boot_eq(:,1,b) = obj.bids.h;
            obj.boot_eq(:,2,b) = obj.bids.Delta;
            obj.boot_eq(:,3,b) = obj.bids.ER .* obj.bids.Delta;
            obj.boot_eq(:,4,b) = obj.bids.c;

            % (5) Score
            obj.boot_eq(:,5,b)      = obj.bids.LevelisedTariff;
            
            % (6) Margin over cost            
            obj.boot_eq(:,6,b) = 100*( obj.boot_eq(:,5,b) - ...
                                 obj.boot_eq(:,4,b) ) ./ obj.boot_eq(:,4,b);

            % (7) Pseudo-type - (8) margin over pseudo-type
            obj.boot_eq(:,7,b) = obj.bids.k;  
            obj.boot_eq(:,8,b) = 100*( obj.boot_eq(:,5,b) + ...
                            obj.boot_eq(:,7,b) ) ./ (-obj.boot_eq(:,7,b));

            % (9) Whether bid won
            %   Pick winner (lowest score) given scores drawn by auction
            auction_ids = unique(obj.bids.auction_id_provisional);
            for j = 1:length(auction_ids)
                bids_in_auction = find(strcmp(obj.bids.auction_id_provisional,...
                                    auction_ids(j)));
                eq_bids = obj.bids.LevelisedTariff( bids_in_auction );

                % Rank of each bid within auction
                [ ~, ri ] = sort(eq_bids,'ascend');
                r         = [1:length(ri)]';
                r(ri)     = r;

                % Whether the bid would have won
                W  = obj.bids.winners( bids_in_auction(1) );
                NB = length(bids_in_auction);
                obj.bids.eq_winner(bids_in_auction,1) = 1*(r <= W*ones(NB,1));
            end
            obj.boot_eq(:,9,b) = obj.bids.eq_winner;
            
            % (10) Adjusted score
            %   Residualize score of each bid using the parameters of the 
            %   original auction whence the bidder was drawn
            S_b         = obj.bids.LevelisedTariff;
            logStil_ia  = ( log(S_b) - obj.bids.mu_auction_pred ) ./ ...
                            obj.bids.sig_auction_pred;
            
            %   Inflate score to reflect what the bidder would have bid 
            %   in the auction to which bidder is assigned   
            logStil_iap = logStil_ia .* scoreModel.sig_auction_pred_b(:,b) + ...
                          scoreModel.mu_auction_pred_b(:,b);                     
            obj.bids.adjusted_score = exp( logStil_iap ); 
            obj.boot_eq(:,10,b)     = obj.bids.adjusted_score;
            
             % (11) Adjusted margin over cost            
            obj.boot_eq(:,11,b) = 100*( obj.boot_eq(:,10,b) + ...
                            obj.boot_eq(:,7,b) ) ./ (-obj.boot_eq(:,7,b));
            
        end

        function [ obj ] = counterfactual_bootstrap( obj )
            % Bootstrap counterfactual prices and mark-ups
            
            % Preserve bids object to restore after bootstrap iterations
            obj.bids_original = obj.bids;
                       
            % Initialize output matrix
            N           = size(obj.bids,1);
            obj.boot_cf = zeros(N,9,obj.B);           
        
            fprintf(1,'Running counterfactuals - bootstrap iteration:\n');
            for b = 1:obj.B
                fprintf(1,'\t%4.0f',b);
                if mod(b,10) == 0
                    fprintf(1,'\n');
                end

                % Draw bids for a given iteration
                obj.bids = [ obj.bids_original(:,obj.auction_variables) ...
                             obj.bids_original(obj.bi(:,b),obj.bidder_variables) ];
                
                % Solve for counterfactual bids
                obj = obj.counterfactual();
                
                % Assign counterfactual outcomes
                obj = obj.counterfactual_outcomes( b );         

            end
            
            % Restore the typeModel properties inherited from scoreModel to
            % the original versions from the actually observed sample
            obj.bids = obj.bids_original;
            
        end
        
        function [ obj ] = counterfactual( obj )
        % Solve optimal bids for all auctions under strict contract
        %    enforcement, given a typeModel object
        
            % Indices of bids with heat rates from estimated type
            bidi = [1:size(obj.bids,1)]';
            bidi = bidi( ~isnan(obj.bids.h), : ); % Must have type h, Delta
            
            % Initialize costs and counterfactual bids
            obj.bids.c    = NaN(size(obj.bids,1),1);
            obj.bids.cf_b = NaN(size(obj.bids,1),1);
            
            % Solve optimal counterfactual bids, bid-by-bid
            for i = 1:length(bidi)
                [ bc_i, c_i ] = obj.optimalBid( bidi(i) );
                obj.bids.c( bidi(i) )    = c_i;
                obj.bids.cf_b( bidi(i) ) = bc_i;
            end
            
            % Declare winners for each auction based on counterfactual bids
            auction_ids = unique(obj.bids.auction_id_provisional(bidi,:));
            for j = 1:length(auction_ids)
                bids_in_auction = find(strcmp(obj.bids.auction_id_provisional,...
                                    auction_ids(j)));
                cf_bids = obj.bids.cf_b( bids_in_auction );
                
                % Rank of counterfactual bid within auction
                [ ~, ri ] = sort(cf_bids,'ascend');
                r     = [1:length(ri)]';
                r(ri) = r;
                
                % Whether the bid would have won               
                W  = obj.bids.winners( bids_in_auction(1) );
                NB = length(bids_in_auction);
                obj.bids.cf_winner(bids_in_auction,1) = 1*(r <= W*ones(NB,1));
            end
            
        end
        
        function [ obj ] = counterfactual_outcomes( obj, b ) 
            % Calculate prices and mark-ups in counterfactuals. Store in 
            % obj.boot_cf columns 1-9:
            %     (1) h
            %     (2) Delta
            %     (3) Value of renegotiation ER*Delta
            %     (4) Cost of supply
            %     (5) Score (adjusted) / counterfactual bid
            %     (6) Margin of bid over cost
            %     (7) Pseudo-type 
            %     (8) Margin of bid over pseudo-type
            %     (9) Whether bid won
                
            % Assign components of counterfactual that remain the same
            % as in equilibrium, including components of bidder type
            obj.boot_cf(:,1:4,b) = obj.boot_eq(:,1:4,b);
            obj.boot_cf(:,7,b)   = obj.boot_eq(:,7,b);

            % Assign results to obj.boot_cf object
            obj.boot_cf(:,5,b) = obj.bids.cf_b;
            obj.boot_cf(:,6,b) = 100*( obj.boot_cf(:,5,b) - ...
                                obj.boot_cf(:,4,b) ) ./ obj.boot_cf(:,4,b);
            obj.boot_cf(:,8,b) = 100*( obj.boot_cf(:,5,b) + ...
                                obj.boot_cf(:,7,b) ) ./ (-obj.boot_cf(:,7,b));
            obj.boot_cf(:,9,b) = obj.bids.cf_winner;    

        end
        
        function [ Fh, fh ] = smoothHeatCdf( obj, x, h_bandwidth )
            % Smooth empirical distribution of estimated types
            %   Vector x input of points at which to evaluate distribution
        
            % Extract heat rate estimates
            hi = obj.bids.h(~isnan(obj.bids.h),:)';
            N  = length(hi);
            P  = length(x);

            % Kernel
            % K   = @(u) 0.75*(1-u.^2) .* (abs(u) <= 1); % Epanechnikov kernel
            Kp  = @(u) 1/sqrt(2*pi)*exp(-u.^2/2);      % Normal kernel pdf
            Kc  = @(u) normcdf(u,0,1);

            % Calculate density for every point in grid
            u = (x(:,ones(1,N))-hi(ones(P,1),:))/h_bandwidth;
            
            Fh = 1/N * sum( Kc(u), 2 );
            if nargout > 1
                fh = 1/N * sum( 1/h_bandwidth*Kp(u), 2 );
            end
    
        end
               
        function [ bc_i, ci ] = optimalBid( obj, bid_idx, hi )
        % Solve for optimal bid function in a given auction
        %   hi - Vector of heat rates for which to evaluate the optimal bid
           % fprintf(1,'Solving optimal bid for bid: %10s\n',...
           %    obj.bids.bid_id_provisional{bid_idx});
             
           % Bid data object for bid to be solved
           if nargin < 3
               hi = obj.bids.h(bid_idx);
           end
           
           % Components of optimal bid
           EP = obj.bids.EP(bid_idx);
           F  = obj.bids.F(bid_idx);
           T  = obj.bids.T(bid_idx);
           ci = hi .* EP + F + T;   % Costs corresponding to heat rates
           
           N  = obj.bids.bidders(bid_idx);
           W  = obj.bids.winners(bid_idx);
                      
           % Denominator of mark-up
           [ Fh_i, ~ ] = obj.smoothHeatCdf( hi, obj.h_bandwidth );
           denom_i = (1-Fh_i).^(N-W);
           
           % Numerator of mark-up
           %   Need to numerically integrate, for each element of hi, over
           %   the range of costs from that hi to the maximum possible hi
           Nabs    = 15;         % Number of abscissa for numerical int
           Npts    = length(ci); % Number of points at which to evaluate bid
           [ xtil, wt ] = GaussLegendre(Nabs);
           
           % Change of variables for integration over [c_i,c_upp]
           c_upp = 35000*EP + F + T;
           c_prime = ( (c_upp-repelem(ci,Nabs,1)).*repmat(xtil,Npts,1) + ...
                       (c_upp+repelem(ci,Nabs,1)) ) / 2;
           
           ia   = repelem([1:Npts]',Nabs,1);
           w_ia = repmat(wt,Npts,1);
           c_ia = (c_upp-repelem(ci,Nabs,1)) / 2;
           
           h_prime = (c_prime - F - T) / EP;
           [ Fh_ia, ~ ] = obj.smoothHeatCdf( h_prime, obj.h_bandwidth );
           
           summand_ia = w_ia .* c_ia .* (1-Fh_ia).^(N-W);
           num_i      = accumarray(ia,summand_ia);
           
           bc_i = ci + num_i ./ denom_i;      
    
        end
                              
        % Summarize results of typeModel estimation
        [] = summarize( obj );

        % Plot type distribution
        [ ] = plot1d( obj, file );  % Heat rate only
        [ ] = plot2d( obj, file );  % Heat rate and bonus in 2-d

        % Tabulate bids (model estimates in equilibrium)
        [ ] = tabulateBids( obj, sample, file );
        [ ] = tabulateCounterfactual( obj, sample, file );
        [ ] = tabulateBoots( obj, file );

        % Plot optimal bid function
        [ ] = plotBidFunction( obj, bid_id, hi, file );
        
    end % End methods block
        
end % End typeModel class


%% Objective function 
function [ f ] = objective( theta, k, F, beta_h, beta_e, EP, P0, ...
                                eta, VP, mu_t, sig_t, V0, delta, Tdisc )
% objective Invert pseudo-types for 2-D types
%   Specify a system of equations consisting of the level of the
%   pseudo-type and the optimal level of indexation

% Unknown types
h     = theta(1);
Delta = theta(2);

% Expected value of renegotiation as a function of h
[ ER, dERdBetah ] = expectedRenegotiation( h, mu_t, sig_t, V0, ...
                                           beta_e, beta_h, delta, Tdisc );
   
% Two equations of
%   (1) Level of pseudo-type
%   (2) FOC for optimal indexation decision

% termsk = [ k beta_h*(EP-P0) -F -h*EP Delta*ER -eta*(h-beta_h)^2*VP ];
% display(termsk);
keq = k - (beta_h*(EP-P0) - F - h*EP + Delta*ER - eta*(h-beta_h)^2*VP);

% termsh = [ (EP-P0) Delta*dERdBetah eta*2*(h-beta_h)*VP ];
% display(termsh);
heq = (EP-P0) + Delta*dERdBetah + eta*2*(h-beta_h)*VP;

% Calculate objective function value
W = [ 1 0; 0 1e8 ]; % Weighting because FOC is scaled 1e-4 smaller
g = [ keq; heq ];
f = g'*W*g;

end




