function [ bids ] = cleanBidInventory( bids, coal )
%cleanBidInventory Function to read and clean bid and auction data
%
% It is expected this function is called from the directory in
%    which the relevant data files live.
%
% INPUT - 
%    bdis  - data table containing bid-level data
%    coal  - coalData object containing coal price time series data.
%
% OUTPUT -
%    bids   - data table object of bid data merged with auction
%             characteristics, for use in estimating the score distribution.

% Read auction inventory
auctions = readtable('auction_inventory_master.txt','Delimiter','\t',...
                      'ReadVariableNames',true,'HeaderLines',1);
keep     = ~ strcmp(auctions.auction_id_provisional,'');
auctions = auctions(keep,{'auction_id_provisional','auction_id',...
                    'Case','UMPP','FuelSource','TermOfProject','PPALength'});

% Merge the bid and auction datasets
bids     = join(bids,auctions,'Keys','auction_id_provisional');
      
% Drop any remaining hydro projects
keep = ~ strcmp(bids.FuelSource,'HYDRO');             
bids = bids(keep,:);

% Keep bids up to 2012
keep = ~ strcmp(bids.auction_yyyymm,'');
bids = bids(keep,:);
bids.auction_year = cellfun(@(x) str2double(x(1:4)), bids.auction_yyyymm);
bids = bids(bids.auction_year <= 2012,:);

%% Clean/add variables needed for model of score distribution
bids.case2 = double( strcmp(bids.Case_auctions,'Case 2') );
bids.coal_captive  = double( strcmp(bids.FuelSource,'CAPTIVE') );
bids.coal_imported = zeros(size(bids.coal_captive));
IMP_found          = strfind(bids.FuelSource,'IMPORTED');
bids.coal_imported(not(cellfun('isempty',IMP_found))) = 1;
bids.coal_domestic = double( ~ bids.coal_captive & ~ bids.coal_imported );

% Bring in coal prices for each bid based on
%   (year prior to bidding) X source of fuel {captive, domestic, imported}
year_idx    = bids.auction_year - 2005;
bids.source = 1*bids.coal_captive + 2*bids.coal_domestic + 3*bids.coal_imported;
num_years   = size(coal.trailing_price,1);
price_idx   = year_idx + num_years*(bids.source-1);

bids.trailing_price = coal.trailing_price( price_idx );
bids.expected_price = coal.exp_price( price_idx );
bids.variance_price = coal.variance_price( price_idx );

% Imported prices only
% bids.trailing_price = coal.trailing_price( year_idx, 3 );
% bids.expected_price = coal.exp_price( year_idx, 3 );
% bids.variance_price = coal.variance_price( year_idx, 3 );

% Add the number of bidders to the dataset
[ ~, ~, ic ] = unique(bids.auction_id_provisional);
id_counts = accumarray(ic,1);
bids.bidders = id_counts(ic);
% bids.bidders_top = min(bids.bidders,6);
bids.bidders_top = min(bids.bidders,4);
bids.coal_notcaptive = ~ bids.coal_captive;

% Add the number of winners to the dataset
bids.winner = 1*strcmp(bids.Winner,'Yes');
bids.winner( strcmp(bids.Winner,'.') ) = NaN;
winner_counts = accumarray(ic,bids.winner,[],@sum); % Sum winners in auction

% Impute winners based on bidders if winners are missing
winner_counts( isnan(winner_counts) & id_counts <= 5 ) =1;
winner_counts( isnan(winner_counts) & id_counts >=6 & id_counts <= 9 ) = 2;
winner_counts( isnan(winner_counts) & id_counts >= 10 ) = 3;
bids.winners = winner_counts(ic);

% Reduce number of winners in auction where losing bids omitted
bids.winners(strcmp(bids.auction_id_provisional,'MP032')) = 1;
bids.winners(strcmp(bids.auction_id_provisional,'MH046')) = 2;
bids.winners(strcmp(bids.auction_id_provisional,'MH048')) = 1;

% Calculate bidders per winning slot
bids.bidders_per_winner     = double(bids.bidders) ./ double(bids.winners);
bids.bidders_per_winner_top = min(bids.bidders_per_winner,4);

% Impute winner dummy where winning bid indicated but losers are not
[ auction_ids, ~, ia ] = unique(bids.auction_id_provisional);
notnan    = @(x) any(~isnan(x));
anywinner = accumarray(ia,bids.winner,[],notnan);
bids.winner(anywinner(ia) & isnan(bids.winner)) = 0; 

% Impute winner dummy where winning bid not indicated
for j = 1:length(auction_ids)
    bids_in_auction = find(strcmp(bids.auction_id_provisional,...
                           auction_ids(j)));
    if ~any(isnan(bids.winner( bids_in_auction )))
        continue
    end

    % Rank of bid within auction
    [ ~, ri ] = sort( bids.LevelisedTariff( bids_in_auction ),'ascend');
    r     = [1:length(ri)]';
    r(ri) = r;

    % Whether the bid won
    W = bids.winners( bids_in_auction(1) );
    bids.winner( bids_in_auction ) = 1*(r <= W);
end

% Code winners in auctions with missing data
bids.winner(strcmp(bids.bid_id_provisional,'UP074-001')) = 1;
bids.winner(strcmp(bids.bid_id_provisional,'MP032-001')) = 0;
bids.winner(strcmp(bids.bid_id_provisional,'MP032-002')) = 0;

% Interaction term between fuel source and price
gs = grpstats( bids,'source', {'mean'}, 'datavars', {'trailing_price'});
% mean_trailing_price   = mean(bids.trailing_price);
mean_trailing_price   = gs{bids.source,3};
bids.price            = (bids.trailing_price-mean_trailing_price);
bids.priceXnotcaptive = (bids.trailing_price-mean_trailing_price) .* ...
                        ~bids.coal_captive;
bids.priceXcaptive    = (bids.trailing_price-mean_trailing_price) .* ...
                         bids.coal_captive;
                    
% Separate dummy for Case 2 ex-UMPP and UMPP
bids.case2exUMPP = bids.case2 & ~bids.UMPP;

% for captive UMPPs
bids.UMPPXnotcaptive = bids.UMPP & ~bids.coal_captive;
bids.UMPPXcaptive    = bids.UMPP & bids.coal_captive;

% Dummy for Anpara (UP077), for which bids seem unusually low given
% fundamentals.
bids.anpara = strcmp(bids.auction_id_provisional,'UP077');

% Add state dummies
bids.state_abbrev = cellfun(@(x) x(1:2),bids.auction_id_provisional,...
    'UniformOutput',false);
% tabulate(bids.state_abbrev);
[ unique_states ] = unique(bids.state_abbrev);
for i = 1:length(unique_states)
    state_dum = strcat('state_',unique_states{i});
    bids.(state_dum) = double( strcmp(bids.state_abbrev,unique_states(i)) );
end

% Output tab-delimited text file for use in regressions of fraction indexed
% on bidder connectedness
writeBidInventory( bids );

% Assume we have no bids if auction has only partial bidding data
bids.clean( strcmp(bids.auction_id_provisional,'BH008') ) = 0;

end