function [ ER, dERdBetah ] = expectedRenegotiation( h, mu_t, sig_t, ...
                                         V0, beta_e, beta_h, delta, Tdisc )
%expectedRenegotiation Calculate expected value of renegotiation 
%   The expected value of renegotiation is the expectation of the
%   present discounted value of future renegotiation events. 
%  
% INPUT 
%   year - auction year in which the expectation is being taken
%   mu_t - mean of log price distribution in years 1:T'
%   sig_t - std of log price distribution in years 1:T'
%   V0   - threshold value of variable profits at which renegotiation
%          occurs
%   beta_e - non-indexed component of the bid (INR/kWh) in year t = 1:T'
%   h      - heat rate of the bidder
%   beta_h - indexed component of bid
%
% OUTPUT
%   exp_reneg - expected value of renegotiation in given year
%   exp_reneg_deriv - derivative of expected value of renegotiation, with
%                     respect to beta_h, in a given year

% Expectation of future renegotiation
t0 = 5;
p_bar = (V0 + beta_e) / (h - beta_h);  % Threshold coal price in each year
ERt   = logncdf(p_bar,mu_t(t0:end),sig_t(t0:end),'upper');
ER    = sum( delta .* ERt ) / Tdisc;

% Derivative of expectation with respect to beta_h
dERtdBeta = - lognpdf(p_bar,mu_t(t0:end),sig_t(t0:end)) .* ...
                     (V0 + beta_e) / (h - beta_h)^2;
dERdBetah = sum( delta .* dERtdBeta ) / Tdisc;

end

