%% ========================================================================
%          Estimation of bidding model with renegotiation
%
%  Paper: Contract Enforcement and Production Efficiency: Evidence from the
%  Bidding and Renegotiation of Power Contracts in India
%
%  Author: Nicholas Ryan
%%=========================================================================

%% ========================================================================
%                 Set directory paths
%%=========================================================================

% This code sets directories on the assumption that it has been called from
%  ?/replication_bidding_renegotiation/code/matlab
% Please navigate to that directory before running the script.

clear;
cd ../..
root = pwd;

code     = [root,'/code/matlab/'];
cd code;

databids = [root,'/data/bids/clean/'];
dataesc  = [root,'/data/bids/assumptions/'];
datainv  = [root,'/data/inventory_master'];
dataext  = [root,'/data/external'];
datawork = [root,'/data/work'];
datacoal = [root,'/data/cag_coal_blocks/clean'];

outcomes = [root,'/data/outcomes/'];
tables   = [root,'/output/tables'];
figures  = [root,'/output/figures'];

addpath(code);

%% ========================================================================
%                 Data preparation
%%=========================================================================

%% Read auction inventory and escalation factor data

% Read escalation factors
cd(dataesc);
esc_file    = 'bidding_assumptions.txt';
esc_factors = readtable(esc_file,'Delimiter','\t',...
                        'ReadVariableNames',true,'TreatAsEmpty',{'.'});

% Read bid inventory
cd(datainv);
bids = readtable('data_inventory_master.txt','Delimiter','\t',...
                      'ReadVariableNames',true);
keep = ~ strcmp(bids.auction_id_provisional,'N/A');
bids = bids(keep,:);

% Flag bids with detailed data on bid composition
bids = sortrows( bids, {'auction_id_provisional','bid_id_provisional'} );
bids.clean = strcmp(bids.DataStatus,'Clean');


%% Coal prices and price expectations

cd(dataext);
coal = coalData('coal_price_newcastle.csv','coal_domestic_wpi.csv');
coal.print();


%% Clean and augment bidding data

% For auctions in which bids are available, add derived bid variables such 
%    as the bid charges in several components and the fraction indexed
cd(databids);
bids = prepareIndexationData( bids, esc_factors );

% Augment bids with auction-level covariables.  Assign coal prices to bids.
cd(datainv);
bids = cleanBidInventory( bids, coal );


%% ========================================================================
%                 Estimate model objects
%%=========================================================================

%% 1. Fit parametric (log-normal) distribution to scores

% Estimate score distribution (once, with analytic standard errors)
scoreDist = scoreModel( bids );
scoreDist = scoreDist.estimate( );

% Tabulate estimated parameters of score distribution
cd(tables);
file = 'tab_score_distribution_parameters.tex';
scoreDist.tabulate( file );

% Plot score distribution
cd(figures);
scoreDist.plotScoreDistribution( 1 );

% Plot residual score distribution
figure;
scoreDist.plotResidualScoreDistribution( 1 );


%% 2. Pseudo-type distribution from inverting scores
%    For all auctions with levelised tariffs
scoreDist = scoreDist.invertScores( );


%% Bootstrap score distribution

% Sample bids within scoreModel object
method    = 'block';
scoreDist = scoreDist.sampleBids( method );

warning('off','optim:fminunc:WillRunDiffAlg');
scoreDist = scoreDist.bootstrap( );

today = date;
cd(datawork);
filename = ['score_model_bootstrap_',today];
save(filename,'scoreDist');


%% 3. Estimate type distribution (all auctions with bid components)

% Load scoreModel estimates
cd(datawork);
load('score_model_bootstrap_28-Jan-2019','scoreDist');

% Initialize type model object
load('type_model_bootstrap_28-Jan-2019','typeDist');

cd(databids);
typeDist = typeModel( scoreDist, coal, esc_factors );

% Estimate types for auctions with bidding data
cd(databids);
typeDist = typeDist.estimate( coal );


%% 5. Examine type distribution 

% Tabulate
typeDist.summarize();

% Plot 1-D
cd(figures);
file = 'fig_heat_distribution_annotated.pdf';
typeDist.plot1d( file );

% Plot 2-D
file = 'fig_type_distribution.pdf';
typeDist.plot2d( file );


%% 6. Bootstrap equilibrium and counterfactual outcomes

% Bootstrap equilibrium outcomes
cd(databids);
typeDist.noisy = 0;
typeDist = typeDist.equilibrium_bootstrap( scoreDist, coal );

% Bootstrap counterfactual outcomes
typeDist = typeDist.counterfactual_bootstrap( );

% Save type model object
cd(datawork);
filename = ['type_model_bootstrap_',today];
save(filename,'typeDist');

% Tabulate equilibrium and counterfactual outcomes
cd(tables);
file = 'tab_bid_markups_counterfactual_boots.tex';
typeDist.tabulateBoots( file );


%% 7.  Example of optimal bid function

% Calculate optimal bid
bid_id = 'AP004-001'; % Krishnapatnam
% bid_id = 'GJ018-001'; % Mundra
bid_idx = find(strcmp(typeDist.bids.bid_id_provisional,bid_id));
hi     = [ 4000:500:18000 ]';
bc_i   = typeDist.optimalBid( bid_idx, hi );

% Plot optimal bid function
cd(figures);
file   = sprintf('fig_optimal_bid_function_%s.pdf',bid_id);
typeDist.plotBidFunction( bid_idx, hi, file );


%% ========================================================================
%                 Robustness checks for appendix
%%=========================================================================

%% Run robustness checks
eta =  [ 1.0  0.50 1.50 1.00 1.00 ]';
V0  =  [ 0.30 0.30 0.30 0.15 0.45 ]';
energy_growth_index =  [ 3    3    3    3   3   ]';
scenarios = table(eta,V0,energy_growth_index);

runRobustnessChecks( scenarios, scoreDist, coal, ...
                     esc_factors, databids, datawork );


%% Tabulate the results of robustness checks
cd(tables);
file = 'tab_bidder_types_robustness.tex';
tabulateRobustnessChecks( scenarios, file, datawork, tables );


%% ========================================================================
%                 Plot bids from Mundra UMPP auction
%%=========================================================================

%% GJ018 Mundra -- Plot Bids

% Read bids
cd(databids);
auction_id = 'GJ018';
auction    = auctionData( auction_id, bids, esc_factors );

% Plot bids
cd(figures);
auction.plotAuction( 1 );

auction.bids.GJ018_001.plotBid( 1 );
auction.bids.GJ018_004.plotBid( 1 );
auction.bids.GJ018_005.plotBid( 1 );


%% ========================================================================
%                                 END
%%=========================================================================



