function [ ] = plotIndexationByRank( inventory, file )
% plotLevelisedTariff  Plot contribution of future years to levelised bid
%
% INPUT :
%  inventory    data table with variables on rank and fraction levelised
%  file         file name
%
% OUTPUT :
%               Writes plot to file
if nargin < 2
    file = 0;
end

%% Formatting options
textProp = {'fontsize'    , 32, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 24, ...
            'FontName'    , textProp{4}};
        
        
%% Data to plot

inventory.lt_rank1  = inventory.lt_rank == 1;
inventory.lt_rank2  = inventory.lt_rank == 2;
inventory.lt_rank3  = inventory.lt_rank == 3;
inventory.lt_rank4  = inventory.lt_rank == 4;
inventory.lt_rank5p = inventory.lt_rank >= 5;

% Fraction of bid indexed
lm1 = fitlm(inventory,['frac_indexed ~ lt_rank1 + lt_rank2 + lt_rank3' ...
                        '+ lt_rank4 + lt_rank5p'],'Intercept',false);
display(lm1);
                    
lm2 = fitlm(inventory,['frac_indexed ~ lt_rank2 + lt_rank3' ...
                        '+ lt_rank4 + lt_rank5p'],'Intercept',true);
display(lm2);

sefactor = [ 0; ones(4,1) ];
indexed = [ lm1.Coefficients.Estimate ...
            lm1.Coefficients.Estimate-1.64*sefactor.*lm2.Coefficients.SE ...
            lm1.Coefficients.Estimate+1.64*sefactor.*lm2.Coefficients.SE ];

        
% Fraction of bid value in first 5 years
lm1 = fitlm(inventory,['frac_early5 ~ lt_rank1 + lt_rank2 + lt_rank3' ...
                        '+ lt_rank4 + lt_rank5p'],'Intercept',false);
display(lm1);
                    
lm2 = fitlm(inventory,['frac_early5 ~ lt_rank2 + lt_rank3' ...
                        '+ lt_rank4 + lt_rank5p'],'Intercept',true);
display(lm2);

early = [ lm1.Coefficients.Estimate ...
          lm1.Coefficients.Estimate-1.64*sefactor.*lm2.Coefficients.SE ...
          lm1.Coefficients.Estimate+1.64*sefactor.*lm2.Coefficients.SE ];

        
%% Plot supply, demand and the clearing price
rank = 1:5;
plot(rank,early(:,1),'b-' ,'LineWidth',2);  hold on;
plot(rank(2:end),early(2:end,2),'b:','LineWidth',1);
plot(rank(2:end),early(2:end,3),'b:','LineWidth',1);

plot(rank,indexed(:,1),'k-' ,'LineWidth',1.5);  
plot(rank(2:end),indexed(2:end,2),'k:','LineWidth',1);
plot(rank(2:end),indexed(2:end,3),'k:','LineWidth',1);

xlim([0.5 5.5]);
ylim([0 0.70]);

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'XTick'      , 1:5                , ...
         'XTickLabels' , {'1','2','3','4','5+'}, ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Rank of bidder in auction',textProp{:})
ylabel('Fraction of bid present value',textProp{:})

% if inrPerUsd == 1
%     units = ' (INR/kWh)';
% else
%     units = ' (cents/kWh)';
% end
% if present
%     ylabel(['Present value of tariff',units],textProp{:})
% else
%     ylabel(['Future tariff',units],textProp{:})
% end

title(sprintf('Indexation by Bidder Rank'));

% Text labels
text(0.75,0.58,'In first 5 years',labProp{:});
text(0.75,0.25,'Indexed to coal',labProp{:});

hold off;

%% Export figure to file
if file
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end
