function [ bids ] = prepareIndexationData( bids, esc_factors )
%prepareIndexationData Add variable on the indexation of bid components to
%  the bid inventory
%
% INPUT:
%   inventory - Table of bids
%   
% OUTPUT:
%   inventory - Cleaned table of bids with additional variables

warning('OFF','MATLAB:table:ModifiedVarnames')

% Assam project (=1)
assam    = false(size(bids.auction_id_provisional));
AS_found = strfind(bids.auction_id_provisional,'AS');
assam(not(cellfun('isempty',AS_found))) = true;

% Keep only long-term thermal auctions
drop = strcmp(bids.auction_id_provisional,'AP006') | ... % Medium-term
       strcmp(bids.auction_id_provisional,'GJ025') | ... % Medium-term
       strcmp(bids.auction_id_provisional,'JK023') | ... % Hydro
       strcmp(bids.auction_id_provisional,'MH045') | ... % Medium-term
       strcmp(bids.auction_id_provisional,'MH048') | ... % Medium-term
       strcmp(bids.auction_id_provisional,'RJ054') | ... % Heat-rates bid
       strcmp(bids.auction_id_provisional,'UP074') | ... % Heat-rates bid (Added 1/21)
       strcmp(bids.auction_id_provisional,'KA031') | ... % Medium-term
       assam                                       | ... % Auction in assam
       isnan(bids.LevelisedTariff)                 | ... % Missing bid
       strcmp(bids.bid_id_provisional,'BH010-012');      % LNG bid  
bids = bids(~drop,:);

% strcmp(bids.auction_id_provisional,'UP075') | ... % Bids already indexed

% Add fraction of bid levelised and bid rank (L1, L2, etc.) to bid
%   inventory data table
auction_ids = unique(bids.auction_id_provisional);
auctions = cell(length(auction_ids),1);
bids.frac_indexed = NaN(size(bids,1),1);
bids.lt_rank      = NaN(size(bids,1),1);

% Initialize charges as NaN
charges = {'capacity','energy_nesc','energy_esc','transport'};
for i = 1:length(charges)
    bids.(charges{i}) = NaN(size(bids,1),1);
end

% Restrict bids to those with cleaned bidding data
auction_ids = unique(bids.auction_id_provisional(bids.clean,:));

for j = 1:length(auction_ids)
    
    fprintf(1,'Reading auction: %10s\n',auction_ids{j});
    auctions{j} = auctionData( auction_ids{j}, ...
                            bids(bids.clean,:), esc_factors );
    
    for i = 1:length( auctions{j}.bid_ids )
        
        % Select bid from auction
        fprintf(1,'\t\tBid: %10s\n',auctions{j}.bid_ids{i});
        bid_index = strcmp( bids.bid_id_provisional, ...
                            auctions{j}.bid_ids{i} );
                        
        % Add variables calculated as part of bid scoring to the table of 
        %   bid characteristics
        bids.frac_indexed( bid_index ) = ...
            auctions{j}.bids.(auctions{j}.bid_keys{i}).frac_indexed;
        bids.frac_indexed_var( bid_index ) = ...
            auctions{j}.bids.(auctions{j}.bid_keys{i}).frac_indexed_var;
        bids.frac_early5( bid_index ) = ...
            auctions{j}.bids.(auctions{j}.bid_keys{i}).frac_early5;
        bids.frac_early10( bid_index ) = ...
            auctions{j}.bids.(auctions{j}.bid_keys{i}).frac_early10;
        bids.lt_rank( bid_index ) = auctions{j}.rank(i);
        
        % Expected present nominal value of bid charges
        bids( bid_index, charges ) = ...
            auctions{j}.bids.(auctions{j}.bid_keys{i}).charges;
    end
end

end

