%% ========================================================================
%
%  Project: Bidding and Renegotiation in Indian Power Auctions
%
%  Purpose: To numerically study the changes in profits due to changes 
%           in the components offered in bids
%
%  Date:    April 29, 2018
%
%  ========================================================================

%% Set parameters of bidding problem
root = '/Users/nryan/Dropbox/longbids';
figures     = [root,'/docs/exhibits/figures'];
simulations = [root,'/code/matlab/simulations'];
cd(simulations);

% Plant efficiency h = heat rate (btu/kWh)
h     = 11615;    % Cropper AER article
% h      = 10000;     % Assumed
Delta  = 0.5;
eta    =  1.0;    % Risk aversion
% eta    = 1.0;
% eta    =  2;
V0     = -0.3;  % Tolerable per unit loss

% Coal prices
% coal_price_usd_ton         = 80;
coal_price_inr_ton         = 3680;
% coal_price_inr_ton         = 1800;
% coal_gcv_kcal_kg           = 5000;       % IPCC range
gcv_kcal_kg                = 6000;       % Newcastle index specification
btu_per_kcal               = 3.97;    
inr_per_usd                = 46;

p_inr_btu = coal_price_inr_ton* 1/1000 * 1/gcv_kcal_kg * 1/btu_per_kcal;

% Solve for parameters of log-normal price distribution that yields 
%   the current price as the mean price with variance vp
EP     = p_inr_btu;
VP     = 1.85e-9;
mu_p   = log( EP^2 / sqrt( VP + EP^2 ) );
sig_p  = sqrt( log( 1 + VP / EP^2 ) );

% Known bid components
beta_e = 1.2; % Non-escalable energy charge (INR/kWh)
F      = 1;   % Fixed cost (INR/kWh)


%% Build value function

p_bar = @( beta_h ) (V0 + beta_e) ./ (h - beta_h);
                             
valueFunction = @( beta_h ) pseudotypeValue( beta_h, h, Delta, F, beta_e, ...
                                             eta, V0, mu_p, sig_p );
valueFunctionObj = @( beta_h ) - valueFunction( beta_h );

 
%% Plot components of profit

beta_h = linspace(0,h)';
[ values, value_parts ] = valueFunction( beta_h );

% Vpi1s  = Vpi1( beta_C ); % Direct effect on renegotiation profits
% Vpi2s  = Vpi2( beta_C ); % Insurance contribution of renegotiation
% Vpi3s  = Vpi3( beta_C ); % Risk of not indexing
% plot(beta_C,Vpi1s,'k-',beta_C,Vpi2s,'b:',beta_C,Vpi3s,'r--');

plot(beta_h,value_parts(:,2),'b:',...   % Bonus
     beta_h,value_parts(:,3),'r--',...  % Price risk
     'LineWidth',2);
hold on;
plot(beta_h,sum(value_parts(:,2:3),2),'k-');

% Find maximum of profit function
LB      = [ 0 ];
UB      = [ h ];
[ beta_h_opt, k ] = fminbnd(valueFunctionObj,LB,UB);
plot(beta_h_opt, -k-value_parts(1,1),'or','MarkerSize',15);
fprintf(1,'Fraction indexed %3.2f\n',beta_h_opt / h);

%% Solve pseudotype and indexation system for theta = {h,Delta}

theta0  = [ h*1.2 Delta*0.5 ]';
epsilon = theta0(1) * 1e-2;
options = optimoptions('fmincon','TolX',1e-15,'TolFun',1e-15,...
                       'MaxIter',1e4,'MaxFunEvals',1e5,...
                       'Display','iter');

thetaObj = @( theta ) pseudotypeIndexationDistance( theta, -k, beta_h_opt, F, ...
                                    beta_e, eta, V0, mu_p, sig_p, EP, VP );

% % Constraints
% A = [ -1  0; 0 -1 ];
% B = [ -(beta_h_opt + epsilon); -1e-3 ];
% [ thetaHat, fval ] = ...
%     fmincon( thetaObj, theta0, A, B, [],[],[],[],[],options);

[ thetaHat, fval ] = fminsearch( thetaObj, theta0, options );

theta = [ h Delta ]';

output = [ theta0 thetaHat theta thetaHat-theta]';
format = '%15s\t%6.0f\t%3.2f\n';
rowlab = {'Starting value','Estimate','Truth','Difference'};
for r = 1:length(rowlab)
    fprintf(1,format,rowlab{r}, output(r,:));
end

%% Plot objective function

hi = [6000:250:14000]';
Deltai = [0.01:0.01:1]';
[ hi2, Deltai2 ] = meshgrid(hi,Deltai);
obji = zeros(size(hi2));
thetai = [ hi2(:), Deltai2(:) ];
for i = 1:length(thetai)
   obji(i) = thetaObj(thetai(i,:));
end
surf( hi2, Deltai2, obji ); 
           

%% Mapping from { c, beta_R } to { beta_C, k }.
%    Calculate optimal indexation for various types
%    Vary marginal cost with fixed beta_R and calculate observables
%    Vary beta_R with fixed cost and calculate observables

% Lay out types at which to evaluate indexation and optimum
N      = 101;
c_min  = 0.4;
c      = F + h*EP;
c_int  = (c - c_min) / ((N-1)/2);
c_max  = c_min + c_int* (N-1);
h_grid = [ c_min: c_int: c_max ]';

Delta_min  = 0.03;
Delta_int  = (Delta - Delta_min) / ((N-1)/2);
Delta_max  = Delta_min + Delta_int* (N-1);
Delta_grid = [ Delta_min: Delta_int: Delta_max ]';

n_mid = (N-1)/2 + 1;
n_p75 = (N-1)/4*3 + 1;
theta = cat( 3, [ h_grid                  Delta_grid(n_mid)*ones(N,1)], ...
                [ h_grid                  Delta_grid(n_p75)*ones(N,1)], ... 
                [ h_grid(n_mid)*ones(N,1) Delta_grid                 ], ...
                [ h_grid(n_p75)*ones(N,1) Delta_grid                 ]);

% Evaluate indexation and value (pseudo-type) for various types
beta_C_opt = zeros(size(theta,1),4);
k_opt      = zeros(size(theta,1),4);

for j = 1:size(theta,3)
    for i = 1:size(theta,1)
        
    % Set objective function given type
    valueFunction = @( beta_h ) pseudotypeValue( beta_h, theta(i,1,j), ...
                    theta(i,2,j), F, beta_e, eta, V0, mu_p, sig_p );
    valueFunctionOBj = @( beta_h ) - valueFunction( beta_h );
    
    % Maximize objective function and store indexation, optimum
    LB      = [ 0 ];
    UB      = [ 0.95*theta(i,1,j) ];
    [ beta_h_opt(i,j), k_opt(i,j) ] = fminbnd(valueFunctionObj,LB,UB);
    
    end
end

% Value against Delta
figure; 
plot(Delta_grid,-k_opt(:,3),'r--',...
     'LineWidth',2);
xlabel('Bonus Delta');
ylabel('Pseudo-type');

% Indexation against Delta
figure; 
plot(Delta_grid,beta_h_opt(:,3),'r--',...
     'LineWidth',2);
xlabel('Bonus Delta');
ylabel('Indexation beta_C');

% Value against indexation
figure;
plot(beta_h_opt(:,1),-k_opt(:,1),'k-',...
     beta_h_opt(:,2),-k_opt(:,2),'b:',...
     beta_h_opt(:,3),-k_opt(:,3),'r--',...
     beta_h_opt(:,4),-k_opt(:,4),'g:',...
     'LineWidth',2);
 xlabel('Indexation beta_C');
 ylabel('Pseudo-type');
 
 
%% Plot identification in several panels

% Create profit as a function of indexation for three values of cost
h_points = [ h_grid(n_mid - 30); ...
             h_grid(n_mid);      ...
             h_grid(n_mid + 30) ];

beta_h = [ linspace(0,h_points(1)); ...
           linspace(0,h_points(2)); ...
           linspace(0,h_points(3)) ]';
value = zeros(size(beta_h));

for i = 1:length(c_points)
    valueFunction = @( beta_h ) pseudotypeValue( beta_h, h_points(i), ...
                                      Delta, F, beta_e, eta, V0, mu_p, sig_p );
    [ value(:,i), ~ ] = valueFunction( beta_h(:,i) );
end

% % Subset the iso-type lines
% beta_h_opt = beta_h_opt(:,[1 3]);
% k_opt      = k_opt(:,[1 3]);

% Create plots
% cd(figures);
file = [figures,'/fig_identification_panel_%1.0f.pdf'];
plotIdentification( file, beta_h, value, beta_h_opt, k_opt );

 
%% ========================================================================
%                                  END
% =========================================================================
