function [ k, kparts ] = pseudotypeValue( beta_h, h, Delta, F, beta_e, ...
                                             eta, V0, mu_p, sigma_p )
%pseudotypeValue Value that defines the pseudo-type; i.e. the contribution
% of a bidder of type { h, Delta } to apparent social surplus
%
% INPUT: 
%   beta_h  - Degree of indexation
%   h       - Efficiency of production in btu per kWh
%   Delta   - bonus payment if renegotiation
%   beta_e  - non-indexed component of energy charge
%   eta     - risk aversion
%   V0      - maximal tolerable loss e.g. 0.5 INR/kWh
%   mu_p    - mean of price distribution
%   sigma_p - standard deviation of price distribution

% Threshold price function
p_bar = @( beta_h ) (V0 + beta_e) ./ (h - beta_h);
                             
% Price distribution functions
hpdf  = @( p ) lognpdf( p, mu_p, sigma_p );
Hupp  = @( p ) logncdf( p, mu_p, sigma_p, 'upper' );

% Expectation and variance of price
EP = exp( mu_p + sigma_p^2/2 );
VP = (exp(sigma_p^2) - 1)*exp(2*mu_p+sigma_p^2);

% Create separate terms for each component of value
value1_cost  = -F -h * EP;                            % Cost
value2_bonus = Delta * Hupp( p_bar( beta_h ) );       % Bonus
value3_price = (h - beta_h).^2 * VP;                  % Price risk

% Truncated normal mean
%   Run into numerical trouble as b -> 0
% Ep_gt_pbar = @( b ) mu_p + h(b)./Hupp(b) * sigma_p;
% value4_reneg = beta_R^2 * H(p_bar(beta_C)) .* Hupp(p_bar(beta_C)); 
% value5_insur = 2* (c-beta_C) * beta_R .* ( Hupp(p_bar(beta_C)) ) .* ...
%                ( Ep_gt_pbar(p_bar(beta_C)) - mu_p );

% Aggregate value terms: all components
% k = value1_cost + value2_bonus ...
%     - eta* ( value3_price + value4_reneg - value5_insur );
% kparts = [ value1_cost(ones(length(beta_C),1))  value2_bonus -eta*value3_price ...
%            -eta*value4_reneg +eta*value5_insur ];

% Aggregate value terms: no renegotiation risk
k = value1_cost + value2_bonus - eta*value3_price;
kparts = [ value1_cost(ones(length(beta_h),1)) value2_bonus -eta*value3_price ];
       
end

