function [ ] = tabulateRobustnessChecks( scenarios, file, datawork, tables )
% Table of bidder types with alternative values of calibrated parameters
%
%   scenarios : alternative values of parameters under which the estimates
%               have been run
%   file :      file to which to print the table


%% Load type distributions
cd(datawork)
S         = size(scenarios,1);
estimates = cell(S,1);

filename     = 'type_model_bootstrap_24-Jan-2019.mat';
load(filename,'typeDist');
estimates{1} = typeDist;

% Load type distribution scenarios with alternative parameters
for s = 2:S
    filename = sprintf('type_model_bootstrap_eta%03.0f_V0%03.0f.mat',...
                        scenarios.eta(s)*100,scenarios.V0(s)*100);
    load(filename,'typeDist');         
    estimates{s} = typeDist;
end

%% Prepare data for table
%    h is stored in first column of typeDist.boot_eq
%    Delta is stored in second column of typeDist.boot_eq


% Variable names and statistics to calculate
rowHeads = {'Mean $h$ (btu/kWh)', ...
            'Median $h$ (btu/kWh)', ...
            'Standard deviation of $\Delta$ (btu/kWh)', ...
            'Mean $\Delta$ (INR/kWh)', ...
            'Median $\Delta$ (INR/kWh)',...
            'Standard deviation of $\Delta$ (INR/kWh)',...
            'Correlation of $h$ and $\Delta$'};
rows = length(rowHeads);

B          = estimates{1}.B;
table_data = zeros(rows,S,2); 
boot_stats = zeros(B,rows,S); % h, Delta, corr(h,Delta)

% Loop over scenarios and populate statistics for each
for s = 1:S
    for b = 1:B

        % Flag and exclude negative pseudo-types
        negative_pseudotype = estimates{s}.boot_eq(:,7,b) > -0.5;
        boot_eq_b           = estimates{s}.boot_eq(~negative_pseudotype,:,b);
        boot_cf_b           = estimates{s}.boot_cf(~negative_pseudotype,:,b);
        with_type           = ~isnan(boot_eq_b(:,1)); % heat rate present

        % Mean h
        boot_stats(b,1,s) = mean( boot_eq_b(with_type,1), 1 );

        % Median h
        boot_stats(b,2,s) = median( boot_eq_b(with_type,1), 1 );

        % Std h
        boot_stats(b,3,s) = std( boot_eq_b(with_type,1), [], 1 );

        % Mean h
        boot_stats(b,4,s) = mean( boot_eq_b(with_type,2), 1 );

        % Median h
        boot_stats(b,5,s) = median( boot_eq_b(with_type,2), 1 );

        % Std h
        boot_stats(b,6,s) = std( boot_eq_b(with_type,2), [], 1 );
        
        % Correlation h and Delta
        boot_stats(b,7,s) = corr( boot_eq_b(with_type,1), ...
                                  boot_eq_b(with_type,2) );
        
    end
end

% Fill the table data for each scenario    
table_data(:,:,1) = permute( mean(boot_stats,1),   [ 2 3 1 ] ) ;
table_data(:,:,2) = permute( std(boot_stats,[],1), [ 2 3 1 ] ) ;

          
%% Prepare table formatting
cd(tables)

% Title of table
title = 'Robustness of Type Distribution Estimates to Calibrated Parameters';

% Calculate size of parameter table
columns  = size(table_data,2);
colHeads1 = {'',' $\eta = 1.0$ '};
colHeads2 = {'',' $V_0 = 0.30$ '};
for s = 3:S+1
    colHeads1{s} = sprintf(' $\\eta = %2.1f$ ',scenarios.eta(s-1));
    colHeads2{s} = sprintf(' $V_0 = %3.2f$ ',scenarios.V0(s-1));
end
      
% Adjust format with latex separators

% For heat rates
format1 = ['%15s',repmat('\t%5.0f',1,columns)];
format1 = regexprep(format1,'\\t','&');

seformat1 = ['%15s',repmat('\t(%3.0f)',1,columns)];
seformat1 = regexprep(seformat1,'\\t','&');

% For deltas / correlation
format2 = ['%15s',repmat('\t%3.2f',1,columns)];
format2 = regexprep(format2,'\\t','&');

seformat2 = ['%15s',repmat('\t(%4.3f)',1,columns)];
seformat2 = regexprep(seformat2,'\\t','&');

%% Print table to file
fid = fopen( file, 'w' );

% Front matter
fprintf(fid,'\\begin{table}[!ht]\n\t\\centering\n\t');
fprintf(fid,'\t\\caption{%s}\n',title);
fprintf(fid,'\\begin{tabular}{%s}\n',['l',repmat('c',1,columns)]);

% Title of table
fprintf(fid,'\t\t\\toprule\n');

% Meta headings
fprintf(fid,[' & \\multicolumn{5}{c}{Calibrated parameter values} \\\\\n']);
fprintf(fid,['\\cmidrule(lr){2-6} \n']);

% Column headings
cformat = regexp(regexprep(format1,'\.\df','s'),'&','split')';
for c = 1:columns+1
    fprintf(fid,cformat{c},colHeads1{c});
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end

for c = 1:columns+1
    fprintf(fid,cformat{c},colHeads2{c});
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end

for c = 1:columns+1
    if c > 1
        fprintf(fid,'(%1.0f)',c-1);
    end
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end
fprintf(fid,'\t\t\\midrule\n');

% Data rows with row headings
for r = 1:rows
    if r <= 3
        fprintf(fid,['\t\t',format1,'\\\\\n'],rowHeads{r},table_data(r,:,1));
        fprintf(fid,['\t\t',seformat1,'\\\\\n'],' ',table_data(r,:,2));
    else
        fprintf(fid,['\t\t',format2,'\\\\\n'],rowHeads{r},table_data(r,:,1));
        fprintf(fid,['\t\t',seformat2,'\\\\\n'],' ',table_data(r,:,2));
    end
    fprintf(fid,['\t\t \\addlinespace \n']);
end

%  Footer rows with statistics of interest
% foot3format = ['%15s\t\\multicolumn{2}{c}{%3.0f}'];
% foot3format = regexprep(foot3format,'\\t','&');
% fprintf(fid,['\t\t',foot3format,'\\\\\n'],'N',obj.N);

% End matter
fprintf(fid,'\t\t\\bottomrule\n');
fprintf(fid,['\\multicolumn{%1.0f}{p{%2.1f\\hsize}}{\\footnotesize ' ...
        'The table shows summary statistics on the estimated type ' ...
        'distribution under different assumptions on the calibrated ' ...
        'parameters in the model. The calibrated parameters are the ' ...
        'bidder risk aversion $\\eta$ and the regulatory threshold $V_0$ ' ...
        'for granting a contract revision. Column 1 shows the baseline ' ...
        'estimates and the other columns vary the values of $\\eta$ and ' ...
        '$V_0$. The standard errors are bootstrapped over $B=200$ ' ...
        'iterations. In each column the row statistic is calculated on ' ...
        'each iteration and the standard error is the standard deviation ' ...
        'of the statistic across iterations.'],...
        columns+1,0.9);
fprintf(fid,'} \\\\\n');
fprintf(fid,'\t\\end{tabular}\n');
fprintf(fid,'\\end{table}\n');

fclose(fid);
fprintf(1,'Printed: %s\n',file);

cd(datawork)

end               
                
