/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

PROJECT: Contract Enforcement and Productive Efficiency:
         Evidence from the Bidding and Renegotiation of Power
         Contracts in India

AUTHOR:  Nick Ryan

DATE:    May 2018
         October 2019 (this revision)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// ***SET ROOT DIRECTORY HERE AND ONLY HERE***
//  settings.do will automatically call on this root directory

// Store path for root directory
cd ../../
local ROOT `c(pwd)'
cd code/stata


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Set paths to additional directories for data and output
  
// Paths to code directories
local CODE      "`ROOT'/code"
local STATA     "`ROOT'/code/stata"

// Paths to data directories
local INVENTORY "`ROOT'/data/inventory_master"
local OUTCOMES  "`ROOT'/data/outcomes"
local EXTERNAL  "`ROOT'/data/external"
local WORK      "`ROOT'/data/work"
local COALGATE  "`ROOT'/data/cag_coal_blocks"

// Paths to output directories
local OUTFIG    "`ROOT'/output/figures"
local OUTTAB    "`ROOT'/output/tables"


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Load programs used in creation of exhibits
include "`STATA'/programs.do"
pause on

// Locals for common constants
local INRPERUSD            50
local USDPERINR            0.02


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Choose what exhibits to run

// Flag for whether to read data from raw sheets
local PREP_BIDDING                  1
local PREP_OUTCOMES                 1
local PREP_INDEXATION               1
local PREP_COALGATE                 1

// Select exhibits to run from paper
local FIG_GENERATION_OWNERSHIP      1
local FIG_COAL_PRICE_WHIST          0

local TAB_BID_OUTCOMES              0
local TAB_REG_RENEGOTIATION_NEW     0
local TAB_REG_BID_INDEXATION        0

// Additional exhibits from appendix
local TAB_REG_RENEGOTIATION_HAZARD  0


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                               Begin DATA PREP
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare project outcomes data
if "`PREP_BIDDING'" == "1" {

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Bid inventory
    insheet using "`INVENTORY'/data_inventory_master.txt", names
    keep bid_id bid_id_provisional auction_id company_id ///
      levelisedtariff ///
      capacityoffered winner foreign publicprivatecompanypsugover ///
      bidderfoundingdate date_founding_parent date_founding_child
    drop if inlist(bid_id,""," ","N/A")

    lab var bid_id_provisional "Bid ID"
    lab var company_id "Company ID"
    lab var bidderfoundingdate "Date of founding"
    lab var date_founding_parent "Date of founding, parent company"
    lab var date_founding_child "Date of founding, child company"
    lab var foreign "Foreign ownership share"
    lab var publicprivatecompany "Ownership"
    
    destring levelisedtariff capacityoffered, replace force
    rename levelisedtariff tariff_level
    label var tariff_level "Levelised tariff (Rs/kWh)"
    rename capacityoffered capacity
    label var capacity "Capacity offered (MW)"

    gen bid_accepted = regexm(winner,"Yes")
    replace bid_accepted = . if missing(winner)
    replace bid_accepted = . if regexm(winner,"?") // Unsure whether bids won
    label var bid_accepted "Bid won contract (=1)"
    label define dummyLabel 0 "No" 1 "Yes"
    label values bid_accepted dummyLabel
    tab bid_accepted, missing
    drop winner

    // Key sample restriction
    //   Dropping bidders where it is unknown if they won or not
    drop if missing(bid_accepted) 
    
    gen bid_year  = substr(bid_id,3,4)
    gen bid_month = substr(bid_id,7,2) // Change (May 18): substr(bid_id,5,2) to substr(bid_id,7,2) -rt
    destring bid_year bid_month, replace 
    gen yearmonth = mofd( mdy( bid_month, 1, bid_year ) )
    label var yearmonth "Year-month of auction"
    format yearmonth %tm
    drop bid_year bid_month

    // Restrict sample period
    keep if yearmonth >= tm(2006m1) & yearmonth <= tm(2012m12)

    tab bid_accepted, missing // Check whether any more winners can be determined
    
    sort bid_id
    order bid_id yearmonth
    label data "Bid inventory"
    describe
    save "`WORK'/data_inventory", replace
    clear
	
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Auction inventory
    import excel "`INVENTORY'/data_inventory_master.xlsx", sheet("auctions") ///
    firstrow

    drop if inlist(auction_id,"","N/A")

    gen term_long = regexm(upper(TermofProject),"LONG")
    label var term_long "Long-term auction"

    gen term_medium = regexm(upper(TermofProject),"MEDIUM")
    label var term_medium "Medium-term auction"

    gen fuel_hydro = regexm(upper(FuelSource),"HYDRO")
    label var fuel_hydro "Hydro project"

    keep auction_id term_* fuel_hydro
    sort auction_id

    tempfile auction_inventory
    save "`auction_inventory'", replace
    clear

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Merge bid and auction inventories

    use "`WORK'/data_inventory"
    sort auction_id
    merge m:1 auction_id using "`auction_inventory'", generate(mergeAuctions)

    lab def mergeLabelAuctions 1 "Bids" 2 "Auctions" 3 "Both"
    lab values mergeAuctions mergeLabelAuctions
    tab mergeAuctions, missing
    drop if mergeAuctions == 2

    // Drop hydro projects and medium-term bids
    drop if fuel_hydro

    save "`WORK'/data_inventory", replace
    clear

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Bid inventory with Characteristics
    import excel "`INVENTORY'/data_inventory_master.xlsx", sheet("bids") firstrow
    keep bid_id MarketCapRsCrore LevelisedTariff CapacityOffered Winner Foreign PublicPrivateCompanyPSUGover BidderFoundingDate date_founding_parent date_founding_child
    drop if bid_id==""
    drop if bid_id=="N/A"
    //drop if bid_id=="GJ200612-001" & LevelisedTariff == "" // One bid id not unique
    drop if bid_id=="GJ200612-001"
	
    destring LevelisedTariff CapacityOffered, replace force
    rename LevelisedTariff tariff_level
    label var tariff_level "Levelised tariff (Rs/kWh)"
    rename CapacityOffered capacity
    label var capacity "Capacity offered (MW)"

    gen bid_accepted = regexm(Winner,"Yes")
    replace bid_accepted = . if missing(Winner)
    replace bid_accepted = . if regexm(Winner,"?") // Unsure whether bids won
    label var bid_accepted "Bid won contract (=1)"
    label define dummyLabel 0 "No" 1 "Yes"
    label values bid_accepted dummyLabel
    drop Winner
    tab bid_accepted, missing

    // Key sample restriction
    //   Dropping bidders where it is unknown if they won or not
    drop if missing(bid_accepted) 
    
    gen bid_year  = substr(bid_id,3,4)
    gen bid_month = substr(bid_id,7,2) // Change (May 18): substr(bid_id,5,2) to substr(bid_id,7,2) -rt
    destring bid_year bid_month, replace 
    gen yearmonth = mofd( mdy( bid_month, 1, bid_year ) )
    label var yearmonth "Month"
    format yearmonth %tm
    drop bid_year bid_month

    tab bid_accepted, missing // Check whether any more winners can be determined
    
    sort bid_id
    order bid_id yearmonth
    label data "Bid inventory"
    describe
    save "`WORK'/data_inventory_chars", replace
    clear

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Project outcomes
    import excel "`OUTCOMES'/project_outcomes.xlsx", sheet("Sheet4") firstrow
    keep AuctionID BidID BidIDProvisional BidCase Date ///
      NameofPlant PlantCapacityMW StatusofUnits1Proceed2 ///
      OriginalEstimatedCost LatestEstimatedCost TotalExpenditure ///
      Dateconstructionbegan Dateconstructioncompleted1 DatePPASigned ///
      ActualDateofCommissioning ///
      WhetherPetitionforTariffRevi DatePetitionFiled ///
      WhetherRevisedTariffGranted ///
      WhetherRevisedQuantityGranted NewLevelizedTariffs ///
      IncreasedDecreasedCapacity ///
      IntendedFuelSource5Blende FuelSource1DomesticMarket

    rename AuctionID                     auction_id    
    rename BidID                         bid_id
    rename BidIDProvisional              bid_id_provisional
    rename BidCase                       auction_case
    rename Date                          auction_year
    rename NameofPlant                   plant_name
    rename PlantCapacityMW               plant_capacity
    rename StatusofUnits1Proceed2        project_status
    rename OriginalEstimatedCost         cost_estimate_original
    rename LatestEstimatedCost           cost_estimate_latest
    rename TotalExpenditure              capex_to_date
    rename Dateconstructionbegan         plant_date_started
    rename Dateconstructioncompleted1    plant_date_complete
    rename DatePPASigned                 ppa_date_signed
    rename ActualDateofCommissioning     plant_date_commissioned
    rename WhetherPetitionforTariffRevi  petition_filed
    rename DatePetitionFiled             petition_date
    rename WhetherRevisedTariffGranted   petition_granted_price
    rename WhetherRevisedQuantityGranted petition_granted_quantity
    rename NewLevelizedTariffs           petition_new_price
    rename IncreasedDecreasedCapacity    petition_new_quantity
    rename IntendedFuelSource5Blende     fuel_source_intended
    rename FuelSource1DomesticMarket     fuel_source_actual

    label var auction_id "Auction ID: SSYYYYMM"
    label var bid_id "Bid ID: SSYYYYMM-BBB"

    destring auction_case, replace
    label var auction_case "Case 1 (general) or 2 (site/fuel specified)"
    lab def caseLabel 1 "Not site/fuel specific" 2 "Site/fuel specified"
    label values auction_case caseLabel
    
    label var auction_year "Year of auction"
    label var plant_name "Name of plant"

    destring plant_capacity, replace
    label var plant_capacity "Plant capacity (MW)"
    replace plant_capacity = plant_capacity/1000
    label var plant_capacity "Plant capacity (GW)"

    gen capacity_missing = missing(plant_capacity)
    label var capacity_missing "Capacity missing (=1)"

    gen capacity_gt1 = capacity >= 1
    label var capacity_gt1 "Capacity above 1 GW"

    gen capacity_umpp = regexm(plant_name,"UMPP")
    label var capacity_umpp "Ultra-mega power plant (=1)"

    destring project_status, replace
    label var project_status "Project status"
    lab def statusLabel 0 "Unknown" 1 "Proceed" 2 "Postponed" 3 "Shelved" ///
      4 "Cancelled by firm" 5 "Cancelled by buyer" 6 "Closed"
    label values project_status statusLabel

    label var cost_estimate_original "Original cost estimate (Rs lakh)"
    label var cost_estimate_latest "Latest cost estimate (Rs lakh)"
    label var capex_to_date "Expenditure on plant capital (Rs lakh)"

    rename plant_date_started plant_date_started_str
    gen plant_date_started = date(plant_date_started_str,"DMY",2020)
    label var plant_date_started "Date plant construction began"
    format plant_date_started %td
    drop plant_date_started_str

    rename plant_date_complete plant_date_complete_str
    gen plant_date_complete = date(plant_date_complete_str,"DMY",2020)
    label var plant_date_complete "Date plant construction complete"
    format plant_date_complete %td
    gen plant_construction_ongoing = plant_date_complete_str == "1"
    label var plant_construction_ongoing "Plant construction ongoing (=1)"
    drop plant_date_complete_str

    rename plant_date_commissioned plant_date_commissioned_str
    gen plant_date_commissioned = date(plant_date_commissioned_str,"DMY",2020)
    label var plant_date_commissioned "Date plant commissioned"
    format plant_date_commissioned %td
    drop plant_date_commissioned_str

    rename petition_date petition_date_str
    gen petition_date = date(petition_date_str,"MDY",2020)
    label var petition_date "Bidder petition, date filed"
    format petition_date %td
    drop petition_date_str
    
    gen petition_year = year(petition_date)
    label var petition_year "Bidder petition, year filed"

    gen petition_ym = mofd(petition_date)
    label var petition_ym "Bidder petition, month filed"

    // Code variables into dummies
    local DUMMIES petition_filed petition_granted_price
    local DUMMIES `DUMMIES' petition_granted_quantity petition_new_price
    local DUMMIES `DUMMIES' petition_new_quantity
    label define dummyLabel 0 "No" 1 "Yes"
    
    foreach v of varlist `DUMMIES' {
      rename `v' `v'_str
      gen `v' = regexm(`v'_str,"Yes")
      label values `v' dummyLabel
    }
    sum `DUMMIES'

    label var petition_filed "Bidder petitioned for new tariff (=1)"
    label var petition_granted_price "Bidder petition granted on price (=1)"
    label var petition_granted_quantity "Bidder petition granted on quantity (=1)"

    egen petition_granted = rowmax(petition_granted_price petition_granted_quantity)
    label var petition_granted "Bidder petition granted (=1)"

    label var petition_new_price "New levelized tariff (Rs/kWh)"
    label var petition_new_quantity "New quantity (MW)"

    // Code fuel source to the marginal source assuming prices are ordered as:
    //   Imported (4) >= blended (5) > domestic market (1) > linkage (2)
    //   > captive (3).
    foreach v of varlist fuel_source_intended fuel_source_actual {
        rename `v' `v'_str
        gen `v' = .
        replace `v' = 4 if regexm(`v'_str,"4") // Imported
        replace `v' = 5 if regexm(`v'_str,"5") & missing(`v') // Blended
        replace `v' = 1 if regexm(`v'_str,"1") & missing(`v') // Dom. market
        replace `v' = 2 if regexm(`v'_str,"2") & missing(`v') // Dom. linkage
        replace `v' = 3 if regexm(`v'_str,"3") & missing(`v') // Dom. captive
    }

    // Recode fuel source based on intended and final fuel source
    //   Logic is to use final fuel source, but replace with intended fuel
    //   source if the project was not brought to completion.
    gen fuel_source = fuel_source_actual
    label var fuel_source "Fuel source for plant"
    replace fuel_source = fuel_source_intended if missing(fuel_source_actual)
    replace fuel_source = 4 if fuel_source == 5
    replace fuel_source = 2 if missing(fuel_source) & !missing(bid_id)
    lab def fuelLabel 1 "Domestic market" 2 "Domestic linkage" 3 "Captive" ///
      4 "Imported" 5 "Blended"
    label values fuel_source fuelLabel
    label values fuel_source_intended fuelLabel
    label values fuel_source_actual fuelLabel
    tab fuel_source

    // Dummy out fuel source
    gen coal_captive = fuel_source == 3
    label var coal_captive "Coal captive (=1)"

    gen coal_domestic = inlist(fuel_source,1,2)
    label var coal_domestic "Coal domestic (=1)"

    gen coal_imported = fuel_source == 4
    label var coal_imported "Coal imported (=1)"

    gen coal_missing = missing(fuel_source)
    label var coal_missing "Coal source unknown (=1)"
    
    // Year-month of bidding
    gen auction_month = substr(auction_id,5,2)
    destring auction_year auction_month, replace 
    gen yearmonth = mofd( mdy( auction_month, 1, auction_year ) )
    drop auction_month
    label var yearmonth "Month"
    format yearmonth %tm
    sort yearmonth auction_id

    // This bid_id is a duplicate. However, it appears the same plant does have
    //   two PPAs under two different bids, so the observation is legitimate.
    // drop if bid_id == "MH200908-003" & petition_filed == 0
    drop if bid_id == "MH200908-003" & plant_name == "Nasik TPP"

    drop if missing(bid_id)
    drop if bid_id == "."
    sort bid_id
    order bid_id
    label data "Project outcomes including tariff revisions and expenditures"
    describe
    save "`WORK'/project_outcomes", replace


    
    clear

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Historical coal prices
    insheet using "`EXTERNAL'/imported_newc/coal_price_newcastle.csv", comma names
    rename date date_string
    gen date = date(date_string,"MDY",2030)
    gen yearmonth = mofd( date )
    label var yearmonth "Month"
    format yearmonth %tm
    drop date date_string 

    tsset yearmonth
    rename newc coal_price
    label var coal_price "Coal price (USD per ton)"

    order yearmonth
    sort yearmonth
    label data "Coal prices (Newcastle Index, formerly Barlow-Jonkers Index)"
    describe
    save "`WORK'/coal_prices", replace
    clear

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Coal price futures 
    import excel "`EXTERNAL'/imported_newc/coal_price_newcastle_futures.xlsx", ///
      sheet("Worksheet") firstrow
    gen monthoffset = substr(Ticker, 3,2)
    gen month = 05
    gen year  = 2018
    destring month year monthoffset, replace
    gen yearmonth = mofd(mdy(month, 1, year))

    // Top value is for May Future, which has since expired, thus our
    //   "offset" (expiration date) is invalid here. 
    replace monthoffset = monthoffset-1  
    replace yearmonth = yearmonth+monthoffset
    format yearmonth %tm
    save "`WORK'/coal_price_futures.dta", replace
    clear

}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare project outcomes data
if "`PREP_OUTCOMES'" == "1" {

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Load project outcomes data
    use "`WORK'/project_outcomes"
    sort yearmonth auction_id
    tempfile CLEAN_OUTCOMES
    save "`CLEAN_OUTCOMES'", replace
    clear
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Prepare price shock data
    // Load data on prices
    use "`WORK'/coal_prices.dta"
    
    // Convert price of coal into equivalent cost of fuel per kWh
    //      USD  =  1 kg      * 1 ton   * 1 kcal   * 11615 btu  * 50 INR
    //      ton     6300 kcal   1000 kg   3.96 btu   1 kwh        1 USD
    gen price = coal_price / 6300 / 1000 / 3.96 * 11615 * `INRPERUSD'
    label var price "Coal price (INR per kWh)"
    
    tssmooth ma price_l1y = price, window(11 1 0)
    tssmooth ma price_l2y = price, window(23 1 0)
    tssmooth ma price_l5y = price, window(59 1 0)
    
    tssmooth ma price_f1y = price, window(0 0 12)
    tssmooth ma price_f2y = price, window(0 0 24)
    tssmooth ma price_f5y = price, window(0 0 60)
    
    gen price_shock_l1_f1 = price_f1y - price_l1y
    label var price_shock_l1_f1 "Coal price shock (1 year after $-$ before)"
    gen price_shock_l2_f2 = price_f2y - price_l2y
    label var price_shock_l2_f2 "Coal price shock (2 years after $-$ before)"
    gen price_shock_l5_f5 = price_f5y - price_l5y
    label var price_shock_l5_f5 "Coal price shock (5 years after $-$ before)"
    gen price_shock_l5_f1 = price_f1y - price_l5y
    label var price_shock_l5_f1 "Coal price shock (1 year after $-$ 5 years before)"
    
    drop if missing(yearmonth)
    sort yearmonth
    tempfile PRICE_SHOCKS
    save "`PRICE_SHOCKS'", replace
    clear
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Merge outcomes and price shocks
    use "`CLEAN_OUTCOMES'"
    
    merge m:1 yearmonth using "`PRICE_SHOCKS'", gen(mergePriceShocks)
    lab def mergePriceShockLabel 1 "Outcomes" 2 "Shocks" 3 "Both"
    label values mergePriceShocks mergePriceShockLabel
    tab mergePriceShocks, missing
    keep if mergePriceShocks != 2
    
    // De-mean shock
    keep if !missing(petition_filed)
    foreach V of varlist price_shock_l1_f1 price_shock_l2_f2 ///
      price_shock_l5_f5 price_shock_l5_f1 {
        egen `V'_mean = mean(`V')
        replace `V' = `V' - `V'_mean
        drop `V'_mean
    }
    
    gen fuel_imported_shock_l5_f5 = coal_imported * price_shock_l5_f5
    label var fuel_imported_shock_l5_f5 "Coal imported (=1) $\times$ coal price shock"
    
    label data "Project outcome data, cleaned and with price shocks"
    save "`WORK'/clean_outcomes.dta", replace
    clear
    
} /* End PREP_OUTCOMES */


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare indexation data
if "`PREP_INDEXATION'" == "1" {

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Load indexation decisions and bidder characteristics
    insheet using "`INVENTORY'/bid_inventory_with_fraction_indexed.txt"
    
    // Clean variables
    lab var auction_id_provisional "Auction ID"
    lab var bid_id_provisional "Bid ID"
    lab var company_id "Company ID"
    lab var auction_yyyymm "Auction year-month"
    lab var bidderfoundingdate "Date of founding"
    lab var date_founding_parent "Date of founding, parent company"
    lab var date_founding_child "Date of founding, child company"
    lab var foreign_ "Foreign ownership share"
    lab var public_privatecompany_psu_govern "Ownership"
    lab var domesticfirm_foreignownership "Foreign or domestic"
    lab var levelisedtariff "Bid price (Rs/kWh)"
    lab var capacityoffered "Capacity offered (MW)"
    lab var frac_indexed "Share of bid value indexed"
    lab var frac_early5 "Share of bid value in first 5 years"
    lab var umpp "Ultra-mega Power Plant (=1)"
    lab var case2 "Specific-asset project (=1)"
    lab var coal_captive "Coal source captive (=1)"
    lab var coal_imported "Coal source imported (=1)"
    lab var coal_domestic "Coal source domestic (=1)"
    lab var trailing_price "Coal price (INR/ton)"
    
    gen auction_year = floor(auction_yyyymm/100)
    label var auction_year "Year of bidding"
    replace auction_year = 2010 if auction_yyyymm == 2010
    
    gen auction_month_num = mod(auction_yyyymm,100)
    label var auction_month_num "Month of bidding"
    replace auction_month_num = 6 if auction_yyyymm == 2010
    
    gen auction_month = mofd(mdy(auction_month_num,1,auction_year))
    label var auction_month "Year-month of auction"
    format auction_month %tm

    destring date_founding_parent, replace force
    destring date_founding_child, replace force
    replace bidderfoundingdate = date_founding_parent ///
      if missing(bidderfoundingdate) & !missing(date_founding_parent)
    gen bidder_age = auction_year - bidderfoundingdate
    label var bidder_age "Age of bidder"
    gen bidder_age_missing = missing(bidder_age)
    label var bidder_age_missing "Age of bidder missing (=1)"
    replace bidder_age = 0 if bidder_age_missing
    
    destring foreign_, replace force
    rename foreign_ foreign_ownership
    
    gen foreign_ownership_missing = missing(foreign_ownership)
    label var foreign_ownership_missing "Foreign ownership missing (=1)"
    replace foreign_ownership = 0 if foreign_ownership_missing
    
    gen ownership = .
    label var ownership "Type of ownership"
    replace ownership = 2 if public_privatecompany_psu_govern == "Private"
    replace ownership = 3 if public_privatecompany_psu_govern == "Public"
    replace ownership = 1 if missing(public_privatecompany_psu_govern)
    label define owner_label 1 "Other" 2 "Privately held" 3 "Publicly held"
    label values ownership owner_label
    tab ownership
    
    gen ownership_public = ownership == 3
    gen ownership_private = ownership == 2
    
    destring frac_indexed, replace force
    destring frac_early5, replace force
    
    sort bid_id_provisional
    describe
    
    cd "`INVENTORY'"
    label data "Bids with fraction indexed"
    save bid_inventory_with_fraction_indexed, replace
    clear

} /* End PREP_INDEXATION */


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare Coalgate data on connectedness
if "`PREP_COALGATE'" == "1" {

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Clean coalgate variables
    insheet using "`COALGATE'/intermediate/cag_coal_blocks_company_level.txt"
    
    lab var serial_number  "Serial number (CAG report)"
    lab var company_id     "Company ID (three-letter code)"
    lab var company_name   "Company name (CAG report)"
    lab var block_name     "Coal block name"
    lab var block_date     "Coal block allocation date"
    lab var company_sector "Sector of coal block allocation"
    lab var qty_mt         "Coal quantity (MT)"        
    lab var qty_pct90      "Coal quantity (MT*90%)"
    lab var grade          "Coal grade range"
    lab var grade_assumed  "Coal grade assumed for pricing"
    lab var price_notified "Coal price (Rs/ton)"
    lab var cost           "Coal extraction cost (Rs/ton)"
    lab var revenue_per_ton "Coal price less cost (Rs/ton)"
    lab var benefit_rs_million "Value of coal given (Rs million)"
    lab var benefit_rs_crore   "Value of coal given (Rs crore)"
    
    drop qty_pct90 grade benefit_rs_crore
    
    gen sector_power = regexm(company_sector,"Power")
    label var sector_power "Coal block for power (=1)"
    
    gen sector_metals = 1 - sector_power
    label var sector_metals "Coal block for metals (=1)"
    
    gen coal_value = benefit_rs_million / 1000
    label var coal_value "Value of coal given (Rs billion)"
    
    rename block_date block_date_string
    gen block_date = date(block_date_string,"DMY",2020)
    format block_date %td
    label var block_date "Date block was awarded"
    
    gen block_month = mofd(block_date)
    label var block_month "Year-month block was awarded"
    format block_month %tm
    
    // Collapse to company by sector level
    sort company_id sector_power block_month
    collapse (sum) qty_mt coal_value (firstnm) block_month, ///
      by(company_id sector_power)
    
    lab var qty_mt     "Coal quantity (MT)"
    gen qty_bt = qty_mt / 1000
    lab var qty_bt     "Coal quantity (BT)"
    drop qty_mt
    
    lab var coal_value "Value of coal given (Rs billion)"
    gsort company_id -sector_power
    
    reshape wide qty_bt coal_value block_month, i(company_id) j(sector_power)
    
    gen coal_sector_power = !missing(qty_bt1)
    label var coal_sector_power "Coal block for power (=1)"
    
    gen coal_sector_metals = !missing(qty_bt0)
    label var coal_sector_metals "Coal block for metals (=1)"
    
    rename qty_bt0      coal_qty_metals
    rename coal_value0  coal_val_metals
    rename block_month0 coal_month_metals
    
    rename qty_bt1      coal_qty_power
    rename coal_value1  coal_val_power  
    rename block_month1 coal_month_power
    
    lab var coal_qty_metals   "Coal quantity (metals, BT)"
    lab var coal_val_metals   "Coal value (metals, Rs billion)"
    lab var coal_month_metals "Month of coal award (metals)"
    
    lab var coal_qty_power   "Coal quantity (power, BT)"
    lab var coal_val_power   "Coal value (power, Rs billion)"
    lab var coal_month_power "Month of coal award (power)"
    
    tab coal_sector_power
    codebook company_id if coal_sector_power
    
    sort company_id
    label data "CAG data on coal block allocation and value"
    describe
    save "`COALGATE'/clean/cag_coal_blocks.dta", replace
    clear

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Merge bid inventory (complete, regardless of whether bidding data is
    //   available for components) with fraction of bid indexed

    use "`WORK'/data_inventory", replace
    keep bid_id_provisional company_id yearmonth date_founding* ///
      publicprivate bidderfoundingdate tariff_level bid_accepted
    sort bid_id_provisional

    gen auction_year = year(dofm(yearmonth))
    label var auction_year "Year of bidding"

    destring date_founding_parent, replace force
    destring date_founding_child, replace force
    replace bidderfoundingdate = date_founding_parent ///
      if missing(bidderfoundingdate) & !missing(date_founding_parent)
    gen bidder_age = auction_year - bidderfoundingdate
    label var bidder_age "Age of bidder (years)"
    gen bidder_age_missing = missing(bidder_age)
    label var bidder_age_missing "Age of bidder missing (=1)"
    replace bidder_age = 0 if bidder_age_missing
    tab bidder_age, missing

    gen ownership = .
    label var ownership "Type of ownership"
    rename publicprivatecompanypsugovernmen public_privatecompany_psu_govern
    replace ownership = 2 if public_privatecompany_psu_govern == "Private"
    replace ownership = 3 if public_privatecompany_psu_govern == "Public"
    replace ownership = 1 if missing(public_privatecompany_psu_govern)
    label define owner_label 1 "Other" 2 "Privately held" 3 "Publicly held"
    label values ownership owner_label
    
    gen ownership_public = ownership == 3
    gen ownership_private = ownership == 2
    tab ownership_public, missing
    label var ownership_public "Publicly-owned firm (=1)"

    cd "`INVENTORY'"
    merge 1:1 bid_id_provisional using bid_inventory_with_fraction_indexed, ///
      generate(mergeFractionIndexed) update replace
    lab def mergeFractionLabel 1 "Bid inventory" 2 "Fraction indexed" 3 "Both"
    label values mergeFractionIndexed mergeFractionLabel
    tab mergeFractionIndexed
    label var mergeFractionIndexed "Whether indexation known for bid (2 or 3)"
    cd "`STATA'"

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Merge bidding and coalgate data based on bid_id
    
    sort company_id
    merge m:1 company_id using "`COALGATE'/clean/cag_coal_blocks.dta", ///
      generate(merge_blocks)
    lab def merge_blocks_label 1 "In bidding data"
    lab def merge_blocks_label 2 "In coalgate data", add
    lab def merge_blocks_label 3 "In both", add
    label var merge_blocks merge_blocks_label
    tab merge_blocks, missing

    // What fraction of companies are in coalgate data?
    sort company_id
    by company_id: gen company_id_first = _n == 1
    label var company_id_first "First observation of company"
    tab merge_blocks if company_id_first
    
    drop if merge_blocks == 2 // Drop observations only from coalgate
    tab merge_blocks, missing 
    
    // Code coalgate variables for companies not matched
    replace coal_sector_power  = 0 if merge_blocks == 1
    replace coal_sector_metals = 0 if merge_blocks == 1
    replace coal_qty_metals    = 0 if merge_blocks == 1
    replace coal_val_metals    = 0 if merge_blocks == 1
    replace coal_qty_power     = 0 if merge_blocks == 1
    replace coal_val_power     = 0 if merge_blocks == 1

    replace coal_qty_power = 0 if coal_sector_power == 0
    egen mean_coal_qty_power = mean(coal_qty_power) if coal_sector_power
    gen coal_qty_power_dm = coal_qty_power - mean_coal_qty_power
    label var coal_qty_power_dm "Coal quantity (billion tons)"
    replace coal_qty_power_dm = 0 if missing(coal_qty_power_dm)

    egen mean_coal_val_power = mean(coal_val_power) if coal_sector_power
    gen coal_val_power_dm = coal_val_power - mean_coal_val_power
    label var coal_val_power_dm "Coal value (Rs billion)"
    replace coal_val_power_dm = 0 if missing(coal_val_power_dm)
    
    gen sample_with_bid_parts = !missing(frac_indexed)
    label var sample_with_bid_parts "Sample of bids with indexation"

    sort bid_id_provisional
    label data "CAG data on coal block allocation, with bid inventory"
    describe
    save cag_coal_blocks_with_inventory.dta, replace

    keep bid_id_provisional coal_sector_power coal_qty_power
    order bid_id_provisional
    export delimited using cag_coal_blocks_with_inventory.txt, ///
      delimiter(tab) replace
    
    clear

} /* End PREP_COALGATE */
	
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                               End DATA PREP
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


  

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                            Paper Exhibits
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Figure 1: Growth in Capacity by Ownership
if `FIG_GENERATION_OWNERSHIP' == 1 {

import excel "`EXTERNAL'/cea_generation_capacity/sector_split", ///
  sheet("Total Generation Capacity") firstrow

// Creating variables for stacked area graph
replace Total = 0 if Total >= 70000
replace Central = Central + State 
replace Private = Private + Central 

// Converting MW to GW
foreach V of varlist Total State Central Private {
  replace `V' = `V' / 1000
}

gen Year = substr(Date,7,4)
destring(Year), replace
save "`EXTERNAL'/cea_generation_capacity/sector_split_cleaned", replace

set scheme s2mono
tw (area Total Year, yaxis(1))   ///
    (area Private Year, yaxis(1)) ///
    (area Central Year, yaxis(1)) ///
    (area State Year, yaxis(1)) ///
    (pcarrowi 0 2006 400 2006, msize(zero) color(gs0)) ///
    (pcarrowi 0 2011 400 2011, msize(zero) color(gs0) lpattern(dash)), ///
    tlabel(1950(10)2020) tmtick(1950(5)2020) tscale(range(1945 2025)) ///
    text(40 1970 "Total") text(250 2018 "Private", place(e)) ///
    text(140 2018 "Central", place(e)) text(50 2018 "State", place(e)) ///
    text(395 2005.5 "New bidding rules", placement(sw)) ///
    text(395 2011.5 "New rules" "+ five years", placement(se) justification(left)) ///
    ytitle("Generation capacity (GW)") xtitle("Year") ///
    graphregion(color(white)) plotregion(color(white)) bgcolor(white) ///
    legend(off)
graph export "`OUTFIG'/sector_history_and_bids.pdf", replace
clear

}

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Figure 3: Timing of Power Procurement and Coal Price Shocks
if `FIG_COAL_PRICE_WHIST' == 1 {

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Load data on bids
insheet using "`INVENTORY'/data_inventory_master.txt", names
keep bid_id levelisedtariff capacityoffered winner
drop if bid_id == ""
drop if bid_id == "N/A" 

gen bid_year  = substr(bid_id,3,4)
gen bid_month = substr(bid_id,7,2) // Change (May 17): substr(bid_id,5,2) to substr(bid_id,7,2) -rt
destring bid_year bid_month, replace 
gen yearmonth = mofd( mdy( bid_month, 1, bid_year ) )
label var yearmonth "Month"
format yearmonth %tm
preserve

collapse (mean) capacityoffered, by(bid_year)
sort bid_year
gen place_holder = bid_year - 2005

tempfile ANNUAL
save "`ANNUAL'"
clear

restore
gen place_holder = 999
gen number_bids    = 1
destring capacityoffered, replace force // Ryo-- Check why missing capacity obs?
append using "`ANNUAL'"
sort place_holder

replace capacityoffered  = capacityoffered[1] if missing(capacityoffered) & bid_year == 2006
replace capacityoffered  = capacityoffered[2] if missing(capacityoffered) & bid_year == 2007
replace capacityoffered  = capacityoffered[3] if missing(capacityoffered) & bid_year == 2008
replace capacityoffered  = capacityoffered[4] if missing(capacityoffered) & bid_year == 2009
replace capacityoffered  = capacityoffered[5] if missing(capacityoffered) & bid_year == 2010
replace capacityoffered  = capacityoffered[6] if missing(capacityoffered) & bid_year == 2011
replace capacityoffered  = capacityoffered[7] if missing(capacityoffered) & bid_year == 2012
replace capacityoffered  = capacityoffered[8] if missing(capacityoffered) & bid_year == 2013
replace capacityoffered  = capacityoffered[9] if missing(capacityoffered) & bid_year == 2014
replace capacityoffered  = capacityoffered[10] if missing(capacityoffered) & bid_year == 2015

drop if bid_id==""

collapse (sum) number_bids total_capacity = capacityoffered, by(yearmonth)

tabstat total_capacity, stats(sum)
label var number_bids "Number of bids"
replace total_capacity = total_capacity / 1000
label var total_capacity "Capacity (GW)"

sort yearmonth
list // Ryo-- Check why missing dates for some bids?
describe
tempfile MONTHLY_BIDS
save "`MONTHLY_BIDS'"
clear

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Load data on prices
use "`WORK'/coal_prices"

// Merge bid and price data
merge 1:1 yearmonth using "`MONTHLY_BIDS'", gen(merge_bids)
replace number_bids    = 0 if merge_bids != 3
replace total_capacity = 0 if merge_bids != 3

// Drop bids after SBDs revised in 2013
replace number_bids = 0 if yearmonth > tm(2013m12)


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Plot prices and number of bids / capacity offered

clonevar coal_price_backup = coal_price

foreach PANEL of numlist 3(-1)1 {

    // Plot prices up to the start of bidding only
    if `PANEL' == 2 {
        replace coal_price = . if yearmonth > mofd( td(31dec2006) )
    }

    // Do not plot any prices
    if `PANEL' == 1 {
        replace coal_price = . 
    }

    tw ///
        (bar total_capacity yearmonth, yaxis(1) barwidth(2) color(gs10) ) ///
        (line coal_price yearmonth, lcolor(black) lpattern(solid) yaxis(2) ylabel(0(50)200, axis(2))), ///
        tlabel(1990m1(60)2015m1) tmtick(1988m1(12)2018m1) ///
        legend(order(1 "Capacity offered" 2 "Price")) ///
        graphregion(color(white)) plotregion(color(white)) bgcolor(white) ///
        legend(region(lcolor(white)) cols(1))
    graph export "`OUTFIG'/fig_line_coal_price_with_capacity_panel`PANEL'.pdf", replace

    tw ///
        (bar number_bids yearmonth, yaxis(1) barwidth(2) color(gs10) ) ///
        (line coal_price yearmonth, lcolor(black) lpattern(solid) yaxis(2) ylabel(0(50)200, axis(2))), ///
        tlabel(1990m1(60)2015m1) tmtick(1988m1(12)2018m1) ///
        legend(order(1 "Number of bids" 2 "Price")) ///
        graphregion(color(white)) plotregion(color(white)) bgcolor(white) ///
        legend(region(lcolor(white)) cols(1))
     graph export "`OUTFIG'/fig_line_coal_price_with_bids_panel`PANEL'.pdf", replace

}

drop coal_price
rename coal_price_backup coal_price
sort yearmonth
preserve
clear

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Plot petition filing against coal prices
cd "`WORK'"
use clean_outcomes

keep petition_year capacity_umpp coal_imported coal_domestic ///
  auction_year yearmonth bid_id petition_filed petition_ym

// Restrict to observations that have known petition status
tab petition_filed, missing
keep if !missing(petition_filed)

collapse (sum) petition_filed, by(petition_year)
label var petition_filed "Petitions filed"

gen yearmonth = mofd( mdy(6,1,petition_year) )
label var yearmonth "Petition filing year"
tab yearmonth
sort yearmonth

tempfile PETITIONDATES
save "`PETITIONDATES'", replace
clear

restore
merge 1:1 yearmonth using "`PETITIONDATES'", generate(mergePetitions)
replace petition_filed = 0 if missing(petition_filed)

tw ///
   (bar petition_filed yearmonth, yaxis(1) barwidth(12) color(gs10) ) ///
   (line coal_price yearmonth, lcolor(black) lpattern(solid) yaxis(2) ylabel(0(50)200, axis(2))), ///
   tlabel(1990m1(60)2015m1) tmtick(1988m1(12)2018m1) ///
   legend(order(1 "Number of petitions" 2 "Price")) ///
   graphregion(color(white)) plotregion(color(white)) bgcolor(white) ///
   legend(region(lcolor(white)) cols(1))
graph export "`OUTFIG'/fig_line_coal_price_with_petition_filing.pdf", replace

}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 1: Summary of Bids and Renegotiation
if `TAB_BID_OUTCOMES' == 1 {

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Merge bids and project outcomes
use "`WORK'/data_inventory"
merge 1:1 bid_id using "`WORK'/project_outcomes", generate(mergeRevisions)
lab def mergeLabel 1 "Bids" 2 "Revisions" 3 "Both"
lab values mergeRevisions mergeLabel
tab mergeRevisions

gen outcome_known = bid_accepted & !missing(petition_filed) 
label var outcome_known "Whether petition filed is known (=1)"

// Sample restrictions based on lack of data
//   The cases of missing winner status should be investigated
drop if missing(tariff_level)
drop mergeRevisions

codebook auction_id

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Collapse to annual totals / means
gen bid_count = 1
egen petition_granted_any = rowmax(petition_granted_price petition_granted_quantity)
gen bid_year = year( dofm(yearmonth) )

pause

preserve
collapse (sum) bid_count bid_accepted outcome_known petition_filed ///
  petition_granted_price petition_granted_quantity petition_granted_any ///
  (mean) tariff_level capacity petition_new_price ///
  petition_new_quantity, by(bid_year)

tempfile YEARLY
save "`YEARLY'"
clear

// Collapse to overall total
restore
collapse (sum) bid_count bid_accepted outcome_known petition_filed ///
  petition_granted_price petition_granted_quantity petition_granted_any ///
  (mean) tariff_level capacity petition_new_price ///
  petition_new_quantity
gen bid_year = 2013

// Append annual and total data
append using "`YEARLY'"
sort bid_year
tostring bid_year, replace
replace bid_year = "Total" if bid_year == "2013"

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Create outcome table

// Round off numeric values for a cleaner-looking table
replace tariff_level               = round(tariff_level, 0.1)
replace capacity                   = round(capacity, 1)
replace petition_new_price         = round(petition_new_price, 0.1)
replace petition_new_quantity      = round(petition_new_quantity, 0.1)
format petition_new_price %03.1f
replace petition_new_price         = . if petition_new_price == 0
replace petition_new_quantity      = . if petition_new_quantity == 0

listtab bid_year bid_count bid_accepted outcome_known petition_filed ///
  petition_granted_any tariff_level capacity ///
  using "`OUTTAB'/tab_bid_level_outcomes.tex", replace ///
  type rstyle(tabular) missnum(-) ///
  head("\begin{table}[ht] \centering \caption{Summary of Bids and Renegotiation}\label{tab:bidsummary} \begin{tabular}{lccccccc} \toprule \multirow{2}{*}{Year} & \multirow{2}{*}{Bids} & \multirow{2}{*}{Winners}  & \multicolumn{3}{c}{Petition} & \multicolumn{2}{c}{Mean} \\ \cmidrule(lr){4-6} \cmidrule(lr){7-8} & & & Known & Filed & Granted & Tariff & Capacity \\ (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) \\ \midrule") ///
  foot("\bottomrule\end{tabular}\end{table}")

clear

}

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 2: Cost shocks and renegotiation
//   also
// Table 3: Firm connectedness and renegotiation
if `TAB_REG_RENEGOTIATION_NEW' == 1 {

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Read outcomes data with price shocks
use "`WORK'/clean_outcomes.dta"

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Merge in coalgate data for variables on
// connectedness and indexation

cd "`COALGATE'/clean"
sort bid_id_provisional
merge 1:m bid_id_provisional using cag_coal_blocks_with_inventory, ///
  generate(mergeCoalgate)
lab def mergeCoalgateLabel 1 "Outcome data" 2 "Coalgate / inventory" 3 "Both"
label values mergeCoalgate mergeCoalgateLabel
tab mergeCoalgate
codebook bid_id_provisional

list bid_id_provisional plant_name if mergeCoalgate == 1
tab coal_sector_power mergeCoalgate, missing

// Calculate number of bidders and winners in the auction
sort auction_id_provisional
by auction_id_provisional: egen num_winners = total(bid_accepted)
label var num_winners "Number of winning bidders"
replace num_winners = 1 if num_winners == 0 // If winners aren't known

gen dummy = 1
by auction_id_provisional: egen num_bidders = total(dummy)
label var num_bidders "Number of bidders"

gen multiple_winners = num_winners > 1
label var multiple_winners "Auction has multiple winners"

gen bidders_per_winner = num_bidders / num_winners
label var bidders_per_winner "Bidders per winner"

sort auction_id_provisional
by auction_id_provisional: gen first_in_auction = _n == 1
sum num_winners num_bidders bidders_per_winner if first_in_auction

gen sample_with_outcomes = (mergeCoalgate == 3)
label var sample_with_outcomes "Bidding data with outcomes observed (=1)"
keep if sample_with_outcomes

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Estimation petition filing as function of
//   interactions of fuel source and price shock

cd "`ROOT'/code"
reg petition_filed price_shock_l5_f5, robust
est store petition1

reg petition_filed price_shock_l5_f5 capacity_umpp, ///
    robust
est store petition2

reg petition_filed capacity_umpp ///
  coal_imported coal_domestic, robust
est store petition3

reg petition_filed price_shock_l5_f5 fuel_imported_shock_l5_f5 ///
  capacity_umpp ///
  coal_imported coal_domestic, robust
est store petition4
gen insample = e(sample) == 1

esttab petition1 petition2 petition3 petition4 ///
    using "`OUTTAB'/tab_reg_petition_final.tex", ///
    title("Cost Shocks and Renegotiation") ///
    order(price_shock_l5_f5 fuel_imported_shock_l5_f5 ///
          capacity_umpp capacity_missing coal_imported coal_domestic) ///
    b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    alignment(D{.}{.}{-1}) label width(1\hsize)  ///
    replace nomtitles booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{5}{p{0.98\hsize}}{\footnotesize The table shows linear probability models for whether an auction winner filed a petition for renegotiation of tariffs. The explanatory variables are the shock to coal prices around the time of bidding, a dummy for whether a plant is an ultra-mega power plant (the largest projects) and dummies for the source of fuel used by the plant. The coal price shock is measured as the difference in coal prices in a five-year moving period after the auction date relative to a five-year moving period before the auction. The units for the coal price shock are converted from USD per ton, the original price of the coal price index, to INR per kWh, by assuming a calorific value of coal of 6300 kcal per kg and a plant heat rate of 11615 btu. Hence a one unit change in coal prices is the change in coal prices that would cause a plant with this efficiency and using this grade of coal to experience a one INR per kWh increase in the marginal cost of power generation. The coal price shock has been demeaned. Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Estimation petition filing as function of bid indexation 

gen frac_indexed_missing = missing(frac_indexed)
label var frac_indexed_missing "Missing fraction indexed (=1)"
replace frac_indexed = 0 if frac_indexed_missing

gen price_shock_X_indexed = price_shock_l5_f5 * frac_indexed 
label var price_shock_X_indexed "Coal price shock (Rs/kWh) $\times$ Share indexed"

label var coal_sector_power "Connected firm (=1)"

local FIRMCONTROLS bidder_age ownership_public

// Indexation
reg petition_filed price_shock_l5_f5, robust
est store petition5

reg petition_filed price_shock_l5_f5 frac_indexed price_shock_X_indexed ///
  frac_indexed_missing, robust
est store petition6

esttab petition5 petition6 ///
    using "`OUTTAB'/tab_reg_petition_robustness_indexation.tex", ///
    title("Cost Shocks and Renegotiation, Robustness Checks (Indexation)") ///
    order(price_shock_l5_f5 price_shock_X_indexed frac_indexed ///
          frac_indexed_missing) ///
    b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    alignment(D{.}{.}{-1}) label width(1\hsize)  ///
    replace nomtitles booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{3}{p{0.98\hsize}}{\footnotesize The table shows linear probability models for whether an auction winner filed a petition for renegotiation of tariffs. The explanatory variables are . . . Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Estimation petition filing as function of bidder connectedness

local BIDCONTROLS tariff_level frac_indexed
local PROJCONTROLS price_shock_l5_f5 fuel_imported_shock_l5_f5 ///
  capacity_umpp coal_imported coal_domestic

// Outcome: petition filed
reg petition_filed coal_sector_power, robust
sum petition_filed
estadd scalar ymean = r(mean)
sum petition_filed if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition7

reg petition_filed coal_sector_power `FIRMCONTROLS', robust
sum petition_filed
estadd scalar ymean = r(mean)
sum petition_filed if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition8

reg petition_filed coal_sector_power `FIRMCONTROLS' `PROJCONTROLS', robust
sum petition_filed
estadd scalar ymean = r(mean)
sum petition_filed if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition9

reg petition_filed coal_sector_power `FIRMCONTROLS' `BIDCONTROLS', robust
sum petition_filed
estadd scalar ymean = r(mean)
sum petition_filed if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition10

reg petition_filed coal_sector_power `FIRMCONTROLS' `PROJCONTROLS' `BIDCONTROLS', robust
sum petition_filed
estadd scalar ymean = r(mean)
sum petition_filed if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition11

// Outcome: petition granted
reg petition_granted coal_sector_power, robust
sum petition_granted
estadd scalar ymean = r(mean)
sum petition_granted if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition12

reg petition_granted coal_sector_power `FIRMCONTROLS', robust
sum petition_granted
estadd scalar ymean = r(mean)
sum petition_granted if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition13

reg petition_granted coal_sector_power `FIRMCONTROLS' `PROJCONTROLS', robust
sum petition_granted
estadd scalar ymean = r(mean)
sum petition_granted if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition14

reg petition_granted coal_sector_power `FIRMCONTROLS' `BIDCONTROLS', robust
sum petition_granted
estadd scalar ymean = r(mean)
sum petition_granted if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition15

reg petition_granted coal_sector_power `FIRMCONTROLS' `PROJCONTROLS' `BIDCONTROLS', robust
sum petition_granted
estadd scalar ymean = r(mean)
sum petition_granted if !coal_sector_power
estadd scalar ymunc = r(mean)
est store petition16

esttab petition7 petition8 petition9 petition10 petition11 ///
       petition12 petition13 petition14 petition15 petition16 ///
    using "`OUTTAB'/tab_reg_petition_robustness_connections.tex", ///
    title("Cost Shocks and Renegotiation, Robustness Checks (Connections)") ///
    mtitles("Filed" "Filed" "Filed" "Filed" "Filed" ///
            "Granted" "Granted" "Granted" "Granted" "Granted") ///
    order(coal_sector_power `BIDCONTROLS') ///
    indicate("Fuel controls = `FIRMCONTROLS'" ///
             "Firm controls = `PROJCONTROLS'" ///
             "Bid controls =  `BIDCONTROLS'", labels("Yes" "")) ///
    b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    label width(1\hsize)  ///
    replace booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{11}{p{0.98\hsize}}{\footnotesize The table shows linear probability models for whether an auction winner filed a petition for renegotiation of tariffs. The explanatory variables are . . . Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Petition filing table for revision of paper 
//   Petition filing correlation with firm connectedness

esttab petition7 petition8 petition12 petition13 ///
    using "`OUTTAB'/tab_reg_petition_revision.tex", ///
    title("Connectedness and Renegotiation") ///
    order(coal_sector_power) ///
    mtitles("Filed" "Filed" "Granted" "Granted") ///
    indicate("Firm controls = `FIRMCONTROLS'", labels("Yes" "")) ///
    b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    stats(ymean ymunc N, fmt(2 2 0) ///
          labels("Mean dep. var." "Mean dep. var.: unconnected" "Observations")) ///
    alignment(D{.}{.}{-1}) label width(0.7\hsize) noconstant ///
    replace booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{5}{p{0.68\hsize}}{\footnotesize The table shows linear probability models for whether an auction winner filed a petition for renegotiation of tariffs. The explanatory variables are a dummy for whether a firm is connected (received coal below market rates in the coalgate scandal) and controls for firm age and whether a firm is publicly traded. Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Petition filing robustness table for appendix

esttab petition5 petition6 petition10 petition11 ///
    using "`OUTTAB'/tab_reg_petition_appendix.tex", ///
    title("Determinants of Renegotiation: Robustness Checks") ///
    order(price_shock_l5_f5 coal_sector_power) ///
    indicate("Firm controls = `FIRMCONTROLS'", labels("Yes" "")) ///
    b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    alignment(D{.}{.}{-1}) label width(1\hsize)  ///
    replace nomtitles booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{5}{p{0.98\hsize}}{\footnotesize REVISE The table shows linear probability models for whether an auction winner filed a petition for renegotiation of tariffs. The explanatory variables are the shock to coal prices around the time of bidding, a dummy for whether a plant is an ultra-mega power plant (the largest projects) and dummies for the source of fuel used by the plant. The coal price shock is measured as the difference in coal prices in a five-year moving period after the auction date relative to a five-year moving period before the auction. The units for the coal price shock are converted from USD per ton, the original price of the coal price index, to INR per kWh, by assuming a calorific value of coal of 6300 kcal per kg and a plant heat rate of 11615 btu. Hence a one unit change in coal prices is the change in coal prices that would cause a plant with this efficiency and using this grade of coal to experience a one INR per kWh increase in the marginal cost of power generation. The coal price shock has been demeaned. Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Summary statistics of regression variables: renegotiation

estpost tabstat petition_filed petition_granted price_shock_l5_f5 ///
    fuel_imported_shock_l5_f5 capacity_umpp coal_imported coal_domestic ///
    coal_sector_power `FIRMCONTROLS' if insample, ///
    statistics(mean sd) columns(statistics)

esttab using "`OUTTAB'/tab_reg_petition_summary_stats.tex", ///
    cells("mean(fmt(%4.2f)) sd(fmt(%4.2f))") ///
    title("Summary statistics for determinants of renegotiation") ///
    unstack varwidth(36) nonumber nogaps label replace nomtitles ///
    booktabs width(0.6\hsize) ///
    postfoot("\bottomrule" ///
             "\multicolumn{3}{p{0.56\hsize}}{\footnotesize The table shows summary statistics for the dependent and indepenent variables in the regressions of Tables~2 and 3. The variables are: whether a bidder filed a petition for a revision to their tariff; whether the bidder filed a petition for a new tariff that was granted; the (de-meaned) shock to coal prices from the five years before a project was bid to the five years after; the interaction of the coal price shock with a dummy for the use of imported coal; dummies for imported and domestic coal use; a dummy for a firm being connected, as measured by having received coal during the coalgate scandal, the age of the firm and a dummy for whether the firm is publicly owned.}\\" ///
             "\end{tabular*}" ///
             "\end{table}")


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Summary statistics of bids and auctions, by petition status
gen petition_status = 0
replace petition_status = 1 if petition_filed
replace petition_status = 2 if petition_granted
label var petition_status "Petition status"

local COMPVARS tariff_level bidders_per_winner

cd "`OUTTAB'"
ttestTablefast `COMPVARS', treat(petition_status) casewise(1) ///
  outname("tab_renegotiation_by_tariff") ///
  title("Tariff bid by renegotiation status") ///
  label("") csv("FALSE")

ttest tariff_level, by(petition_filed)
ttest tariff_level, by(petition_granted)

ttest num_bidders, by(petition_filed)
ttest bidders_per_winner, by(petition_filed)

clear

}  /* End TAB_REG_RENEGOTIATION_NEW */


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 4: Firm Connectedness and Bidding Strategies
if `TAB_REG_BID_INDEXATION' == 1 {

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare regression controls

cd "`COALGATE'/clean"
use cag_coal_blocks_with_inventory

local FIRMCONTROLS bidder_age ownership_public
sum `FIRMCONTROLS'

local AUCCONTROLS coal_captive coal_imported trailing_price
sum `AUCCONTROLS'

encode auction_id_provisional, generate(auction_code)


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Create variables useful in regression analysis

label var coal_sector_power "Connected firm (=1)"

gen coal_tied_to_auction = coal_imported | coal_captive
label var coal_tied_to_auction "Coal source with project (=1)"

gen coal_block_X_tied_to_auction = coal_tied_to_auction * coal_sector_power
label var coal_block_X_tied_to_auction "Connected firm (=1) $\times$ coal tied to auction (=1)"

gen bid_before_coal_power = (auction_month < coal_month_power) & coal_sector_power
label var bid_before_coal_power "Bid before getting coal (=1)"

gen bid_before_coal_metals = (auction_month < coal_month_metals) & coal_sector_metals
label var bid_before_coal_metals "Bid before getting coal (metals) (=1)"
tab bid_before_coal_power coal_sector_power

gen coal_block_X_bid_before_coal = bid_before_coal_power * coal_sector_power 
label var coal_block_X_bid_before_coal "Connected firm (=1) $\times$ bid before getting coal (=1)"

sum frac_indexed


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Estimation determinants of bid strategy: fraction indexed

// Without auction fixed effects
qui reg frac_indexed coal_sector_power levelisedtariff, robust
est store reglt1

qui reg frac_indexed coal_sector_power levelisedtariff coal_qty_power_dm ///
  `AUCCONTROLS' `FIRMCONTROLS', robust
est store reglt5

// With auction FEs
qui areg frac_indexed coal_sector_power levelisedtariff coal_qty_power_dm ///
  `FIRMCONTROLS', absorb(auction_code) vce(robust)
est store areglt5

qui areg frac_indexed coal_sector_power levelisedtariff ///
   coal_block_X_tied_to_auction coal_qty_power_dm ///
  `FIRMCONTROLS', absorb(auction_code) vce(robust)
est store areglt6

qui areg frac_indexed coal_sector_power levelisedtariff ///
   coal_block_X_bid_before_coal coal_qty_power_dm ///
  `FIRMCONTROLS', absorb(auction_code) vce(robust)
est store areglt7

estadd ysumm, mean: areglt5 areglt6 areglt7
estadd local fixed "Yes", replace: areglt5 areglt6 areglt7

esttab areglt5 areglt6 areglt7, ///
    order(coal_sector_power coal_block_X_tied_to_auction coal_block_X_bid_before_coal) ///
    indicate("Firm controls = `FIRMCONTROLS' coal_qty_power_dm" ///
             , labels("Yes" "")) ///
    stats(fixed ymean N, fmt(2 2 0) ///
          labels("Auction fixed effects" "Mean dep. var." "Observations")) ///
    b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01)


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Summary table on bid strategy

esttab reglt1 reglt5 areglt5 areglt6 areglt7 ///
    using "`OUTTAB'/tab_reg_bid_strategies.tex", ///
    title("Firm Connectedness and Bidding Strategies") ///
    order(coal_sector_power levelisedtariff coal_block_X_tied_to_auction coal_block_X_bid_before_coal) ///
    indicate("Firm controls = `FIRMCONTROLS' coal_qty_power_dm" ///
             "Auction controls = `AUCCONTROLS'", labels("Yes" "")) ///
    noconstant b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    stats(fixed ymean N, fmt(2 2 0) ///
          labels("Auction fixed effects" "Mean dep. var." "Observations")) ///
    label width(1\hsize) replace nomtitles booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{6}{p{0.98\hsize}}{\footnotesize The table shows estimates of linear regressions of bidding strategies on firm connectedness. The dependent variable is the fraction of the expected present discounted value of bids that a firm indexed to the price of coal in their bid. The main independent variable of interest is ``Connected firm (=1)'', which is a dummy variable equal to one if the firm bidding was allocated a coal block during the Coalgate scandal. All regressions control for the present discounted value of the bid, denoted as the bid price here. Firm-level controls are the firm age at bidding and whether the firm is publicly owned. Auction controls include a set of dummies for the source of fuel and the price of coal at the time of bidding. See the text for a description of the interaction variables. Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Summary table on bid strategy
//   -- without controls for bid price
estimates clear

qui reg frac_indexed coal_sector_power, robust
est store reglt1

qui reg frac_indexed coal_sector_power coal_qty_power_dm ///
  `AUCCONTROLS' `FIRMCONTROLS', robust
est store reglt5

qui areg frac_indexed coal_sector_power coal_qty_power_dm ///
  `FIRMCONTROLS', absorb(auction_code) vce(robust)
est store areglt5

qui areg frac_indexed coal_sector_power ///
   coal_block_X_tied_to_auction coal_qty_power_dm ///
  `FIRMCONTROLS', absorb(auction_code) vce(robust)
est store areglt6

qui areg frac_indexed coal_sector_power ///
   coal_block_X_bid_before_coal coal_qty_power_dm ///
  `FIRMCONTROLS', absorb(auction_code) vce(robust)
est store areglt7
gen insample = e(sample) == 1

estadd ysumm, mean: reglt1 reglt5 areglt5 areglt6 areglt7
estadd local fixed "Yes", replace: areglt5 areglt6 areglt7

esttab reglt1 reglt5 areglt5 areglt6 areglt7 ///
    using "`OUTTAB'/tab_reg_bid_strategies_noprice.tex", ///
    title("Firm Connectedness and Bidding Strategies") ///
    order(coal_sector_power coal_block_X_tied_to_auction coal_block_X_bid_before_coal) ///
    indicate("Firm controls = `FIRMCONTROLS' coal_qty_power_dm" ///
             "Auction controls = `AUCCONTROLS'", labels("Yes" "")) ///
    noconstant b(a3) se(a3) star(* 0.10 ** 0.05 *** 0.01) ///
    stats(fixed ymean N, fmt(2 2 0) ///
          labels("Auction fixed effects" "Mean dep. var." "Observations")) ///
    label width(1\hsize) replace nomtitles booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{6}{p{0.98\hsize}}{\footnotesize The table shows estimates of linear regressions of bidding strategies on firm connectedness. The dependent variable is the fraction of the expected present discounted value of bids that a firm indexed to the price of coal in their bid. The main independent variable of interest is ``Connected firm (=1)'', which is a dummy variable equal to one if the firm bidding was allocated a coal block during the Coalgate scandal. Firm-level controls are the firm age at bidding and whether the firm is publicly owned. Auction controls include a set of dummies for the source of fuel and the price of coal at the time of bidding. See the text for a description of the interaction variables. Robust standard errors in parentheses with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Summary statistics of regression variables: indexation

estpost tabstat frac_indexed coal_sector_power levelisedtariff ///
  coal_block_X_tied_to_auction coal_block_X_bid_before_coal ///
  `FIRMCONTROLS' `AUCCONTROLS' if insample, ///
  statistics(mean sd) columns(statistics)

esttab using "`OUTTAB'/tab_reg_indexation_summary_stats.tex", ///
    cells("mean(fmt(%4.2f)) sd(fmt(%4.2f))") ///
    title("Summary statistics for bidding strategies") ///
    unstack varwidth(36) nonumber nogaps label replace nomtitles ///
    booktabs width(0.7\hsize) ///
    postfoot("\bottomrule" ///
             "\multicolumn{3}{p{0.66\hsize}}{\footnotesize The table shows summary statistics for the dependent and indepenent variables in the regressions of Table 4. The variables are: the fraction of the present value of a bid indexed to the price of coal; a dummy for a firm being connected, as measured by having received coal during the coalgate scandal; the present discounted value of the bid; an interaction between being connected and the source of coal for a project being bundled with the auction; an interaction between being connected and the auction being bid out before a connected firm was awarded a coal block in coalgate; the age of the firm; a dummy for whether the firm is publicly owned and controls for the source of coal for a project and the coal price at the time of an auction.}\\" ///
             "\end{tabular*}" ///
             "\end{table}")

clear

}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                            Appendix Exhibits
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Hazard model of petition for renegotiation on project characteristics
if `TAB_REG_RENEGOTIATION_HAZARD' == 1 {

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare price shock data
// Load data on prices
use "`WORK'/coal_prices.dta"

gen int year = year( dofm(yearmonth) )
label var year "Year"

// Convert price to 5y MA
tsset yearmonth
tssmooth ma coal_price_l5y = coal_price, window(59 1 0)

label var coal_price     "Coal price (USD/ton)"
label var coal_price_l5y "Coal price (USD/ton), 5-year MA"
label data               "Coal prices, Newcastle index"

sort yearmonth
save "`WORK'/coal_prices_smoothed", replace

clear

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Prepare outcome data for hazard analysis  
cd "`WORK'"
use clean_outcomes

keep petition_year capacity_umpp coal_imported coal_domestic ///
  auction_year yearmonth bid_id petition_filed petition_ym

// Restrict to observations that have known petition status
tab petition_filed, missing
keep if !missing(petition_filed)

gen petition_year_trunc = petition_year
replace petition_year_trunc = 2018 if missing(petition_year)

gen petition_ym_trunc = petition_ym
replace petition_ym_trunc = tm(2018m1) if missing(petition_ym)

rename yearmonth auction_yearmonth
stset petition_ym_trunc, id(bid_id) failure(petition_filed) ///
  origin(time auction_yearmonth) 
stsplit monthcount, every(1)

sort _origin bid_id monthcount
list _origin bid_id monthcount petition_filed in 1/70

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Add coal prices to data as a time-varying control

// Merge in coal price in year at risk (running time variable)
gen int yearmonth = _origin + monthcount
label var yearmonth "Year-month in survival data"
format yearmonth %tm
tab yearmonth

sort yearmonth
merge m:1 yearmonth using "`WORK'/coal_prices_smoothed", generate(mergeCoal) ///
  update replace

drop if mergeCoal == 2
drop mergeCoal
rename coal_price_l5y coal_price_lagged
codebook coal_price_lagged

// Merge in coal price in origin year
rename yearmonth yearmonth_atrisk
gen yearmonth = _origin
label var yearmonth "Year-month of auction"
format yearmonth %tm
tab yearmonth

sort yearmonth
merge m:1 yearmonth using "`WORK'/coal_prices_smoothed", generate(mergeCoal) ///
  update replace

codebook yearmonth
drop if mergeCoal == 2
drop mergeCoal
rename coal_price_l5y coal_price_origin

// Generate coal price shock in equivalent cost of fuel per kWh
//      USD  =  1 kg      * 1 ton   * 1 kcal   * 11615 btu  * 50 INR
//      ton     6300 kcal   1000 kg   3.96 btu   1 kwh        1 USD
gen price_shock_orig_curr = coal_price_lagged - coal_price_origin
replace price_shock_orig_curr = price_shock_orig_curr / 6300 / 1000 / 3.96 * 11615 * `INRPERUSD'
label var price_shock_orig_curr "Coal price shock (INR per kWh)"

tabstat price_shock_orig_curr, stats(mean) by(_origin)
// tabstat price_shock_orig_curr, stats(mean) by(yearmonth_atrisk)

// De-mean shock
foreach V of varlist price_shock_orig_curr {
    egen `V'_mean = mean(`V')
    replace `V' = `V' - `V'_mean
    drop `V'_mean
}

// Generate interactions of fuel source and price shock
gen fuel_imported_shock_orig_curr = coal_imported * price_shock_orig_curr
label var fuel_imported_shock_orig_curr "Coal imported (=1) $\times$ coal price shock"

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Estimate petition filing hazard as a function of
//   interactions of fuel source and price shock

stcox price_shock_orig_curr, vce(cluster bid_id)
est store hazard1

stcox price_shock_orig_curr capacity_umpp, vce(cluster bid_id)
est store hazard2

stcox capacity_umpp coal_imported coal_domestic, vce(cluster bid_id)
est store hazard3

stcox price_shock_orig_curr fuel_imported_shock_orig_curr ///
  capacity_umpp coal_imported coal_domestic, vce(cluster bid_id)
est store hazard4
gen insample = e(sample) == 1

esttab hazard1 hazard2 hazard3 hazard4 ///
    using "`OUTTAB'/tab_reg_petition_hazard.tex", ///
    title("Cost Shocks and Renegotiation, Hazard Model") ///
    order(price_shock_orig_curr fuel_imported_shock_orig_curr ///
          capacity_umpp coal_imported coal_domestic) ///
    eform b(a3) p(a2) star(* 0.10 ** 0.05 *** 0.01) ///
    alignment(D{.}{.}{-1}) label width(1\hsize)  ///
    replace nomtitles booktabs ///
    postfoot("\bottomrule" ///
             "\multicolumn{5}{p{0.98\hsize}}{\footnotesize The table shows hazard ratios from Cox proportional hazard models for whether an auction winner filed a petition for renegotiation of tariffs. In hazard model terms, filing a petition represents failure. The sample is monthly data from the first year of auctions, 2006, to the end of 2017. Contracts are at risk of failure from the time of the auction until failure is observed or until the end of the sample. The explanatory variables include a time-varying shock to coal prices from the month of bidding to the observation month. Explanatory variables that do not vary in time include: a dummy for whether a plant is an ultra-mega power plant (the largest projects) and dummies for the source of fuel used by the plant. The coal price shock is measured as the difference in coal prices in a five-year moving average in the observation month minus the same five-year moving average in the auction month. The units for the coal price shock are converted from USD per ton, the original price of the coal price index, to INR per kWh, by assuming a calorific value of coal of 6300 kcal per kg and a plant heat rate of 11615 btu. Hence a one unit change in coal prices is the change in coal prices that would cause a plant with this efficiency and using this grade of coal to experience a one INR per kWh increase in the marginal cost of power generation. The coal price shock has been demeaned. Table entries are hazard ratios, not coefficients. Inference is done with robust standard errors clustered at the bid level (across years); p-values from a test of the null that the hazard ratio is equal to one are in parentheses, with \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).}\\" ///
             "\end{tabular*}" ///
             "\end{table}")

} /* End TAB_REG_RENEGOTIATION_HAZARD */


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                                     END
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%








