/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

PROJECT: Longbids

PURPOSE: Helper programs used to create exhibits.

AUTHOR:  Nick Ryan

DATE:    20 June, 2012
         Modified July, 2019

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// T-test table where each test is performed on a different variable, across
//   the same categorical dummy by variable.
capt prog drop diffTest3
program diffTest3, eclass
  syntax varlist [if] [in], by(varname) [strata(varlist) ///
         usestrat(integer 0) casewise(integer 1)] [ * ] 
  marksample touse
  markout `touse' `by'
  tempname N N_1 N_2 sd_1 sd_2 mu_1 mu_2 d d_se d_t d_p
  foreach var of local varlist {
      if `casewise' == 0 {
          qui ttest `var' if `touse', by(`by') `options'
      }
      else {
          qui ttest `var', by(`by') `options'
      }        
      local N_T = r(N_1) + r(N_2)
      mat `N'   = nullmat(`N'), `N_T'

      // Code to store treatment and control means
      //   Treatment column first
      // mat `N_1' = nullmat(`N_1'), r(N_2)
      // mat `N_2' = nullmat(`N_2'), r(N_1)
      // mat `mu_1' = nullmat(`mu_1'), r(mu_2)
      // mat `mu_2' = nullmat(`mu_2'), r(mu_1)
      // mat `sd_1' = nullmat(`sd_1'), r(sd_2)
      // mat `sd_2' = nullmat(`sd_2'), r(sd_1)

      //   Control column first
      mat `N_1' = nullmat(`N_1'), r(N_1)
      mat `N_2' = nullmat(`N_2'), r(N_2)
      mat `mu_1' = nullmat(`mu_1'), r(mu_1)
      mat `mu_2' = nullmat(`mu_2'), r(mu_2)
      mat `sd_1' = nullmat(`sd_1'), r(sd_1)
      mat `sd_2' = nullmat(`sd_2'), r(sd_2)

      // if `usestrat' & `cluster' {
      //     qui xi: reg `var' `by' i.`strata', cluster(`cluster')
      // }
      if `usestrat' {
      //    qui xi: reg `var' `by' i.`strata'
          qui xi: reg `var' `by' i.`strata', vce(robust)
      }
      else {
          qui reg `var' `by', vce(robust)
      }
      mat `d'    = nullmat(`d'   ), _b[`by']
      mat `d_se' = nullmat(`d_se'), _se[`by']
      mat `d_t'  = nullmat(`d_t' ), (_b[`by']/_se[`by'])
      mat `d_p'  = nullmat(`d_p' ), (2*ttail( e(df_r), abs(_b[`by']/_se[`by'])))
  }
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p N N_1 N_2 {
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p N N_1 N_2 {
      eret mat `mat' = ``mat''
  }
end

capt prog drop ttestTable3
program define ttestTable3
  syntax varlist, by(varname) [strata(varlist) outname(string) ///
                               title(string) label(string) csv(string) ///
                               usestrat(integer 0) casewise(integer 1)] 

  diffTest3 `varlist', by(`by') strata(`strata') usestrat(`usestrat') ///
                       casewise(`casewise')

  if "`csv'" == "TRUE" {
    esttab using `outname'.rtf, ///
      title("`title'") ///
      nomtitles nonumbers collabels("Control" "Treatment" "Difference") ///
      varwidth(32) label replace nogap compress ///
      cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" ///
            "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)" ///
            "N_1(fmt(a2)) N_2 N") ///
      star(* 0.10 ** 0.05 *** 0.01) ///
      addnotes("* p lt 0.10, ** p lt 0.05, *** p lt 0.01" ///
               "Last updated: $S_DATE $S_TIME.")
  }

  else {
    esttab using `outname'.tex, ///
      title("`title'"\label{tab:"`label'"}) ///
      nomtitles nonumbers collabels("Control" "Treatment" "Difference") ///
      varwidth(32) label replace nogap compress booktabs width(0.9\hsize) ///
      cells("mu_1(fmt(a2))          mu_2           d(star pvalue(d_p))" ///
            "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)" ///
            "N_1(fmt(a2))           N_2            N" ) ///
      star(* 0.10 ** 0.05 *** 0.01) ///
      addnotes("* p lt 0.10, ** p lt 0.05, *** p lt 0.01" ///
               "Last updated: $S_DATE $S_TIME.")
  }
end


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Program to do t-tests with multiple cateogries
capt prog drop diffTestfast
program diffTestfast, eclass
  syntax varlist [if] [in], treat(varname) [strata(varlist) ///
         usestrat(integer 0) casewise(integer 1)] [ * ] 
  marksample touse
  markout `touse'
  tempname N1 N2 N_1 N_2 N_3 sd_1 sd_2 sd_3 mu_1 mu_2 mu_3 d1 d2 d_se1 d_se2 d_t1 d_t2 d_p1 d_p2
  foreach var of local varlist {

      // Create cumulative treatment dummies
      tempvar treat1 treat2
      gen `treat1' = inlist(`treat',1,2)
      gen `treat2' = inlist(`treat',2)

      // Run t-test command to get summary stats by group
      qui ttest `var', by(`treat1') `options'
      local N_T1 = r(N_1) + r(N_2)
      mat `N1'   = nullmat(`N1'), `N_T1'
      mat `N_1'  = nullmat(`N_1'), r(N_1)
      mat `N_2'  = nullmat(`N_2'), r(N_2)
      mat `mu_1' = nullmat(`mu_1'), r(mu_1)
      mat `mu_2' = nullmat(`mu_2'), r(mu_2)
      mat `sd_1' = nullmat(`sd_1'), r(sd_1)
      mat `sd_2' = nullmat(`sd_2'), r(sd_2)

      qui ttest `var', by(`treat2') `options'
      local N_T2 = r(N_1) + r(N_2)
      mat `N2'   = nullmat(`N1'), `N_T2'
      mat `N_3'  = nullmat(`N_3'), r(N_2)
      mat `mu_3' = nullmat(`mu_3'), r(mu_2)
      mat `sd_3' = nullmat(`sd_3'), r(sd_2)

      // Run regression to get differences and standard errors
      qui reg `var' `treat1', vce(robust)
      mat `d1'    = nullmat(`d1'   ), _b[`treat1']
      mat `d_se1' = nullmat(`d_se1'), _se[`treat1']
      mat `d_t1'  = nullmat(`d_t1' ), (_b[`treat1']/_se[`treat1'])
      mat `d_p1'  = nullmat(`d_p1' ), (2*ttail( e(df_r), abs(_b[`treat1']/_se[`treat1'])))
	
      qui reg `var' `treat2', vce(robust)
      mat `d2'    = nullmat(`d2'   ), _b[`treat2']
      mat `d_se2' = nullmat(`d_se2'), _se[`treat2']
      mat `d_t2'  = nullmat(`d_t2' ), (_b[`treat2']/_se[`treat2'])
      mat `d_p2'  = nullmat(`d_p2' ), (2*ttail( e(df_r), abs(_b[`treat2']/_se[`treat2'])))
	  
  }
  foreach mat in mu_1 mu_2 mu_3 sd_1 sd_2 sd_3 d1 d2 d_se1 d_se2 d_t1 d_t2 d_p1 d_p2 N1 N2 N_1 N_2 N_3 {
      display "`mat'"
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in mu_1 mu_2 mu_3 sd_1 sd_2 sd_3 d1 d2 d_se1 d_se2 d_t1 d_t2 d_p1 d_p2 N1 N2 N_1 N_2 N_3 {
      eret mat `mat' = ``mat''
  }

end

capt prog drop ttestTablefast
program define ttestTablefast
  syntax varlist, treat(varname) [strata(varlist) outname(string) ///
                               title(string) label(string) csv(string) ///
                               usestrat(integer 0) casewise(integer 1)] 

  diffTestfast `varlist', treat(`treat') strata(`strata') usestrat(`usestrat') ///
                       casewise(`casewise')

  esttab using `outname'.tex, ///
  title("`title'"\label{tab:"`label'"}) ///
  noobs nomtitles collabels("None" "Filed" "Granted" "Filed - None" "Granted - None") ///
  varwidth(32) label replace nogap compress booktabs width(0.9\hsize) ///
  cells("mu_1(fmt(a2))           mu_2             mu_3              d1(star pvalue(d_p1))       d2(star pvalue(d_p2))" ///
        "sd_1(fmt(a2) par([ ]))  sd_2(par([ ]))   sd_3(par([ ]))    d_se1(par)                  d_se2(par)" ///
        "N_1(fmt(a2))            N_2              N_3               N1                          N2" ) ///
  star(* 0.10 ** 0.05 *** 0.01) ///
  addnotes("* p lt 0.10, ** p lt 0.05, *** p lt 0.01" ///
           "Last updated: $S_DATE $S_TIME.")

end


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                                 END
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
